import{c as qt,r as f,j as _,R as co,i as Jt,e as je,k as sa,u as er}from"./index-qMrAuFFG.js";import{c as ee,l as ca}from"./queries-B0q6a4VE.js";/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const aa=[["path",{d:"M20 6 9 17l-5-5",key:"1gmf2c"}]],ua=qt("Check",aa);/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const la=[["path",{d:"m6 9 6 6 6-6",key:"qrunsl"}]],ao=qt("ChevronDown",la);/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const fa=[["path",{d:"m18 15-6-6-6 6",key:"153udz"}]],da=qt("ChevronUp",fa);/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const pa=[["rect",{width:"8",height:"18",x:"3",y:"3",rx:"1",key:"oynpb5"}],["path",{d:"M7 3v18",key:"bbkbws"}],["path",{d:"M20.4 18.9c.2.5-.1 1.1-.6 1.3l-1.9.7c-.5.2-1.1-.1-1.3-.6L11.1 5.1c-.2-.5.1-1.1.6-1.3l1.9-.7c.5-.2 1.1.1 1.3.6Z",key:"1qboyk"}]],xv=qt("LibraryBig",pa),Sv=e=>f.createElement("svg",{width:"1em",height:"1em",viewBox:"0 0 64 64",fill:"none",xmlns:"http://www.w3.org/2000/svg",...e},f.createElement("path",{d:"M52.9014 9.88223C52.9014 11.8054 51.3412 13.3644 49.4166 13.3644C47.492 13.3644 45.9318 11.8054 45.9318 9.88223C45.9318 7.9591 47.492 6.40009 49.4166 6.40009C51.3412 6.40009 52.9014 7.9591 52.9014 9.88223Z",fill:"currentColor"}),f.createElement("path",{d:"M52.9014 9.88223C52.9014 11.8054 51.3412 13.3644 49.4166 13.3644C47.492 13.3644 45.9318 11.8054 45.9318 9.88223C45.9318 7.9591 47.492 6.40009 49.4166 6.40009C51.3412 6.40009 52.9014 7.9591 52.9014 9.88223Z",fill:"currentColor"}),f.createElement("path",{d:"M41.053 13.3644C41.053 15.2875 39.4928 16.8465 37.5682 16.8465C35.6435 16.8465 34.0833 15.2875 34.0833 13.3644C34.0833 11.4412 35.6435 9.88223 37.5682 9.88223C39.4928 9.88223 41.053 11.4412 41.053 13.3644Z",fill:"currentColor"}),f.createElement("path",{d:"M41.053 13.3644C41.053 15.2875 39.4928 16.8465 37.5682 16.8465C35.6435 16.8465 34.0833 15.2875 34.0833 13.3644C34.0833 11.4412 35.6435 9.88223 37.5682 9.88223C39.4928 9.88223 41.053 11.4412 41.053 13.3644Z",fill:"currentColor"}),f.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M21.1513 29.924C21.1513 35.9728 24.1217 41.3284 28.6845 44.6137C31.4126 42.1705 33.1291 38.6224 33.1291 34.6736V24.9187C33.1291 23.4495 34.121 22.1652 35.5434 21.7928L53.36 17.1279C55.4098 16.5912 57.4136 18.1364 57.4136 20.2538L57.4136 32.1232C57.4136 46.1937 45.9984 57.6001 31.9171 57.6001L31.8755 57.6001C17.7941 57.6001 6.37891 46.1937 6.37891 32.1232V23.9317C6.37891 22.457 7.37805 21.1694 8.80736 20.8021L17.1119 18.668C19.1582 18.1421 21.1513 19.6863 21.1513 21.7976V29.924ZM10.0748 32.1232C10.0748 37.0258 11.6957 41.5501 14.4311 45.1904C15.706 46.8871 17.6525 48.0176 19.7748 48.0176C21.7952 48.0176 23.7108 47.5693 25.4274 46.7668C20.56 42.771 17.4554 36.7098 17.4554 29.924V22.393L10.0748 24.2896V32.1232Z",fill:"currentColor"}),f.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M21.1513 29.924C21.1513 35.9728 24.1217 41.3284 28.6845 44.6137C31.4126 42.1705 33.1291 38.6224 33.1291 34.6736V24.9187C33.1291 23.4495 34.121 22.1652 35.5434 21.7928L53.36 17.1279C55.4098 16.5912 57.4136 18.1364 57.4136 20.2538L57.4136 32.1232C57.4136 46.1937 45.9984 57.6001 31.9171 57.6001L31.8755 57.6001C17.7941 57.6001 6.37891 46.1937 6.37891 32.1232V23.9317C6.37891 22.457 7.37805 21.1694 8.80736 20.8021L17.1119 18.668C19.1582 18.1421 21.1513 19.6863 21.1513 21.7976V29.924ZM10.0748 32.1232C10.0748 37.0258 11.6957 41.5501 14.4311 45.1904C15.706 46.8871 17.6525 48.0176 19.7748 48.0176C21.7952 48.0176 23.7108 47.5693 25.4274 46.7668C20.56 42.771 17.4554 36.7098 17.4554 29.924V22.393L10.0748 24.2896V32.1232Z",fill:"currentColor"}));function br(e,t){if(typeof e=="function")return e(t);e!=null&&(e.current=t)}function uo(...e){return t=>{let n=!1;const r=e.map(o=>{const i=br(o,t);return!n&&typeof i=="function"&&(n=!0),i});if(n)return()=>{for(let o=0;o<r.length;o++){const i=r[o];typeof i=="function"?i():br(e[o],null)}}}}function Q(...e){return f.useCallback(uo(...e),e)}function pt(e){const t=ma(e),n=f.forwardRef((r,o)=>{const{children:i,...s}=r,c=f.Children.toArray(i),a=c.find(va);if(a){const u=a.props.children,l=c.map(d=>d===a?f.Children.count(u)>1?f.Children.only(null):f.isValidElement(u)?u.props.children:null:d);return _.jsx(t,{...s,ref:o,children:f.isValidElement(u)?f.cloneElement(u,void 0,l):null})}return _.jsx(t,{...s,ref:o,children:i})});return n.displayName=`${e}.Slot`,n}var ha=pt("Slot");function ma(e){const t=f.forwardRef((n,r)=>{const{children:o,...i}=n;if(f.isValidElement(o)){const s=wa(o),c=ga(i,o.props);return o.type!==f.Fragment&&(c.ref=r?uo(r,s):s),f.cloneElement(o,c)}return f.Children.count(o)>1?f.Children.only(null):null});return t.displayName=`${e}.SlotClone`,t}var lo=Symbol("radix.slottable");function Ev(e){const t=({children:n})=>_.jsx(_.Fragment,{children:n});return t.displayName=`${e}.Slottable`,t.__radixId=lo,t}function va(e){return f.isValidElement(e)&&typeof e.type=="function"&&"__radixId"in e.type&&e.type.__radixId===lo}function ga(e,t){const n={...t};for(const r in t){const o=e[r],i=t[r];/^on[A-Z]/.test(r)?o&&i?n[r]=(...c)=>{const a=i(...c);return o(...c),a}:o&&(n[r]=o):r==="style"?n[r]={...o,...i}:r==="className"&&(n[r]=[o,i].filter(Boolean).join(" "))}return{...e,...n}}function wa(e){var r,o;let t=(r=Object.getOwnPropertyDescriptor(e.props,"ref"))==null?void 0:r.get,n=t&&"isReactWarning"in t&&t.isReactWarning;return n?e.ref:(t=(o=Object.getOwnPropertyDescriptor(e,"ref"))==null?void 0:o.get,n=t&&"isReactWarning"in t&&t.isReactWarning,n?e.props.ref:e.props.ref||e.ref)}const ba=ca("inline-flex items-center justify-center gap-2 whitespace-nowrap rounded-md text-sm font-medium transition-all disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4 shrink-0 [&_svg]:shrink-0 outline-none focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive cursor-pointer",{variants:{variant:{default:"bg-primary text-primary-foreground hover:bg-primary/90",destructive:"bg-destructive text-white hover:bg-destructive/90 focus-visible:ring-destructive/20 dark:focus-visible:ring-destructive/40 dark:bg-destructive/60",outline:"border bg-background shadow-xs hover:bg-accent hover:text-accent-foreground dark:bg-input/30 dark:border-input dark:hover:bg-input/50",secondary:"bg-secondary text-secondary-foreground hover:bg-secondary/80",ghost:"hover:bg-accent hover:text-accent-foreground dark:hover:bg-accent/50",link:"text-primary underline-offset-4 hover:underline"},size:{default:"h-9 px-4 py-2 has-[>svg]:px-3",sm:"h-8 rounded-md gap-1.5 px-3 has-[>svg]:px-2.5",lg:"h-10 rounded-md px-6 has-[>svg]:px-4",icon:"size-9","icon-sm":"size-8","icon-lg":"size-10"}},defaultVariants:{variant:"default",size:"default"}});function Cv({className:e,variant:t,size:n,asChild:r=!1,...o}){const i=r?ha:"button";return _.jsx(i,{"data-slot":"button",className:ee(ba({variant:t,size:n,className:e})),...o})}function W(e,t,{checkForDefaultPrevented:n=!0}={}){return function(o){if(e==null||e(o),n===!1||!o.defaultPrevented)return t==null?void 0:t(o)}}function zv(e,t){const n=f.createContext(t),r=i=>{const{children:s,...c}=i,a=f.useMemo(()=>c,Object.values(c));return _.jsx(n.Provider,{value:a,children:s})};r.displayName=e+"Provider";function o(i){const s=f.useContext(n);if(s)return s;if(t!==void 0)return t;throw new Error(`\`${i}\` must be used within \`${e}\``)}return[r,o]}function Qt(e,t=[]){let n=[];function r(i,s){const c=f.createContext(s),a=n.length;n=[...n,s];const u=d=>{var x;const{scope:m,children:h,...w}=d,p=((x=m==null?void 0:m[e])==null?void 0:x[a])||c,g=f.useMemo(()=>w,Object.values(w));return _.jsx(p.Provider,{value:g,children:h})};u.displayName=i+"Provider";function l(d,m){var p;const h=((p=m==null?void 0:m[e])==null?void 0:p[a])||c,w=f.useContext(h);if(w)return w;if(s!==void 0)return s;throw new Error(`\`${d}\` must be used within \`${i}\``)}return[u,l]}const o=()=>{const i=n.map(s=>f.createContext(s));return function(c){const a=(c==null?void 0:c[e])||i;return f.useMemo(()=>({[`__scope${e}`]:{...c,[e]:a}}),[c,a])}};return o.scopeName=e,[r,ya(o,...t)]}function ya(...e){const t=e[0];if(e.length===1)return t;const n=()=>{const r=e.map(o=>({useScope:o(),scopeName:o.scopeName}));return function(i){const s=r.reduce((c,{useScope:a,scopeName:u})=>{const d=a(i)[`__scope${u}`];return{...c,...d}},{});return f.useMemo(()=>({[`__scope${t.scopeName}`]:s}),[s])}};return n.scopeName=t.scopeName,n}var ne=globalThis!=null&&globalThis.document?f.useLayoutEffect:()=>{},_a=co[" useInsertionEffect ".trim().toString()]||ne;function In({prop:e,defaultProp:t,onChange:n=()=>{},caller:r}){const[o,i,s]=xa({defaultProp:t,onChange:n}),c=e!==void 0,a=c?e:o;{const l=f.useRef(e!==void 0);f.useEffect(()=>{const d=l.current;d!==c&&console.warn(`${r} is changing from ${d?"controlled":"uncontrolled"} to ${c?"controlled":"uncontrolled"}. Components should not switch from controlled to uncontrolled (or vice versa). Decide between using a controlled or uncontrolled value for the lifetime of the component.`),l.current=c},[c,r])}const u=f.useCallback(l=>{var d;if(c){const m=Sa(l)?l(e):l;m!==e&&((d=s.current)==null||d.call(s,m))}else i(l)},[c,e,i,s]);return[a,u]}function xa({defaultProp:e,onChange:t}){const[n,r]=f.useState(e),o=f.useRef(n),i=f.useRef(t);return _a(()=>{i.current=t},[t]),f.useEffect(()=>{var s;o.current!==n&&((s=i.current)==null||s.call(i,n),o.current=n)},[n,o]),[n,r,i]}function Sa(e){return typeof e=="function"}var Ea=["a","button","div","form","h2","h3","img","input","label","li","nav","ol","p","select","span","svg","ul"],q=Ea.reduce((e,t)=>{const n=pt(`Primitive.${t}`),r=f.forwardRef((o,i)=>{const{asChild:s,...c}=o,a=s?n:t;return typeof window<"u"&&(window[Symbol.for("radix-ui")]=!0),_.jsx(a,{...c,ref:i})});return r.displayName=`Primitive.${t}`,{...e,[t]:r}},{});function Ca(e,t){e&&Jt.flushSync(()=>e.dispatchEvent(t))}function fo(e){const t=e+"CollectionProvider",[n,r]=Qt(t),[o,i]=n(t,{collectionRef:{current:null},itemMap:new Map}),s=p=>{const{scope:g,children:x}=p,y=je.useRef(null),b=je.useRef(new Map).current;return _.jsx(o,{scope:g,itemMap:b,collectionRef:y,children:x})};s.displayName=t;const c=e+"CollectionSlot",a=pt(c),u=je.forwardRef((p,g)=>{const{scope:x,children:y}=p,b=i(c,x),E=Q(g,b.collectionRef);return _.jsx(a,{ref:E,children:y})});u.displayName=c;const l=e+"CollectionItemSlot",d="data-radix-collection-item",m=pt(l),h=je.forwardRef((p,g)=>{const{scope:x,children:y,...b}=p,E=je.useRef(null),C=Q(g,E),A=i(l,x);return je.useEffect(()=>(A.itemMap.set(E,{ref:E,...b}),()=>void A.itemMap.delete(E))),_.jsx(m,{[d]:"",ref:C,children:y})});h.displayName=l;function w(p){const g=i(e+"CollectionConsumer",p);return je.useCallback(()=>{const y=g.collectionRef.current;if(!y)return[];const b=Array.from(y.querySelectorAll(`[${d}]`));return Array.from(g.itemMap.values()).sort((A,z)=>b.indexOf(A.ref.current)-b.indexOf(z.ref.current))},[g.collectionRef,g.itemMap])}return[{Provider:s,Slot:u,ItemSlot:h},w,r]}var za=f.createContext(void 0);function po(e){const t=f.useContext(za);return e||t||"ltr"}function Te(e){const t=f.useRef(e);return f.useEffect(()=>{t.current=e}),f.useMemo(()=>(...n)=>{var r;return(r=t.current)==null?void 0:r.call(t,...n)},[])}function ka(e,t=globalThis==null?void 0:globalThis.document){const n=Te(e);f.useEffect(()=>{const r=o=>{o.key==="Escape"&&n(o)};return t.addEventListener("keydown",r,{capture:!0}),()=>t.removeEventListener("keydown",r,{capture:!0})},[n,t])}var Aa="DismissableLayer",Rn="dismissableLayer.update",$a="dismissableLayer.pointerDownOutside",Pa="dismissableLayer.focusOutside",yr,ho=f.createContext({layers:new Set,layersWithOutsidePointerEventsDisabled:new Set,branches:new Set}),mo=f.forwardRef((e,t)=>{const{disableOutsidePointerEvents:n=!1,onEscapeKeyDown:r,onPointerDownOutside:o,onFocusOutside:i,onInteractOutside:s,onDismiss:c,...a}=e,u=f.useContext(ho),[l,d]=f.useState(null),m=(l==null?void 0:l.ownerDocument)??(globalThis==null?void 0:globalThis.document),[,h]=f.useState({}),w=Q(t,z=>d(z)),p=Array.from(u.layers),[g]=[...u.layersWithOutsidePointerEventsDisabled].slice(-1),x=p.indexOf(g),y=l?p.indexOf(l):-1,b=u.layersWithOutsidePointerEventsDisabled.size>0,E=y>=x,C=Ra(z=>{const k=z.target,D=[...u.branches].some(Z=>Z.contains(k));!E||D||(o==null||o(z),s==null||s(z),z.defaultPrevented||c==null||c())},m),A=Na(z=>{const k=z.target;[...u.branches].some(Z=>Z.contains(k))||(i==null||i(z),s==null||s(z),z.defaultPrevented||c==null||c())},m);return ka(z=>{y===u.layers.size-1&&(r==null||r(z),!z.defaultPrevented&&c&&(z.preventDefault(),c()))},m),f.useEffect(()=>{if(l)return n&&(u.layersWithOutsidePointerEventsDisabled.size===0&&(yr=m.body.style.pointerEvents,m.body.style.pointerEvents="none"),u.layersWithOutsidePointerEventsDisabled.add(l)),u.layers.add(l),_r(),()=>{n&&u.layersWithOutsidePointerEventsDisabled.size===1&&(m.body.style.pointerEvents=yr)}},[l,m,n,u]),f.useEffect(()=>()=>{l&&(u.layers.delete(l),u.layersWithOutsidePointerEventsDisabled.delete(l),_r())},[l,u]),f.useEffect(()=>{const z=()=>h({});return document.addEventListener(Rn,z),()=>document.removeEventListener(Rn,z)},[]),_.jsx(q.div,{...a,ref:w,style:{pointerEvents:b?E?"auto":"none":void 0,...e.style},onFocusCapture:W(e.onFocusCapture,A.onFocusCapture),onBlurCapture:W(e.onBlurCapture,A.onBlurCapture),onPointerDownCapture:W(e.onPointerDownCapture,C.onPointerDownCapture)})});mo.displayName=Aa;var Ta="DismissableLayerBranch",Ia=f.forwardRef((e,t)=>{const n=f.useContext(ho),r=f.useRef(null),o=Q(t,r);return f.useEffect(()=>{const i=r.current;if(i)return n.branches.add(i),()=>{n.branches.delete(i)}},[n.branches]),_.jsx(q.div,{...e,ref:o})});Ia.displayName=Ta;function Ra(e,t=globalThis==null?void 0:globalThis.document){const n=Te(e),r=f.useRef(!1),o=f.useRef(()=>{});return f.useEffect(()=>{const i=c=>{if(c.target&&!r.current){let a=function(){vo($a,n,u,{discrete:!0})};const u={originalEvent:c};c.pointerType==="touch"?(t.removeEventListener("click",o.current),o.current=a,t.addEventListener("click",o.current,{once:!0})):a()}else t.removeEventListener("click",o.current);r.current=!1},s=window.setTimeout(()=>{t.addEventListener("pointerdown",i)},0);return()=>{window.clearTimeout(s),t.removeEventListener("pointerdown",i),t.removeEventListener("click",o.current)}},[t,n]),{onPointerDownCapture:()=>r.current=!0}}function Na(e,t=globalThis==null?void 0:globalThis.document){const n=Te(e),r=f.useRef(!1);return f.useEffect(()=>{const o=i=>{i.target&&!r.current&&vo(Pa,n,{originalEvent:i},{discrete:!1})};return t.addEventListener("focusin",o),()=>t.removeEventListener("focusin",o)},[t,n]),{onFocusCapture:()=>r.current=!0,onBlurCapture:()=>r.current=!1}}function _r(){const e=new CustomEvent(Rn);document.dispatchEvent(e)}function vo(e,t,n,{discrete:r}){const o=n.originalEvent.target,i=new CustomEvent(e,{bubbles:!1,cancelable:!0,detail:n});t&&o.addEventListener(e,t,{once:!0}),r?Ca(o,i):o.dispatchEvent(i)}var xn=0;function Za(){f.useEffect(()=>{const e=document.querySelectorAll("[data-radix-focus-guard]");return document.body.insertAdjacentElement("afterbegin",e[0]??xr()),document.body.insertAdjacentElement("beforeend",e[1]??xr()),xn++,()=>{xn===1&&document.querySelectorAll("[data-radix-focus-guard]").forEach(t=>t.remove()),xn--}},[])}function xr(){const e=document.createElement("span");return e.setAttribute("data-radix-focus-guard",""),e.tabIndex=0,e.style.outline="none",e.style.opacity="0",e.style.position="fixed",e.style.pointerEvents="none",e}var Sn="focusScope.autoFocusOnMount",En="focusScope.autoFocusOnUnmount",Sr={bubbles:!1,cancelable:!0},Oa="FocusScope",go=f.forwardRef((e,t)=>{const{loop:n=!1,trapped:r=!1,onMountAutoFocus:o,onUnmountAutoFocus:i,...s}=e,[c,a]=f.useState(null),u=Te(o),l=Te(i),d=f.useRef(null),m=Q(t,p=>a(p)),h=f.useRef({paused:!1,pause(){this.paused=!0},resume(){this.paused=!1}}).current;f.useEffect(()=>{if(r){let p=function(b){if(h.paused||!c)return;const E=b.target;c.contains(E)?d.current=E:Ae(d.current,{select:!0})},g=function(b){if(h.paused||!c)return;const E=b.relatedTarget;E!==null&&(c.contains(E)||Ae(d.current,{select:!0}))},x=function(b){if(document.activeElement===document.body)for(const C of b)C.removedNodes.length>0&&Ae(c)};document.addEventListener("focusin",p),document.addEventListener("focusout",g);const y=new MutationObserver(x);return c&&y.observe(c,{childList:!0,subtree:!0}),()=>{document.removeEventListener("focusin",p),document.removeEventListener("focusout",g),y.disconnect()}}},[r,c,h.paused]),f.useEffect(()=>{if(c){Cr.add(h);const p=document.activeElement;if(!c.contains(p)){const x=new CustomEvent(Sn,Sr);c.addEventListener(Sn,u),c.dispatchEvent(x),x.defaultPrevented||(Da(Ba(wo(c)),{select:!0}),document.activeElement===p&&Ae(c))}return()=>{c.removeEventListener(Sn,u),setTimeout(()=>{const x=new CustomEvent(En,Sr);c.addEventListener(En,l),c.dispatchEvent(x),x.defaultPrevented||Ae(p??document.body,{select:!0}),c.removeEventListener(En,l),Cr.remove(h)},0)}}},[c,u,l,h]);const w=f.useCallback(p=>{if(!n&&!r||h.paused)return;const g=p.key==="Tab"&&!p.altKey&&!p.ctrlKey&&!p.metaKey,x=document.activeElement;if(g&&x){const y=p.currentTarget,[b,E]=Ma(y);b&&E?!p.shiftKey&&x===E?(p.preventDefault(),n&&Ae(b,{select:!0})):p.shiftKey&&x===b&&(p.preventDefault(),n&&Ae(E,{select:!0})):x===y&&p.preventDefault()}},[n,r,h.paused]);return _.jsx(q.div,{tabIndex:-1,...s,ref:m,onKeyDown:w})});go.displayName=Oa;function Da(e,{select:t=!1}={}){const n=document.activeElement;for(const r of e)if(Ae(r,{select:t}),document.activeElement!==n)return}function Ma(e){const t=wo(e),n=Er(t,e),r=Er(t.reverse(),e);return[n,r]}function wo(e){const t=[],n=document.createTreeWalker(e,NodeFilter.SHOW_ELEMENT,{acceptNode:r=>{const o=r.tagName==="INPUT"&&r.type==="hidden";return r.disabled||r.hidden||o?NodeFilter.FILTER_SKIP:r.tabIndex>=0?NodeFilter.FILTER_ACCEPT:NodeFilter.FILTER_SKIP}});for(;n.nextNode();)t.push(n.currentNode);return t}function Er(e,t){for(const n of e)if(!ja(n,{upTo:t}))return n}function ja(e,{upTo:t}){if(getComputedStyle(e).visibility==="hidden")return!0;for(;e;){if(t!==void 0&&e===t)return!1;if(getComputedStyle(e).display==="none")return!0;e=e.parentElement}return!1}function La(e){return e instanceof HTMLInputElement&&"select"in e}function Ae(e,{select:t=!1}={}){if(e&&e.focus){const n=document.activeElement;e.focus({preventScroll:!0}),e!==n&&La(e)&&t&&e.select()}}var Cr=Fa();function Fa(){let e=[];return{add(t){const n=e[0];t!==n&&(n==null||n.pause()),e=zr(e,t),e.unshift(t)},remove(t){var n;e=zr(e,t),(n=e[0])==null||n.resume()}}}function zr(e,t){const n=[...e],r=n.indexOf(t);return r!==-1&&n.splice(r,1),n}function Ba(e){return e.filter(t=>t.tagName!=="A")}var Ua=co[" useId ".trim().toString()]||(()=>{}),Va=0;function en(e){const[t,n]=f.useState(Ua());return ne(()=>{n(r=>r??String(Va++))},[e]),e||(t?`radix-${t}`:"")}const Wa=["top","right","bottom","left"],Ie=Math.min,ie=Math.max,Ft=Math.round,kt=Math.floor,be=e=>({x:e,y:e}),Ha={left:"right",right:"left",bottom:"top",top:"bottom"},Ka={start:"end",end:"start"};function Nn(e,t,n){return ie(e,Ie(t,n))}function Ee(e,t){return typeof e=="function"?e(t):e}function Ce(e){return e.split("-")[0]}function rt(e){return e.split("-")[1]}function tr(e){return e==="x"?"y":"x"}function nr(e){return e==="y"?"height":"width"}const Ga=new Set(["top","bottom"]);function we(e){return Ga.has(Ce(e))?"y":"x"}function rr(e){return tr(we(e))}function Ya(e,t,n){n===void 0&&(n=!1);const r=rt(e),o=rr(e),i=nr(o);let s=o==="x"?r===(n?"end":"start")?"right":"left":r==="start"?"bottom":"top";return t.reference[i]>t.floating[i]&&(s=Bt(s)),[s,Bt(s)]}function Xa(e){const t=Bt(e);return[Zn(e),t,Zn(t)]}function Zn(e){return e.replace(/start|end/g,t=>Ka[t])}const kr=["left","right"],Ar=["right","left"],qa=["top","bottom"],Ja=["bottom","top"];function Qa(e,t,n){switch(e){case"top":case"bottom":return n?t?Ar:kr:t?kr:Ar;case"left":case"right":return t?qa:Ja;default:return[]}}function eu(e,t,n,r){const o=rt(e);let i=Qa(Ce(e),n==="start",r);return o&&(i=i.map(s=>s+"-"+o),t&&(i=i.concat(i.map(Zn)))),i}function Bt(e){return e.replace(/left|right|bottom|top/g,t=>Ha[t])}function tu(e){return{top:0,right:0,bottom:0,left:0,...e}}function bo(e){return typeof e!="number"?tu(e):{top:e,right:e,bottom:e,left:e}}function Ut(e){const{x:t,y:n,width:r,height:o}=e;return{width:r,height:o,top:n,left:t,right:t+r,bottom:n+o,x:t,y:n}}function $r(e,t,n){let{reference:r,floating:o}=e;const i=we(t),s=rr(t),c=nr(s),a=Ce(t),u=i==="y",l=r.x+r.width/2-o.width/2,d=r.y+r.height/2-o.height/2,m=r[c]/2-o[c]/2;let h;switch(a){case"top":h={x:l,y:r.y-o.height};break;case"bottom":h={x:l,y:r.y+r.height};break;case"right":h={x:r.x+r.width,y:d};break;case"left":h={x:r.x-o.width,y:d};break;default:h={x:r.x,y:r.y}}switch(rt(t)){case"start":h[s]-=m*(n&&u?-1:1);break;case"end":h[s]+=m*(n&&u?-1:1);break}return h}const nu=async(e,t,n)=>{const{placement:r="bottom",strategy:o="absolute",middleware:i=[],platform:s}=n,c=i.filter(Boolean),a=await(s.isRTL==null?void 0:s.isRTL(t));let u=await s.getElementRects({reference:e,floating:t,strategy:o}),{x:l,y:d}=$r(u,r,a),m=r,h={},w=0;for(let p=0;p<c.length;p++){const{name:g,fn:x}=c[p],{x:y,y:b,data:E,reset:C}=await x({x:l,y:d,initialPlacement:r,placement:m,strategy:o,middlewareData:h,rects:u,platform:s,elements:{reference:e,floating:t}});l=y??l,d=b??d,h={...h,[g]:{...h[g],...E}},C&&w<=50&&(w++,typeof C=="object"&&(C.placement&&(m=C.placement),C.rects&&(u=C.rects===!0?await s.getElementRects({reference:e,floating:t,strategy:o}):C.rects),{x:l,y:d}=$r(u,m,a)),p=-1)}return{x:l,y:d,placement:m,strategy:o,middlewareData:h}};async function ht(e,t){var n;t===void 0&&(t={});const{x:r,y:o,platform:i,rects:s,elements:c,strategy:a}=e,{boundary:u="clippingAncestors",rootBoundary:l="viewport",elementContext:d="floating",altBoundary:m=!1,padding:h=0}=Ee(t,e),w=bo(h),g=c[m?d==="floating"?"reference":"floating":d],x=Ut(await i.getClippingRect({element:(n=await(i.isElement==null?void 0:i.isElement(g)))==null||n?g:g.contextElement||await(i.getDocumentElement==null?void 0:i.getDocumentElement(c.floating)),boundary:u,rootBoundary:l,strategy:a})),y=d==="floating"?{x:r,y:o,width:s.floating.width,height:s.floating.height}:s.reference,b=await(i.getOffsetParent==null?void 0:i.getOffsetParent(c.floating)),E=await(i.isElement==null?void 0:i.isElement(b))?await(i.getScale==null?void 0:i.getScale(b))||{x:1,y:1}:{x:1,y:1},C=Ut(i.convertOffsetParentRelativeRectToViewportRelativeRect?await i.convertOffsetParentRelativeRectToViewportRelativeRect({elements:c,rect:y,offsetParent:b,strategy:a}):y);return{top:(x.top-C.top+w.top)/E.y,bottom:(C.bottom-x.bottom+w.bottom)/E.y,left:(x.left-C.left+w.left)/E.x,right:(C.right-x.right+w.right)/E.x}}const ru=e=>({name:"arrow",options:e,async fn(t){const{x:n,y:r,placement:o,rects:i,platform:s,elements:c,middlewareData:a}=t,{element:u,padding:l=0}=Ee(e,t)||{};if(u==null)return{};const d=bo(l),m={x:n,y:r},h=rr(o),w=nr(h),p=await s.getDimensions(u),g=h==="y",x=g?"top":"left",y=g?"bottom":"right",b=g?"clientHeight":"clientWidth",E=i.reference[w]+i.reference[h]-m[h]-i.floating[w],C=m[h]-i.reference[h],A=await(s.getOffsetParent==null?void 0:s.getOffsetParent(u));let z=A?A[b]:0;(!z||!await(s.isElement==null?void 0:s.isElement(A)))&&(z=c.floating[b]||i.floating[w]);const k=E/2-C/2,D=z/2-p[w]/2-1,Z=Ie(d[x],D),L=Ie(d[y],D),U=Z,M=z-p[w]-L,O=z/2-p[w]/2+k,H=Nn(U,O,M),I=!a.arrow&&rt(o)!=null&&O!==H&&i.reference[w]/2-(O<U?Z:L)-p[w]/2<0,j=I?O<U?O-U:O-M:0;return{[h]:m[h]+j,data:{[h]:H,centerOffset:O-H-j,...I&&{alignmentOffset:j}},reset:I}}}),ou=function(e){return e===void 0&&(e={}),{name:"flip",options:e,async fn(t){var n,r;const{placement:o,middlewareData:i,rects:s,initialPlacement:c,platform:a,elements:u}=t,{mainAxis:l=!0,crossAxis:d=!0,fallbackPlacements:m,fallbackStrategy:h="bestFit",fallbackAxisSideDirection:w="none",flipAlignment:p=!0,...g}=Ee(e,t);if((n=i.arrow)!=null&&n.alignmentOffset)return{};const x=Ce(o),y=we(c),b=Ce(c)===c,E=await(a.isRTL==null?void 0:a.isRTL(u.floating)),C=m||(b||!p?[Bt(c)]:Xa(c)),A=w!=="none";!m&&A&&C.push(...eu(c,p,w,E));const z=[c,...C],k=await ht(t,g),D=[];let Z=((r=i.flip)==null?void 0:r.overflows)||[];if(l&&D.push(k[x]),d){const O=Ya(o,s,E);D.push(k[O[0]],k[O[1]])}if(Z=[...Z,{placement:o,overflows:D}],!D.every(O=>O<=0)){var L,U;const O=(((L=i.flip)==null?void 0:L.index)||0)+1,H=z[O];if(H&&(!(d==="alignment"?y!==we(H):!1)||Z.every($=>we($.placement)===y?$.overflows[0]>0:!0)))return{data:{index:O,overflows:Z},reset:{placement:H}};let I=(U=Z.filter(j=>j.overflows[0]<=0).sort((j,$)=>j.overflows[1]-$.overflows[1])[0])==null?void 0:U.placement;if(!I)switch(h){case"bestFit":{var M;const j=(M=Z.filter($=>{if(A){const K=we($.placement);return K===y||K==="y"}return!0}).map($=>[$.placement,$.overflows.filter(K=>K>0).reduce((K,re)=>K+re,0)]).sort(($,K)=>$[1]-K[1])[0])==null?void 0:M[0];j&&(I=j);break}case"initialPlacement":I=c;break}if(o!==I)return{reset:{placement:I}}}return{}}}};function Pr(e,t){return{top:e.top-t.height,right:e.right-t.width,bottom:e.bottom-t.height,left:e.left-t.width}}function Tr(e){return Wa.some(t=>e[t]>=0)}const iu=function(e){return e===void 0&&(e={}),{name:"hide",options:e,async fn(t){const{rects:n}=t,{strategy:r="referenceHidden",...o}=Ee(e,t);switch(r){case"referenceHidden":{const i=await ht(t,{...o,elementContext:"reference"}),s=Pr(i,n.reference);return{data:{referenceHiddenOffsets:s,referenceHidden:Tr(s)}}}case"escaped":{const i=await ht(t,{...o,altBoundary:!0}),s=Pr(i,n.floating);return{data:{escapedOffsets:s,escaped:Tr(s)}}}default:return{}}}}},yo=new Set(["left","top"]);async function su(e,t){const{placement:n,platform:r,elements:o}=e,i=await(r.isRTL==null?void 0:r.isRTL(o.floating)),s=Ce(n),c=rt(n),a=we(n)==="y",u=yo.has(s)?-1:1,l=i&&a?-1:1,d=Ee(t,e);let{mainAxis:m,crossAxis:h,alignmentAxis:w}=typeof d=="number"?{mainAxis:d,crossAxis:0,alignmentAxis:null}:{mainAxis:d.mainAxis||0,crossAxis:d.crossAxis||0,alignmentAxis:d.alignmentAxis};return c&&typeof w=="number"&&(h=c==="end"?w*-1:w),a?{x:h*l,y:m*u}:{x:m*u,y:h*l}}const cu=function(e){return e===void 0&&(e=0),{name:"offset",options:e,async fn(t){var n,r;const{x:o,y:i,placement:s,middlewareData:c}=t,a=await su(t,e);return s===((n=c.offset)==null?void 0:n.placement)&&(r=c.arrow)!=null&&r.alignmentOffset?{}:{x:o+a.x,y:i+a.y,data:{...a,placement:s}}}}},au=function(e){return e===void 0&&(e={}),{name:"shift",options:e,async fn(t){const{x:n,y:r,placement:o}=t,{mainAxis:i=!0,crossAxis:s=!1,limiter:c={fn:g=>{let{x,y}=g;return{x,y}}},...a}=Ee(e,t),u={x:n,y:r},l=await ht(t,a),d=we(Ce(o)),m=tr(d);let h=u[m],w=u[d];if(i){const g=m==="y"?"top":"left",x=m==="y"?"bottom":"right",y=h+l[g],b=h-l[x];h=Nn(y,h,b)}if(s){const g=d==="y"?"top":"left",x=d==="y"?"bottom":"right",y=w+l[g],b=w-l[x];w=Nn(y,w,b)}const p=c.fn({...t,[m]:h,[d]:w});return{...p,data:{x:p.x-n,y:p.y-r,enabled:{[m]:i,[d]:s}}}}}},uu=function(e){return e===void 0&&(e={}),{options:e,fn(t){const{x:n,y:r,placement:o,rects:i,middlewareData:s}=t,{offset:c=0,mainAxis:a=!0,crossAxis:u=!0}=Ee(e,t),l={x:n,y:r},d=we(o),m=tr(d);let h=l[m],w=l[d];const p=Ee(c,t),g=typeof p=="number"?{mainAxis:p,crossAxis:0}:{mainAxis:0,crossAxis:0,...p};if(a){const b=m==="y"?"height":"width",E=i.reference[m]-i.floating[b]+g.mainAxis,C=i.reference[m]+i.reference[b]-g.mainAxis;h<E?h=E:h>C&&(h=C)}if(u){var x,y;const b=m==="y"?"width":"height",E=yo.has(Ce(o)),C=i.reference[d]-i.floating[b]+(E&&((x=s.offset)==null?void 0:x[d])||0)+(E?0:g.crossAxis),A=i.reference[d]+i.reference[b]+(E?0:((y=s.offset)==null?void 0:y[d])||0)-(E?g.crossAxis:0);w<C?w=C:w>A&&(w=A)}return{[m]:h,[d]:w}}}},lu=function(e){return e===void 0&&(e={}),{name:"size",options:e,async fn(t){var n,r;const{placement:o,rects:i,platform:s,elements:c}=t,{apply:a=()=>{},...u}=Ee(e,t),l=await ht(t,u),d=Ce(o),m=rt(o),h=we(o)==="y",{width:w,height:p}=i.floating;let g,x;d==="top"||d==="bottom"?(g=d,x=m===(await(s.isRTL==null?void 0:s.isRTL(c.floating))?"start":"end")?"left":"right"):(x=d,g=m==="end"?"top":"bottom");const y=p-l.top-l.bottom,b=w-l.left-l.right,E=Ie(p-l[g],y),C=Ie(w-l[x],b),A=!t.middlewareData.shift;let z=E,k=C;if((n=t.middlewareData.shift)!=null&&n.enabled.x&&(k=b),(r=t.middlewareData.shift)!=null&&r.enabled.y&&(z=y),A&&!m){const Z=ie(l.left,0),L=ie(l.right,0),U=ie(l.top,0),M=ie(l.bottom,0);h?k=w-2*(Z!==0||L!==0?Z+L:ie(l.left,l.right)):z=p-2*(U!==0||M!==0?U+M:ie(l.top,l.bottom))}await a({...t,availableWidth:k,availableHeight:z});const D=await s.getDimensions(c.floating);return w!==D.width||p!==D.height?{reset:{rects:!0}}:{}}}};function tn(){return typeof window<"u"}function ot(e){return _o(e)?(e.nodeName||"").toLowerCase():"#document"}function se(e){var t;return(e==null||(t=e.ownerDocument)==null?void 0:t.defaultView)||window}function _e(e){var t;return(t=(_o(e)?e.ownerDocument:e.document)||window.document)==null?void 0:t.documentElement}function _o(e){return tn()?e instanceof Node||e instanceof se(e).Node:!1}function de(e){return tn()?e instanceof Element||e instanceof se(e).Element:!1}function ye(e){return tn()?e instanceof HTMLElement||e instanceof se(e).HTMLElement:!1}function Ir(e){return!tn()||typeof ShadowRoot>"u"?!1:e instanceof ShadowRoot||e instanceof se(e).ShadowRoot}const fu=new Set(["inline","contents"]);function bt(e){const{overflow:t,overflowX:n,overflowY:r,display:o}=pe(e);return/auto|scroll|overlay|hidden|clip/.test(t+r+n)&&!fu.has(o)}const du=new Set(["table","td","th"]);function pu(e){return du.has(ot(e))}const hu=[":popover-open",":modal"];function nn(e){return hu.some(t=>{try{return e.matches(t)}catch{return!1}})}const mu=["transform","translate","scale","rotate","perspective"],vu=["transform","translate","scale","rotate","perspective","filter"],gu=["paint","layout","strict","content"];function or(e){const t=ir(),n=de(e)?pe(e):e;return mu.some(r=>n[r]?n[r]!=="none":!1)||(n.containerType?n.containerType!=="normal":!1)||!t&&(n.backdropFilter?n.backdropFilter!=="none":!1)||!t&&(n.filter?n.filter!=="none":!1)||vu.some(r=>(n.willChange||"").includes(r))||gu.some(r=>(n.contain||"").includes(r))}function wu(e){let t=Re(e);for(;ye(t)&&!Qe(t);){if(or(t))return t;if(nn(t))return null;t=Re(t)}return null}function ir(){return typeof CSS>"u"||!CSS.supports?!1:CSS.supports("-webkit-backdrop-filter","none")}const bu=new Set(["html","body","#document"]);function Qe(e){return bu.has(ot(e))}function pe(e){return se(e).getComputedStyle(e)}function rn(e){return de(e)?{scrollLeft:e.scrollLeft,scrollTop:e.scrollTop}:{scrollLeft:e.scrollX,scrollTop:e.scrollY}}function Re(e){if(ot(e)==="html")return e;const t=e.assignedSlot||e.parentNode||Ir(e)&&e.host||_e(e);return Ir(t)?t.host:t}function xo(e){const t=Re(e);return Qe(t)?e.ownerDocument?e.ownerDocument.body:e.body:ye(t)&&bt(t)?t:xo(t)}function mt(e,t,n){var r;t===void 0&&(t=[]),n===void 0&&(n=!0);const o=xo(e),i=o===((r=e.ownerDocument)==null?void 0:r.body),s=se(o);if(i){const c=On(s);return t.concat(s,s.visualViewport||[],bt(o)?o:[],c&&n?mt(c):[])}return t.concat(o,mt(o,[],n))}function On(e){return e.parent&&Object.getPrototypeOf(e.parent)?e.frameElement:null}function So(e){const t=pe(e);let n=parseFloat(t.width)||0,r=parseFloat(t.height)||0;const o=ye(e),i=o?e.offsetWidth:n,s=o?e.offsetHeight:r,c=Ft(n)!==i||Ft(r)!==s;return c&&(n=i,r=s),{width:n,height:r,$:c}}function sr(e){return de(e)?e:e.contextElement}function Xe(e){const t=sr(e);if(!ye(t))return be(1);const n=t.getBoundingClientRect(),{width:r,height:o,$:i}=So(t);let s=(i?Ft(n.width):n.width)/r,c=(i?Ft(n.height):n.height)/o;return(!s||!Number.isFinite(s))&&(s=1),(!c||!Number.isFinite(c))&&(c=1),{x:s,y:c}}const yu=be(0);function Eo(e){const t=se(e);return!ir()||!t.visualViewport?yu:{x:t.visualViewport.offsetLeft,y:t.visualViewport.offsetTop}}function _u(e,t,n){return t===void 0&&(t=!1),!n||t&&n!==se(e)?!1:t}function Fe(e,t,n,r){t===void 0&&(t=!1),n===void 0&&(n=!1);const o=e.getBoundingClientRect(),i=sr(e);let s=be(1);t&&(r?de(r)&&(s=Xe(r)):s=Xe(e));const c=_u(i,n,r)?Eo(i):be(0);let a=(o.left+c.x)/s.x,u=(o.top+c.y)/s.y,l=o.width/s.x,d=o.height/s.y;if(i){const m=se(i),h=r&&de(r)?se(r):r;let w=m,p=On(w);for(;p&&r&&h!==w;){const g=Xe(p),x=p.getBoundingClientRect(),y=pe(p),b=x.left+(p.clientLeft+parseFloat(y.paddingLeft))*g.x,E=x.top+(p.clientTop+parseFloat(y.paddingTop))*g.y;a*=g.x,u*=g.y,l*=g.x,d*=g.y,a+=b,u+=E,w=se(p),p=On(w)}}return Ut({width:l,height:d,x:a,y:u})}function on(e,t){const n=rn(e).scrollLeft;return t?t.left+n:Fe(_e(e)).left+n}function Co(e,t){const n=e.getBoundingClientRect(),r=n.left+t.scrollLeft-on(e,n),o=n.top+t.scrollTop;return{x:r,y:o}}function xu(e){let{elements:t,rect:n,offsetParent:r,strategy:o}=e;const i=o==="fixed",s=_e(r),c=t?nn(t.floating):!1;if(r===s||c&&i)return n;let a={scrollLeft:0,scrollTop:0},u=be(1);const l=be(0),d=ye(r);if((d||!d&&!i)&&((ot(r)!=="body"||bt(s))&&(a=rn(r)),ye(r))){const h=Fe(r);u=Xe(r),l.x=h.x+r.clientLeft,l.y=h.y+r.clientTop}const m=s&&!d&&!i?Co(s,a):be(0);return{width:n.width*u.x,height:n.height*u.y,x:n.x*u.x-a.scrollLeft*u.x+l.x+m.x,y:n.y*u.y-a.scrollTop*u.y+l.y+m.y}}function Su(e){return Array.from(e.getClientRects())}function Eu(e){const t=_e(e),n=rn(e),r=e.ownerDocument.body,o=ie(t.scrollWidth,t.clientWidth,r.scrollWidth,r.clientWidth),i=ie(t.scrollHeight,t.clientHeight,r.scrollHeight,r.clientHeight);let s=-n.scrollLeft+on(e);const c=-n.scrollTop;return pe(r).direction==="rtl"&&(s+=ie(t.clientWidth,r.clientWidth)-o),{width:o,height:i,x:s,y:c}}const Rr=25;function Cu(e,t){const n=se(e),r=_e(e),o=n.visualViewport;let i=r.clientWidth,s=r.clientHeight,c=0,a=0;if(o){i=o.width,s=o.height;const l=ir();(!l||l&&t==="fixed")&&(c=o.offsetLeft,a=o.offsetTop)}const u=on(r);if(u<=0){const l=r.ownerDocument,d=l.body,m=getComputedStyle(d),h=l.compatMode==="CSS1Compat"&&parseFloat(m.marginLeft)+parseFloat(m.marginRight)||0,w=Math.abs(r.clientWidth-d.clientWidth-h);w<=Rr&&(i-=w)}else u<=Rr&&(i+=u);return{width:i,height:s,x:c,y:a}}const zu=new Set(["absolute","fixed"]);function ku(e,t){const n=Fe(e,!0,t==="fixed"),r=n.top+e.clientTop,o=n.left+e.clientLeft,i=ye(e)?Xe(e):be(1),s=e.clientWidth*i.x,c=e.clientHeight*i.y,a=o*i.x,u=r*i.y;return{width:s,height:c,x:a,y:u}}function Nr(e,t,n){let r;if(t==="viewport")r=Cu(e,n);else if(t==="document")r=Eu(_e(e));else if(de(t))r=ku(t,n);else{const o=Eo(e);r={x:t.x-o.x,y:t.y-o.y,width:t.width,height:t.height}}return Ut(r)}function zo(e,t){const n=Re(e);return n===t||!de(n)||Qe(n)?!1:pe(n).position==="fixed"||zo(n,t)}function Au(e,t){const n=t.get(e);if(n)return n;let r=mt(e,[],!1).filter(c=>de(c)&&ot(c)!=="body"),o=null;const i=pe(e).position==="fixed";let s=i?Re(e):e;for(;de(s)&&!Qe(s);){const c=pe(s),a=or(s);!a&&c.position==="fixed"&&(o=null),(i?!a&&!o:!a&&c.position==="static"&&!!o&&zu.has(o.position)||bt(s)&&!a&&zo(e,s))?r=r.filter(l=>l!==s):o=c,s=Re(s)}return t.set(e,r),r}function $u(e){let{element:t,boundary:n,rootBoundary:r,strategy:o}=e;const s=[...n==="clippingAncestors"?nn(t)?[]:Au(t,this._c):[].concat(n),r],c=s[0],a=s.reduce((u,l)=>{const d=Nr(t,l,o);return u.top=ie(d.top,u.top),u.right=Ie(d.right,u.right),u.bottom=Ie(d.bottom,u.bottom),u.left=ie(d.left,u.left),u},Nr(t,c,o));return{width:a.right-a.left,height:a.bottom-a.top,x:a.left,y:a.top}}function Pu(e){const{width:t,height:n}=So(e);return{width:t,height:n}}function Tu(e,t,n){const r=ye(t),o=_e(t),i=n==="fixed",s=Fe(e,!0,i,t);let c={scrollLeft:0,scrollTop:0};const a=be(0);function u(){a.x=on(o)}if(r||!r&&!i)if((ot(t)!=="body"||bt(o))&&(c=rn(t)),r){const h=Fe(t,!0,i,t);a.x=h.x+t.clientLeft,a.y=h.y+t.clientTop}else o&&u();i&&!r&&o&&u();const l=o&&!r&&!i?Co(o,c):be(0),d=s.left+c.scrollLeft-a.x-l.x,m=s.top+c.scrollTop-a.y-l.y;return{x:d,y:m,width:s.width,height:s.height}}function Cn(e){return pe(e).position==="static"}function Zr(e,t){if(!ye(e)||pe(e).position==="fixed")return null;if(t)return t(e);let n=e.offsetParent;return _e(e)===n&&(n=n.ownerDocument.body),n}function ko(e,t){const n=se(e);if(nn(e))return n;if(!ye(e)){let o=Re(e);for(;o&&!Qe(o);){if(de(o)&&!Cn(o))return o;o=Re(o)}return n}let r=Zr(e,t);for(;r&&pu(r)&&Cn(r);)r=Zr(r,t);return r&&Qe(r)&&Cn(r)&&!or(r)?n:r||wu(e)||n}const Iu=async function(e){const t=this.getOffsetParent||ko,n=this.getDimensions,r=await n(e.floating);return{reference:Tu(e.reference,await t(e.floating),e.strategy),floating:{x:0,y:0,width:r.width,height:r.height}}};function Ru(e){return pe(e).direction==="rtl"}const Nu={convertOffsetParentRelativeRectToViewportRelativeRect:xu,getDocumentElement:_e,getClippingRect:$u,getOffsetParent:ko,getElementRects:Iu,getClientRects:Su,getDimensions:Pu,getScale:Xe,isElement:de,isRTL:Ru};function Ao(e,t){return e.x===t.x&&e.y===t.y&&e.width===t.width&&e.height===t.height}function Zu(e,t){let n=null,r;const o=_e(e);function i(){var c;clearTimeout(r),(c=n)==null||c.disconnect(),n=null}function s(c,a){c===void 0&&(c=!1),a===void 0&&(a=1),i();const u=e.getBoundingClientRect(),{left:l,top:d,width:m,height:h}=u;if(c||t(),!m||!h)return;const w=kt(d),p=kt(o.clientWidth-(l+m)),g=kt(o.clientHeight-(d+h)),x=kt(l),b={rootMargin:-w+"px "+-p+"px "+-g+"px "+-x+"px",threshold:ie(0,Ie(1,a))||1};let E=!0;function C(A){const z=A[0].intersectionRatio;if(z!==a){if(!E)return s();z?s(!1,z):r=setTimeout(()=>{s(!1,1e-7)},1e3)}z===1&&!Ao(u,e.getBoundingClientRect())&&s(),E=!1}try{n=new IntersectionObserver(C,{...b,root:o.ownerDocument})}catch{n=new IntersectionObserver(C,b)}n.observe(e)}return s(!0),i}function Ou(e,t,n,r){r===void 0&&(r={});const{ancestorScroll:o=!0,ancestorResize:i=!0,elementResize:s=typeof ResizeObserver=="function",layoutShift:c=typeof IntersectionObserver=="function",animationFrame:a=!1}=r,u=sr(e),l=o||i?[...u?mt(u):[],...mt(t)]:[];l.forEach(x=>{o&&x.addEventListener("scroll",n,{passive:!0}),i&&x.addEventListener("resize",n)});const d=u&&c?Zu(u,n):null;let m=-1,h=null;s&&(h=new ResizeObserver(x=>{let[y]=x;y&&y.target===u&&h&&(h.unobserve(t),cancelAnimationFrame(m),m=requestAnimationFrame(()=>{var b;(b=h)==null||b.observe(t)})),n()}),u&&!a&&h.observe(u),h.observe(t));let w,p=a?Fe(e):null;a&&g();function g(){const x=Fe(e);p&&!Ao(p,x)&&n(),p=x,w=requestAnimationFrame(g)}return n(),()=>{var x;l.forEach(y=>{o&&y.removeEventListener("scroll",n),i&&y.removeEventListener("resize",n)}),d==null||d(),(x=h)==null||x.disconnect(),h=null,a&&cancelAnimationFrame(w)}}const Du=cu,Mu=au,ju=ou,Lu=lu,Fu=iu,Or=ru,Bu=uu,Uu=(e,t,n)=>{const r=new Map,o={platform:Nu,...n},i={...o.platform,_c:r};return nu(e,t,{...o,platform:i})};var Vu=typeof document<"u",Wu=function(){},Mt=Vu?f.useLayoutEffect:Wu;function Vt(e,t){if(e===t)return!0;if(typeof e!=typeof t)return!1;if(typeof e=="function"&&e.toString()===t.toString())return!0;let n,r,o;if(e&&t&&typeof e=="object"){if(Array.isArray(e)){if(n=e.length,n!==t.length)return!1;for(r=n;r--!==0;)if(!Vt(e[r],t[r]))return!1;return!0}if(o=Object.keys(e),n=o.length,n!==Object.keys(t).length)return!1;for(r=n;r--!==0;)if(!{}.hasOwnProperty.call(t,o[r]))return!1;for(r=n;r--!==0;){const i=o[r];if(!(i==="_owner"&&e.$$typeof)&&!Vt(e[i],t[i]))return!1}return!0}return e!==e&&t!==t}function $o(e){return typeof window>"u"?1:(e.ownerDocument.defaultView||window).devicePixelRatio||1}function Dr(e,t){const n=$o(e);return Math.round(t*n)/n}function zn(e){const t=f.useRef(e);return Mt(()=>{t.current=e}),t}function Hu(e){e===void 0&&(e={});const{placement:t="bottom",strategy:n="absolute",middleware:r=[],platform:o,elements:{reference:i,floating:s}={},transform:c=!0,whileElementsMounted:a,open:u}=e,[l,d]=f.useState({x:0,y:0,strategy:n,placement:t,middlewareData:{},isPositioned:!1}),[m,h]=f.useState(r);Vt(m,r)||h(r);const[w,p]=f.useState(null),[g,x]=f.useState(null),y=f.useCallback($=>{$!==A.current&&(A.current=$,p($))},[]),b=f.useCallback($=>{$!==z.current&&(z.current=$,x($))},[]),E=i||w,C=s||g,A=f.useRef(null),z=f.useRef(null),k=f.useRef(l),D=a!=null,Z=zn(a),L=zn(o),U=zn(u),M=f.useCallback(()=>{if(!A.current||!z.current)return;const $={placement:t,strategy:n,middleware:m};L.current&&($.platform=L.current),Uu(A.current,z.current,$).then(K=>{const re={...K,isPositioned:U.current!==!1};O.current&&!Vt(k.current,re)&&(k.current=re,Jt.flushSync(()=>{d(re)}))})},[m,t,n,L,U]);Mt(()=>{u===!1&&k.current.isPositioned&&(k.current.isPositioned=!1,d($=>({...$,isPositioned:!1})))},[u]);const O=f.useRef(!1);Mt(()=>(O.current=!0,()=>{O.current=!1}),[]),Mt(()=>{if(E&&(A.current=E),C&&(z.current=C),E&&C){if(Z.current)return Z.current(E,C,M);M()}},[E,C,M,Z,D]);const H=f.useMemo(()=>({reference:A,floating:z,setReference:y,setFloating:b}),[y,b]),I=f.useMemo(()=>({reference:E,floating:C}),[E,C]),j=f.useMemo(()=>{const $={position:n,left:0,top:0};if(!I.floating)return $;const K=Dr(I.floating,l.x),re=Dr(I.floating,l.y);return c?{...$,transform:"translate("+K+"px, "+re+"px)",...$o(I.floating)>=1.5&&{willChange:"transform"}}:{position:n,left:K,top:re}},[n,c,I.floating,l.x,l.y]);return f.useMemo(()=>({...l,update:M,refs:H,elements:I,floatingStyles:j}),[l,M,H,I,j])}const Ku=e=>{function t(n){return{}.hasOwnProperty.call(n,"current")}return{name:"arrow",options:e,fn(n){const{element:r,padding:o}=typeof e=="function"?e(n):e;return r&&t(r)?r.current!=null?Or({element:r.current,padding:o}).fn(n):{}:r?Or({element:r,padding:o}).fn(n):{}}}},Gu=(e,t)=>({...Du(e),options:[e,t]}),Yu=(e,t)=>({...Mu(e),options:[e,t]}),Xu=(e,t)=>({...Bu(e),options:[e,t]}),qu=(e,t)=>({...ju(e),options:[e,t]}),Ju=(e,t)=>({...Lu(e),options:[e,t]}),Qu=(e,t)=>({...Fu(e),options:[e,t]}),el=(e,t)=>({...Ku(e),options:[e,t]});var tl="Arrow",Po=f.forwardRef((e,t)=>{const{children:n,width:r=10,height:o=5,...i}=e;return _.jsx(q.svg,{...i,ref:t,width:r,height:o,viewBox:"0 0 30 10",preserveAspectRatio:"none",children:e.asChild?n:_.jsx("polygon",{points:"0,0 30,0 15,10"})})});Po.displayName=tl;var nl=Po;function rl(e){const[t,n]=f.useState(void 0);return ne(()=>{if(e){n({width:e.offsetWidth,height:e.offsetHeight});const r=new ResizeObserver(o=>{if(!Array.isArray(o)||!o.length)return;const i=o[0];let s,c;if("borderBoxSize"in i){const a=i.borderBoxSize,u=Array.isArray(a)?a[0]:a;s=u.inlineSize,c=u.blockSize}else s=e.offsetWidth,c=e.offsetHeight;n({width:s,height:c})});return r.observe(e,{box:"border-box"}),()=>r.unobserve(e)}else n(void 0)},[e]),t}var cr="Popper",[To,Io]=Qt(cr),[ol,Ro]=To(cr),No=e=>{const{__scopePopper:t,children:n}=e,[r,o]=f.useState(null);return _.jsx(ol,{scope:t,anchor:r,onAnchorChange:o,children:n})};No.displayName=cr;var Zo="PopperAnchor",Oo=f.forwardRef((e,t)=>{const{__scopePopper:n,virtualRef:r,...o}=e,i=Ro(Zo,n),s=f.useRef(null),c=Q(t,s),a=f.useRef(null);return f.useEffect(()=>{const u=a.current;a.current=(r==null?void 0:r.current)||s.current,u!==a.current&&i.onAnchorChange(a.current)}),r?null:_.jsx(q.div,{...o,ref:c})});Oo.displayName=Zo;var ar="PopperContent",[il,sl]=To(ar),Do=f.forwardRef((e,t)=>{var P,G,te,V,F,B;const{__scopePopper:n,side:r="bottom",sideOffset:o=0,align:i="center",alignOffset:s=0,arrowPadding:c=0,avoidCollisions:a=!0,collisionBoundary:u=[],collisionPadding:l=0,sticky:d="partial",hideWhenDetached:m=!1,updatePositionStrategy:h="optimized",onPlaced:w,...p}=e,g=Ro(ar,n),[x,y]=f.useState(null),b=Q(t,oe=>y(oe)),[E,C]=f.useState(null),A=rl(E),z=(A==null?void 0:A.width)??0,k=(A==null?void 0:A.height)??0,D=r+(i!=="center"?"-"+i:""),Z=typeof l=="number"?l:{top:0,right:0,bottom:0,left:0,...l},L=Array.isArray(u)?u:[u],U=L.length>0,M={padding:Z,boundary:L.filter(al),altBoundary:U},{refs:O,floatingStyles:H,placement:I,isPositioned:j,middlewareData:$}=Hu({strategy:"fixed",placement:D,whileElementsMounted:(...oe)=>Ou(...oe,{animationFrame:h==="always"}),elements:{reference:g.anchor},middleware:[Gu({mainAxis:o+k,alignmentAxis:s}),a&&Yu({mainAxis:!0,crossAxis:!1,limiter:d==="partial"?Xu():void 0,...M}),a&&qu({...M}),Ju({...M,apply:({elements:oe,rects:me,availableWidth:at,availableHeight:ut})=>{const{width:lt,height:ia}=me.reference,zt=oe.floating.style;zt.setProperty("--radix-popper-available-width",`${at}px`),zt.setProperty("--radix-popper-available-height",`${ut}px`),zt.setProperty("--radix-popper-anchor-width",`${lt}px`),zt.setProperty("--radix-popper-anchor-height",`${ia}px`)}}),E&&el({element:E,padding:c}),ul({arrowWidth:z,arrowHeight:k}),m&&Qu({strategy:"referenceHidden",...M})]}),[K,re]=Lo(I),Se=Te(w);ne(()=>{j&&(Se==null||Se())},[j,Se]);const st=(P=$.arrow)==null?void 0:P.x,ct=(G=$.arrow)==null?void 0:G.y,ke=((te=$.arrow)==null?void 0:te.centerOffset)!==0,[He,Me]=f.useState();return ne(()=>{x&&Me(window.getComputedStyle(x).zIndex)},[x]),_.jsx("div",{ref:O.setFloating,"data-radix-popper-content-wrapper":"",style:{...H,transform:j?H.transform:"translate(0, -200%)",minWidth:"max-content",zIndex:He,"--radix-popper-transform-origin":[(V=$.transformOrigin)==null?void 0:V.x,(F=$.transformOrigin)==null?void 0:F.y].join(" "),...((B=$.hide)==null?void 0:B.referenceHidden)&&{visibility:"hidden",pointerEvents:"none"}},dir:e.dir,children:_.jsx(il,{scope:n,placedSide:K,onArrowChange:C,arrowX:st,arrowY:ct,shouldHideArrow:ke,children:_.jsx(q.div,{"data-side":K,"data-align":re,...p,ref:b,style:{...p.style,animation:j?void 0:"none"}})})})});Do.displayName=ar;var Mo="PopperArrow",cl={top:"bottom",right:"left",bottom:"top",left:"right"},jo=f.forwardRef(function(t,n){const{__scopePopper:r,...o}=t,i=sl(Mo,r),s=cl[i.placedSide];return _.jsx("span",{ref:i.onArrowChange,style:{position:"absolute",left:i.arrowX,top:i.arrowY,[s]:0,transformOrigin:{top:"",right:"0 0",bottom:"center 0",left:"100% 0"}[i.placedSide],transform:{top:"translateY(100%)",right:"translateY(50%) rotate(90deg) translateX(-50%)",bottom:"rotate(180deg)",left:"translateY(50%) rotate(-90deg) translateX(50%)"}[i.placedSide],visibility:i.shouldHideArrow?"hidden":void 0},children:_.jsx(nl,{...o,ref:n,style:{...o.style,display:"block"}})})});jo.displayName=Mo;function al(e){return e!==null}var ul=e=>({name:"transformOrigin",options:e,fn(t){var g,x,y;const{placement:n,rects:r,middlewareData:o}=t,s=((g=o.arrow)==null?void 0:g.centerOffset)!==0,c=s?0:e.arrowWidth,a=s?0:e.arrowHeight,[u,l]=Lo(n),d={start:"0%",center:"50%",end:"100%"}[l],m=(((x=o.arrow)==null?void 0:x.x)??0)+c/2,h=(((y=o.arrow)==null?void 0:y.y)??0)+a/2;let w="",p="";return u==="bottom"?(w=s?d:`${m}px`,p=`${-a}px`):u==="top"?(w=s?d:`${m}px`,p=`${r.floating.height+a}px`):u==="right"?(w=`${-a}px`,p=s?d:`${h}px`):u==="left"&&(w=`${r.floating.width+a}px`,p=s?d:`${h}px`),{data:{x:w,y:p}}}});function Lo(e){const[t,n="center"]=e.split("-");return[t,n]}var ll=No,fl=Oo,dl=Do,pl=jo,hl="Portal",Fo=f.forwardRef((e,t)=>{var c;const{container:n,...r}=e,[o,i]=f.useState(!1);ne(()=>i(!0),[]);const s=n||o&&((c=globalThis==null?void 0:globalThis.document)==null?void 0:c.body);return s?sa.createPortal(_.jsx(q.div,{...r,ref:t}),s):null});Fo.displayName=hl;function ml(e,t){return f.useReducer((n,r)=>t[n][r]??n,e)}var vl=e=>{const{present:t,children:n}=e,r=gl(t),o=typeof n=="function"?n({present:r.isPresent}):f.Children.only(n),i=Q(r.ref,wl(o));return typeof n=="function"||r.isPresent?f.cloneElement(o,{ref:i}):null};vl.displayName="Presence";function gl(e){const[t,n]=f.useState(),r=f.useRef(null),o=f.useRef(e),i=f.useRef("none"),s=e?"mounted":"unmounted",[c,a]=ml(s,{mounted:{UNMOUNT:"unmounted",ANIMATION_OUT:"unmountSuspended"},unmountSuspended:{MOUNT:"mounted",ANIMATION_END:"unmounted"},unmounted:{MOUNT:"mounted"}});return f.useEffect(()=>{const u=At(r.current);i.current=c==="mounted"?u:"none"},[c]),ne(()=>{const u=r.current,l=o.current;if(l!==e){const m=i.current,h=At(u);e?a("MOUNT"):h==="none"||(u==null?void 0:u.display)==="none"?a("UNMOUNT"):a(l&&m!==h?"ANIMATION_OUT":"UNMOUNT"),o.current=e}},[e,a]),ne(()=>{if(t){let u;const l=t.ownerDocument.defaultView??window,d=h=>{const p=At(r.current).includes(CSS.escape(h.animationName));if(h.target===t&&p&&(a("ANIMATION_END"),!o.current)){const g=t.style.animationFillMode;t.style.animationFillMode="forwards",u=l.setTimeout(()=>{t.style.animationFillMode==="forwards"&&(t.style.animationFillMode=g)})}},m=h=>{h.target===t&&(i.current=At(r.current))};return t.addEventListener("animationstart",m),t.addEventListener("animationcancel",d),t.addEventListener("animationend",d),()=>{l.clearTimeout(u),t.removeEventListener("animationstart",m),t.removeEventListener("animationcancel",d),t.removeEventListener("animationend",d)}}else a("ANIMATION_END")},[t,a]),{isPresent:["mounted","unmountSuspended"].includes(c),ref:f.useCallback(u=>{r.current=u?getComputedStyle(u):null,n(u)},[])}}function At(e){return(e==null?void 0:e.animationName)||"none"}function wl(e){var r,o;let t=(r=Object.getOwnPropertyDescriptor(e.props,"ref"))==null?void 0:r.get,n=t&&"isReactWarning"in t&&t.isReactWarning;return n?e.ref:(t=(o=Object.getOwnPropertyDescriptor(e,"ref"))==null?void 0:o.get,n=t&&"isReactWarning"in t&&t.isReactWarning,n?e.props.ref:e.props.ref||e.ref)}var kn="rovingFocusGroup.onEntryFocus",bl={bubbles:!1,cancelable:!0},yt="RovingFocusGroup",[Dn,Bo,yl]=fo(yt),[_l,kv]=Qt(yt,[yl]),[xl,Sl]=_l(yt),Uo=f.forwardRef((e,t)=>_.jsx(Dn.Provider,{scope:e.__scopeRovingFocusGroup,children:_.jsx(Dn.Slot,{scope:e.__scopeRovingFocusGroup,children:_.jsx(El,{...e,ref:t})})}));Uo.displayName=yt;var El=f.forwardRef((e,t)=>{const{__scopeRovingFocusGroup:n,orientation:r,loop:o=!1,dir:i,currentTabStopId:s,defaultCurrentTabStopId:c,onCurrentTabStopIdChange:a,onEntryFocus:u,preventScrollOnEntryFocus:l=!1,...d}=e,m=f.useRef(null),h=Q(t,m),w=po(i),[p,g]=In({prop:s,defaultProp:c??null,onChange:a,caller:yt}),[x,y]=f.useState(!1),b=Te(u),E=Bo(n),C=f.useRef(!1),[A,z]=f.useState(0);return f.useEffect(()=>{const k=m.current;if(k)return k.addEventListener(kn,b),()=>k.removeEventListener(kn,b)},[b]),_.jsx(xl,{scope:n,orientation:r,dir:w,loop:o,currentTabStopId:p,onItemFocus:f.useCallback(k=>g(k),[g]),onItemShiftTab:f.useCallback(()=>y(!0),[]),onFocusableItemAdd:f.useCallback(()=>z(k=>k+1),[]),onFocusableItemRemove:f.useCallback(()=>z(k=>k-1),[]),children:_.jsx(q.div,{tabIndex:x||A===0?-1:0,"data-orientation":r,...d,ref:h,style:{outline:"none",...e.style},onMouseDown:W(e.onMouseDown,()=>{C.current=!0}),onFocus:W(e.onFocus,k=>{const D=!C.current;if(k.target===k.currentTarget&&D&&!x){const Z=new CustomEvent(kn,bl);if(k.currentTarget.dispatchEvent(Z),!Z.defaultPrevented){const L=E().filter(I=>I.focusable),U=L.find(I=>I.active),M=L.find(I=>I.id===p),H=[U,M,...L].filter(Boolean).map(I=>I.ref.current);Ho(H,l)}}C.current=!1}),onBlur:W(e.onBlur,()=>y(!1))})})}),Vo="RovingFocusGroupItem",Wo=f.forwardRef((e,t)=>{const{__scopeRovingFocusGroup:n,focusable:r=!0,active:o=!1,tabStopId:i,children:s,...c}=e,a=en(),u=i||a,l=Sl(Vo,n),d=l.currentTabStopId===u,m=Bo(n),{onFocusableItemAdd:h,onFocusableItemRemove:w,currentTabStopId:p}=l;return f.useEffect(()=>{if(r)return h(),()=>w()},[r,h,w]),_.jsx(Dn.ItemSlot,{scope:n,id:u,focusable:r,active:o,children:_.jsx(q.span,{tabIndex:d?0:-1,"data-orientation":l.orientation,...c,ref:t,onMouseDown:W(e.onMouseDown,g=>{r?l.onItemFocus(u):g.preventDefault()}),onFocus:W(e.onFocus,()=>l.onItemFocus(u)),onKeyDown:W(e.onKeyDown,g=>{if(g.key==="Tab"&&g.shiftKey){l.onItemShiftTab();return}if(g.target!==g.currentTarget)return;const x=kl(g,l.orientation,l.dir);if(x!==void 0){if(g.metaKey||g.ctrlKey||g.altKey||g.shiftKey)return;g.preventDefault();let b=m().filter(E=>E.focusable).map(E=>E.ref.current);if(x==="last")b.reverse();else if(x==="prev"||x==="next"){x==="prev"&&b.reverse();const E=b.indexOf(g.currentTarget);b=l.loop?Al(b,E+1):b.slice(E+1)}setTimeout(()=>Ho(b))}}),children:typeof s=="function"?s({isCurrentTabStop:d,hasTabStop:p!=null}):s})})});Wo.displayName=Vo;var Cl={ArrowLeft:"prev",ArrowUp:"prev",ArrowRight:"next",ArrowDown:"next",PageUp:"first",Home:"first",PageDown:"last",End:"last"};function zl(e,t){return t!=="rtl"?e:e==="ArrowLeft"?"ArrowRight":e==="ArrowRight"?"ArrowLeft":e}function kl(e,t,n){const r=zl(e.key,n);if(!(t==="vertical"&&["ArrowLeft","ArrowRight"].includes(r))&&!(t==="horizontal"&&["ArrowUp","ArrowDown"].includes(r)))return Cl[r]}function Ho(e,t=!1){const n=document.activeElement;for(const r of e)if(r===n||(r.focus({preventScroll:t}),document.activeElement!==n))return}function Al(e,t){return e.map((n,r)=>e[(t+r)%e.length])}var Av=Uo,$v=Wo,$l=function(e){if(typeof document>"u")return null;var t=Array.isArray(e)?e[0]:e;return t.ownerDocument.body},Ke=new WeakMap,$t=new WeakMap,Pt={},An=0,Ko=function(e){return e&&(e.host||Ko(e.parentNode))},Pl=function(e,t){return t.map(function(n){if(e.contains(n))return n;var r=Ko(n);return r&&e.contains(r)?r:(console.error("aria-hidden",n,"in not contained inside",e,". Doing nothing"),null)}).filter(function(n){return!!n})},Tl=function(e,t,n,r){var o=Pl(t,Array.isArray(e)?e:[e]);Pt[n]||(Pt[n]=new WeakMap);var i=Pt[n],s=[],c=new Set,a=new Set(o),u=function(d){!d||c.has(d)||(c.add(d),u(d.parentNode))};o.forEach(u);var l=function(d){!d||a.has(d)||Array.prototype.forEach.call(d.children,function(m){if(c.has(m))l(m);else try{var h=m.getAttribute(r),w=h!==null&&h!=="false",p=(Ke.get(m)||0)+1,g=(i.get(m)||0)+1;Ke.set(m,p),i.set(m,g),s.push(m),p===1&&w&&$t.set(m,!0),g===1&&m.setAttribute(n,"true"),w||m.setAttribute(r,"true")}catch(x){console.error("aria-hidden: cannot operate on ",m,x)}})};return l(t),c.clear(),An++,function(){s.forEach(function(d){var m=Ke.get(d)-1,h=i.get(d)-1;Ke.set(d,m),i.set(d,h),m||($t.has(d)||d.removeAttribute(r),$t.delete(d)),h||d.removeAttribute(n)}),An--,An||(Ke=new WeakMap,Ke=new WeakMap,$t=new WeakMap,Pt={})}},Il=function(e,t,n){n===void 0&&(n="data-aria-hidden");var r=Array.from(Array.isArray(e)?e:[e]),o=$l(e);return o?(r.push.apply(r,Array.from(o.querySelectorAll("[aria-live], script"))),Tl(r,o,n,"aria-hidden")):function(){return null}},ve=function(){return ve=Object.assign||function(t){for(var n,r=1,o=arguments.length;r<o;r++){n=arguments[r];for(var i in n)Object.prototype.hasOwnProperty.call(n,i)&&(t[i]=n[i])}return t},ve.apply(this,arguments)};function Go(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n}function Rl(e,t,n){if(n||arguments.length===2)for(var r=0,o=t.length,i;r<o;r++)(i||!(r in t))&&(i||(i=Array.prototype.slice.call(t,0,r)),i[r]=t[r]);return e.concat(i||Array.prototype.slice.call(t))}var jt="right-scroll-bar-position",Lt="width-before-scroll-bar",Nl="with-scroll-bars-hidden",Zl="--removed-body-scroll-bar-size";function $n(e,t){return typeof e=="function"?e(t):e&&(e.current=t),e}function Ol(e,t){var n=f.useState(function(){return{value:e,callback:t,facade:{get current(){return n.value},set current(r){var o=n.value;o!==r&&(n.value=r,n.callback(r,o))}}}})[0];return n.callback=t,n.facade}var Dl=typeof window<"u"?f.useLayoutEffect:f.useEffect,Mr=new WeakMap;function Ml(e,t){var n=Ol(null,function(r){return e.forEach(function(o){return $n(o,r)})});return Dl(function(){var r=Mr.get(n);if(r){var o=new Set(r),i=new Set(e),s=n.current;o.forEach(function(c){i.has(c)||$n(c,null)}),i.forEach(function(c){o.has(c)||$n(c,s)})}Mr.set(n,e)},[e]),n}function jl(e){return e}function Ll(e,t){t===void 0&&(t=jl);var n=[],r=!1,o={read:function(){if(r)throw new Error("Sidecar: could not `read` from an `assigned` medium. `read` could be used only with `useMedium`.");return n.length?n[n.length-1]:e},useMedium:function(i){var s=t(i,r);return n.push(s),function(){n=n.filter(function(c){return c!==s})}},assignSyncMedium:function(i){for(r=!0;n.length;){var s=n;n=[],s.forEach(i)}n={push:function(c){return i(c)},filter:function(){return n}}},assignMedium:function(i){r=!0;var s=[];if(n.length){var c=n;n=[],c.forEach(i),s=n}var a=function(){var l=s;s=[],l.forEach(i)},u=function(){return Promise.resolve().then(a)};u(),n={push:function(l){s.push(l),u()},filter:function(l){return s=s.filter(l),n}}}};return o}function Fl(e){e===void 0&&(e={});var t=Ll(null);return t.options=ve({async:!0,ssr:!1},e),t}var Yo=function(e){var t=e.sideCar,n=Go(e,["sideCar"]);if(!t)throw new Error("Sidecar: please provide `sideCar` property to import the right car");var r=t.read();if(!r)throw new Error("Sidecar medium not found");return f.createElement(r,ve({},n))};Yo.isSideCarExport=!0;function Bl(e,t){return e.useMedium(t),Yo}var Xo=Fl(),Pn=function(){},sn=f.forwardRef(function(e,t){var n=f.useRef(null),r=f.useState({onScrollCapture:Pn,onWheelCapture:Pn,onTouchMoveCapture:Pn}),o=r[0],i=r[1],s=e.forwardProps,c=e.children,a=e.className,u=e.removeScrollBar,l=e.enabled,d=e.shards,m=e.sideCar,h=e.noRelative,w=e.noIsolation,p=e.inert,g=e.allowPinchZoom,x=e.as,y=x===void 0?"div":x,b=e.gapMode,E=Go(e,["forwardProps","children","className","removeScrollBar","enabled","shards","sideCar","noRelative","noIsolation","inert","allowPinchZoom","as","gapMode"]),C=m,A=Ml([n,t]),z=ve(ve({},E),o);return f.createElement(f.Fragment,null,l&&f.createElement(C,{sideCar:Xo,removeScrollBar:u,shards:d,noRelative:h,noIsolation:w,inert:p,setCallbacks:i,allowPinchZoom:!!g,lockRef:n,gapMode:b}),s?f.cloneElement(f.Children.only(c),ve(ve({},z),{ref:A})):f.createElement(y,ve({},z,{className:a,ref:A}),c))});sn.defaultProps={enabled:!0,removeScrollBar:!0,inert:!1};sn.classNames={fullWidth:Lt,zeroRight:jt};var Ul=function(){if(typeof __webpack_nonce__<"u")return __webpack_nonce__};function Vl(){if(!document)return null;var e=document.createElement("style");e.type="text/css";var t=Ul();return t&&e.setAttribute("nonce",t),e}function Wl(e,t){e.styleSheet?e.styleSheet.cssText=t:e.appendChild(document.createTextNode(t))}function Hl(e){var t=document.head||document.getElementsByTagName("head")[0];t.appendChild(e)}var Kl=function(){var e=0,t=null;return{add:function(n){e==0&&(t=Vl())&&(Wl(t,n),Hl(t)),e++},remove:function(){e--,!e&&t&&(t.parentNode&&t.parentNode.removeChild(t),t=null)}}},Gl=function(){var e=Kl();return function(t,n){f.useEffect(function(){return e.add(t),function(){e.remove()}},[t&&n])}},qo=function(){var e=Gl(),t=function(n){var r=n.styles,o=n.dynamic;return e(r,o),null};return t},Yl={left:0,top:0,right:0,gap:0},Tn=function(e){return parseInt(e||"",10)||0},Xl=function(e){var t=window.getComputedStyle(document.body),n=t[e==="padding"?"paddingLeft":"marginLeft"],r=t[e==="padding"?"paddingTop":"marginTop"],o=t[e==="padding"?"paddingRight":"marginRight"];return[Tn(n),Tn(r),Tn(o)]},ql=function(e){if(e===void 0&&(e="margin"),typeof window>"u")return Yl;var t=Xl(e),n=document.documentElement.clientWidth,r=window.innerWidth;return{left:t[0],top:t[1],right:t[2],gap:Math.max(0,r-n+t[2]-t[0])}},Jl=qo(),qe="data-scroll-locked",Ql=function(e,t,n,r){var o=e.left,i=e.top,s=e.right,c=e.gap;return n===void 0&&(n="margin"),`
  .`.concat(Nl,` {
   overflow: hidden `).concat(r,`;
   padding-right: `).concat(c,"px ").concat(r,`;
  }
  body[`).concat(qe,`] {
    overflow: hidden `).concat(r,`;
    overscroll-behavior: contain;
    `).concat([t&&"position: relative ".concat(r,";"),n==="margin"&&`
    padding-left: `.concat(o,`px;
    padding-top: `).concat(i,`px;
    padding-right: `).concat(s,`px;
    margin-left:0;
    margin-top:0;
    margin-right: `).concat(c,"px ").concat(r,`;
    `),n==="padding"&&"padding-right: ".concat(c,"px ").concat(r,";")].filter(Boolean).join(""),`
  }
  
  .`).concat(jt,` {
    right: `).concat(c,"px ").concat(r,`;
  }
  
  .`).concat(Lt,` {
    margin-right: `).concat(c,"px ").concat(r,`;
  }
  
  .`).concat(jt," .").concat(jt,` {
    right: 0 `).concat(r,`;
  }
  
  .`).concat(Lt," .").concat(Lt,` {
    margin-right: 0 `).concat(r,`;
  }
  
  body[`).concat(qe,`] {
    `).concat(Zl,": ").concat(c,`px;
  }
`)},jr=function(){var e=parseInt(document.body.getAttribute(qe)||"0",10);return isFinite(e)?e:0},ef=function(){f.useEffect(function(){return document.body.setAttribute(qe,(jr()+1).toString()),function(){var e=jr()-1;e<=0?document.body.removeAttribute(qe):document.body.setAttribute(qe,e.toString())}},[])},tf=function(e){var t=e.noRelative,n=e.noImportant,r=e.gapMode,o=r===void 0?"margin":r;ef();var i=f.useMemo(function(){return ql(o)},[o]);return f.createElement(Jl,{styles:Ql(i,!t,o,n?"":"!important")})},Mn=!1;if(typeof window<"u")try{var Tt=Object.defineProperty({},"passive",{get:function(){return Mn=!0,!0}});window.addEventListener("test",Tt,Tt),window.removeEventListener("test",Tt,Tt)}catch{Mn=!1}var Ge=Mn?{passive:!1}:!1,nf=function(e){return e.tagName==="TEXTAREA"},Jo=function(e,t){if(!(e instanceof Element))return!1;var n=window.getComputedStyle(e);return n[t]!=="hidden"&&!(n.overflowY===n.overflowX&&!nf(e)&&n[t]==="visible")},rf=function(e){return Jo(e,"overflowY")},of=function(e){return Jo(e,"overflowX")},Lr=function(e,t){var n=t.ownerDocument,r=t;do{typeof ShadowRoot<"u"&&r instanceof ShadowRoot&&(r=r.host);var o=Qo(e,r);if(o){var i=ei(e,r),s=i[1],c=i[2];if(s>c)return!0}r=r.parentNode}while(r&&r!==n.body);return!1},sf=function(e){var t=e.scrollTop,n=e.scrollHeight,r=e.clientHeight;return[t,n,r]},cf=function(e){var t=e.scrollLeft,n=e.scrollWidth,r=e.clientWidth;return[t,n,r]},Qo=function(e,t){return e==="v"?rf(t):of(t)},ei=function(e,t){return e==="v"?sf(t):cf(t)},af=function(e,t){return e==="h"&&t==="rtl"?-1:1},uf=function(e,t,n,r,o){var i=af(e,window.getComputedStyle(t).direction),s=i*r,c=n.target,a=t.contains(c),u=!1,l=s>0,d=0,m=0;do{if(!c)break;var h=ei(e,c),w=h[0],p=h[1],g=h[2],x=p-g-i*w;(w||x)&&Qo(e,c)&&(d+=x,m+=w);var y=c.parentNode;c=y&&y.nodeType===Node.DOCUMENT_FRAGMENT_NODE?y.host:y}while(!a&&c!==document.body||a&&(t.contains(c)||t===c));return(l&&Math.abs(d)<1||!l&&Math.abs(m)<1)&&(u=!0),u},It=function(e){return"changedTouches"in e?[e.changedTouches[0].clientX,e.changedTouches[0].clientY]:[0,0]},Fr=function(e){return[e.deltaX,e.deltaY]},Br=function(e){return e&&"current"in e?e.current:e},lf=function(e,t){return e[0]===t[0]&&e[1]===t[1]},ff=function(e){return`
  .block-interactivity-`.concat(e,` {pointer-events: none;}
  .allow-interactivity-`).concat(e,` {pointer-events: all;}
`)},df=0,Ye=[];function pf(e){var t=f.useRef([]),n=f.useRef([0,0]),r=f.useRef(),o=f.useState(df++)[0],i=f.useState(qo)[0],s=f.useRef(e);f.useEffect(function(){s.current=e},[e]),f.useEffect(function(){if(e.inert){document.body.classList.add("block-interactivity-".concat(o));var p=Rl([e.lockRef.current],(e.shards||[]).map(Br),!0).filter(Boolean);return p.forEach(function(g){return g.classList.add("allow-interactivity-".concat(o))}),function(){document.body.classList.remove("block-interactivity-".concat(o)),p.forEach(function(g){return g.classList.remove("allow-interactivity-".concat(o))})}}},[e.inert,e.lockRef.current,e.shards]);var c=f.useCallback(function(p,g){if("touches"in p&&p.touches.length===2||p.type==="wheel"&&p.ctrlKey)return!s.current.allowPinchZoom;var x=It(p),y=n.current,b="deltaX"in p?p.deltaX:y[0]-x[0],E="deltaY"in p?p.deltaY:y[1]-x[1],C,A=p.target,z=Math.abs(b)>Math.abs(E)?"h":"v";if("touches"in p&&z==="h"&&A.type==="range")return!1;var k=Lr(z,A);if(!k)return!0;if(k?C=z:(C=z==="v"?"h":"v",k=Lr(z,A)),!k)return!1;if(!r.current&&"changedTouches"in p&&(b||E)&&(r.current=C),!C)return!0;var D=r.current||C;return uf(D,g,p,D==="h"?b:E)},[]),a=f.useCallback(function(p){var g=p;if(!(!Ye.length||Ye[Ye.length-1]!==i)){var x="deltaY"in g?Fr(g):It(g),y=t.current.filter(function(C){return C.name===g.type&&(C.target===g.target||g.target===C.shadowParent)&&lf(C.delta,x)})[0];if(y&&y.should){g.cancelable&&g.preventDefault();return}if(!y){var b=(s.current.shards||[]).map(Br).filter(Boolean).filter(function(C){return C.contains(g.target)}),E=b.length>0?c(g,b[0]):!s.current.noIsolation;E&&g.cancelable&&g.preventDefault()}}},[]),u=f.useCallback(function(p,g,x,y){var b={name:p,delta:g,target:x,should:y,shadowParent:hf(x)};t.current.push(b),setTimeout(function(){t.current=t.current.filter(function(E){return E!==b})},1)},[]),l=f.useCallback(function(p){n.current=It(p),r.current=void 0},[]),d=f.useCallback(function(p){u(p.type,Fr(p),p.target,c(p,e.lockRef.current))},[]),m=f.useCallback(function(p){u(p.type,It(p),p.target,c(p,e.lockRef.current))},[]);f.useEffect(function(){return Ye.push(i),e.setCallbacks({onScrollCapture:d,onWheelCapture:d,onTouchMoveCapture:m}),document.addEventListener("wheel",a,Ge),document.addEventListener("touchmove",a,Ge),document.addEventListener("touchstart",l,Ge),function(){Ye=Ye.filter(function(p){return p!==i}),document.removeEventListener("wheel",a,Ge),document.removeEventListener("touchmove",a,Ge),document.removeEventListener("touchstart",l,Ge)}},[]);var h=e.removeScrollBar,w=e.inert;return f.createElement(f.Fragment,null,w?f.createElement(i,{styles:ff(o)}):null,h?f.createElement(tf,{noRelative:e.noRelative,gapMode:e.gapMode}):null)}function hf(e){for(var t=null;e!==null;)e instanceof ShadowRoot&&(t=e.host,e=e.host),e=e.parentNode;return t}const mf=Bl(Xo,pf);var ti=f.forwardRef(function(e,t){return f.createElement(sn,ve({},e,{ref:t,sideCar:mf}))});ti.classNames=sn.classNames;function Pv({className:e,type:t,...n}){return _.jsx("input",{type:t,"data-slot":"input",className:ee("file:text-foreground placeholder:text-muted-foreground selection:bg-primary selection:text-primary-foreground dark:bg-input/30 border-input flex h-9 w-full min-w-0 rounded-md border bg-transparent px-3 py-1 text-base shadow-xs transition-[color,box-shadow] outline-none file:inline-flex file:h-7 file:border-0 file:bg-transparent file:text-sm file:font-medium disabled:pointer-events-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm","focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px]","aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive",e),...n})}const Tv=Object.freeze({status:"aborted"});function v(e,t,n){function r(c,a){var u;Object.defineProperty(c,"_zod",{value:c._zod??{},enumerable:!1}),(u=c._zod).traits??(u.traits=new Set),c._zod.traits.add(e),t(c,a);for(const l in s.prototype)l in c||Object.defineProperty(c,l,{value:s.prototype[l].bind(c)});c._zod.constr=s,c._zod.def=a}const o=(n==null?void 0:n.Parent)??Object;class i extends o{}Object.defineProperty(i,"name",{value:e});function s(c){var a;const u=n!=null&&n.Parent?new i:this;r(u,c),(a=u._zod).deferred??(a.deferred=[]);for(const l of u._zod.deferred)l();return u}return Object.defineProperty(s,"init",{value:r}),Object.defineProperty(s,Symbol.hasInstance,{value:c=>{var a,u;return n!=null&&n.Parent&&c instanceof n.Parent?!0:(u=(a=c==null?void 0:c._zod)==null?void 0:a.traits)==null?void 0:u.has(e)}}),Object.defineProperty(s,"name",{value:e}),s}const Iv=Symbol("zod_brand");class Je extends Error{constructor(){super("Encountered Promise during synchronous parse. Use .parseAsync() instead.")}}class ur extends Error{constructor(t){super(`Encountered unidirectional transform during encode: ${t}`),this.name="ZodEncodeError"}}const jn={};function ce(e){return e&&Object.assign(jn,e),jn}function vf(e){return e}function gf(e){return e}function wf(e){}function bf(e){throw new Error}function yf(e){}function ni(e){const t=Object.values(e).filter(r=>typeof r=="number");return Object.entries(e).filter(([r,o])=>t.indexOf(+r)===-1).map(([r,o])=>o)}function _f(e,t="|"){return e.map(n=>si(n)).join(t)}function Wt(e,t){return typeof t=="bigint"?t.toString():t}function _t(e){return{get value(){{const t=e();return Object.defineProperty(this,"value",{value:t}),t}}}}function We(e){return e==null}function cn(e){const t=e.startsWith("^")?1:0,n=e.endsWith("$")?e.length-1:e.length;return e.slice(t,n)}function ri(e,t){const n=(e.toString().split(".")[1]||"").length,r=t.toString();let o=(r.split(".")[1]||"").length;if(o===0&&/\d?e-\d?/.test(r)){const a=r.match(/\d?e-(\d?)/);a!=null&&a[1]&&(o=Number.parseInt(a[1]))}const i=n>o?n:o,s=Number.parseInt(e.toFixed(i).replace(".","")),c=Number.parseInt(t.toFixed(i).replace(".",""));return s%c/10**i}const Ur=Symbol("evaluating");function N(e,t,n){let r;Object.defineProperty(e,t,{get(){if(r!==Ur)return r===void 0&&(r=Ur,r=n()),r},set(o){Object.defineProperty(e,t,{value:o})},configurable:!0})}function xf(e){return Object.create(Object.getPrototypeOf(e),Object.getOwnPropertyDescriptors(e))}function Ze(e,t,n){Object.defineProperty(e,t,{value:n,writable:!0,enumerable:!0,configurable:!0})}function ze(...e){const t={};for(const n of e){const r=Object.getOwnPropertyDescriptors(n);Object.assign(t,r)}return Object.defineProperties({},t)}function Sf(e){return ze(e._zod.def)}function Ef(e,t){return t?t.reduce((n,r)=>n==null?void 0:n[r],e):e}function Cf(e){const t=Object.keys(e),n=t.map(r=>e[r]);return Promise.all(n).then(r=>{const o={};for(let i=0;i<t.length;i++)o[t[i]]=r[i];return o})}function zf(e=10){const t="abcdefghijklmnopqrstuvwxyz";let n="";for(let r=0;r<e;r++)n+=t[Math.floor(Math.random()*t.length)];return n}function Ln(e){return JSON.stringify(e)}const lr="captureStackTrace"in Error?Error.captureStackTrace:(...e)=>{};function et(e){return typeof e=="object"&&e!==null&&!Array.isArray(e)}const oi=_t(()=>{var e;if(typeof navigator<"u"&&((e=navigator==null?void 0:navigator.userAgent)!=null&&e.includes("Cloudflare")))return!1;try{const t=Function;return new t(""),!0}catch{return!1}});function Be(e){if(et(e)===!1)return!1;const t=e.constructor;if(t===void 0)return!0;const n=t.prototype;return!(et(n)===!1||Object.prototype.hasOwnProperty.call(n,"isPrototypeOf")===!1)}function an(e){return Be(e)?{...e}:Array.isArray(e)?[...e]:e}function kf(e){let t=0;for(const n in e)Object.prototype.hasOwnProperty.call(e,n)&&t++;return t}const Af=e=>{const t=typeof e;switch(t){case"undefined":return"undefined";case"string":return"string";case"number":return Number.isNaN(e)?"nan":"number";case"boolean":return"boolean";case"function":return"function";case"bigint":return"bigint";case"symbol":return"symbol";case"object":return Array.isArray(e)?"array":e===null?"null":e.then&&typeof e.then=="function"&&e.catch&&typeof e.catch=="function"?"promise":typeof Map<"u"&&e instanceof Map?"map":typeof Set<"u"&&e instanceof Set?"set":typeof Date<"u"&&e instanceof Date?"date":typeof File<"u"&&e instanceof File?"file":"object";default:throw new Error(`Unknown data type: ${t}`)}},Ht=new Set(["string","number","symbol"]),ii=new Set(["string","number","bigint","boolean","symbol","undefined"]);function Ne(e){return e.replace(/[.*+?^${}()|[\]\\]/g,"\\$&")}function xe(e,t,n){const r=new e._zod.constr(t??e._zod.def);return(!t||n!=null&&n.parent)&&(r._zod.parent=e),r}function S(e){const t=e;if(!t)return{};if(typeof t=="string")return{error:()=>t};if((t==null?void 0:t.message)!==void 0){if((t==null?void 0:t.error)!==void 0)throw new Error("Cannot specify both `message` and `error` params");t.error=t.message}return delete t.message,typeof t.error=="string"?{...t,error:()=>t.error}:t}function $f(e){let t;return new Proxy({},{get(n,r,o){return t??(t=e()),Reflect.get(t,r,o)},set(n,r,o,i){return t??(t=e()),Reflect.set(t,r,o,i)},has(n,r){return t??(t=e()),Reflect.has(t,r)},deleteProperty(n,r){return t??(t=e()),Reflect.deleteProperty(t,r)},ownKeys(n){return t??(t=e()),Reflect.ownKeys(t)},getOwnPropertyDescriptor(n,r){return t??(t=e()),Reflect.getOwnPropertyDescriptor(t,r)},defineProperty(n,r,o){return t??(t=e()),Reflect.defineProperty(t,r,o)}})}function si(e){return typeof e=="bigint"?e.toString()+"n":typeof e=="string"?`"${e}"`:`${e}`}function ci(e){return Object.keys(e).filter(t=>e[t]._zod.optin==="optional"&&e[t]._zod.optout==="optional")}const ai={safeint:[Number.MIN_SAFE_INTEGER,Number.MAX_SAFE_INTEGER],int32:[-2147483648,2147483647],uint32:[0,4294967295],float32:[-34028234663852886e22,34028234663852886e22],float64:[-Number.MAX_VALUE,Number.MAX_VALUE]},ui={int64:[BigInt("-9223372036854775808"),BigInt("9223372036854775807")],uint64:[BigInt(0),BigInt("18446744073709551615")]};function li(e,t){const n=e._zod.def,r=ze(e._zod.def,{get shape(){const o={};for(const i in t){if(!(i in n.shape))throw new Error(`Unrecognized key: "${i}"`);t[i]&&(o[i]=n.shape[i])}return Ze(this,"shape",o),o},checks:[]});return xe(e,r)}function fi(e,t){const n=e._zod.def,r=ze(e._zod.def,{get shape(){const o={...e._zod.def.shape};for(const i in t){if(!(i in n.shape))throw new Error(`Unrecognized key: "${i}"`);t[i]&&delete o[i]}return Ze(this,"shape",o),o},checks:[]});return xe(e,r)}function di(e,t){if(!Be(t))throw new Error("Invalid input to extend: expected a plain object");const n=e._zod.def.checks;if(n&&n.length>0)throw new Error("Object schemas containing refinements cannot be extended. Use `.safeExtend()` instead.");const o=ze(e._zod.def,{get shape(){const i={...e._zod.def.shape,...t};return Ze(this,"shape",i),i},checks:[]});return xe(e,o)}function pi(e,t){if(!Be(t))throw new Error("Invalid input to safeExtend: expected a plain object");const n={...e._zod.def,get shape(){const r={...e._zod.def.shape,...t};return Ze(this,"shape",r),r},checks:e._zod.def.checks};return xe(e,n)}function hi(e,t){const n=ze(e._zod.def,{get shape(){const r={...e._zod.def.shape,...t._zod.def.shape};return Ze(this,"shape",r),r},get catchall(){return t._zod.def.catchall},checks:[]});return xe(e,n)}function mi(e,t,n){const r=ze(t._zod.def,{get shape(){const o=t._zod.def.shape,i={...o};if(n)for(const s in n){if(!(s in o))throw new Error(`Unrecognized key: "${s}"`);n[s]&&(i[s]=e?new e({type:"optional",innerType:o[s]}):o[s])}else for(const s in o)i[s]=e?new e({type:"optional",innerType:o[s]}):o[s];return Ze(this,"shape",i),i},checks:[]});return xe(t,r)}function vi(e,t,n){const r=ze(t._zod.def,{get shape(){const o=t._zod.def.shape,i={...o};if(n)for(const s in n){if(!(s in i))throw new Error(`Unrecognized key: "${s}"`);n[s]&&(i[s]=new e({type:"nonoptional",innerType:o[s]}))}else for(const s in o)i[s]=new e({type:"nonoptional",innerType:o[s]});return Ze(this,"shape",i),i},checks:[]});return xe(t,r)}function Le(e,t=0){var n;if(e.aborted===!0)return!0;for(let r=t;r<e.issues.length;r++)if(((n=e.issues[r])==null?void 0:n.continue)!==!0)return!0;return!1}function fe(e,t){return t.map(n=>{var r;return(r=n).path??(r.path=[]),n.path.unshift(e),n})}function ft(e){return typeof e=="string"?e:e==null?void 0:e.message}function he(e,t,n){var o,i,s,c,a,u;const r={...e,path:e.path??[]};if(!e.message){const l=ft((s=(i=(o=e.inst)==null?void 0:o._zod.def)==null?void 0:i.error)==null?void 0:s.call(i,e))??ft((c=t==null?void 0:t.error)==null?void 0:c.call(t,e))??ft((a=n.customError)==null?void 0:a.call(n,e))??ft((u=n.localeError)==null?void 0:u.call(n,e))??"Invalid input";r.message=l}return delete r.inst,delete r.continue,t!=null&&t.reportInput||delete r.input,r}function un(e){return e instanceof Set?"set":e instanceof Map?"map":e instanceof File?"file":"unknown"}function ln(e){return Array.isArray(e)?"array":typeof e=="string"?"string":"unknown"}function tt(...e){const[t,n,r]=e;return typeof t=="string"?{message:t,code:"custom",input:n,inst:r}:{...t}}function Pf(e){return Object.entries(e).filter(([t,n])=>Number.isNaN(Number.parseInt(t,10))).map(t=>t[1])}function gi(e){const t=atob(e),n=new Uint8Array(t.length);for(let r=0;r<t.length;r++)n[r]=t.charCodeAt(r);return n}function wi(e){let t="";for(let n=0;n<e.length;n++)t+=String.fromCharCode(e[n]);return btoa(t)}function Tf(e){const t=e.replace(/-/g,"+").replace(/_/g,"/"),n="=".repeat((4-t.length%4)%4);return gi(t+n)}function If(e){return wi(e).replace(/\+/g,"-").replace(/\//g,"_").replace(/=/g,"")}function Rf(e){const t=e.replace(/^0x/,"");if(t.length%2!==0)throw new Error("Invalid hex string length");const n=new Uint8Array(t.length/2);for(let r=0;r<t.length;r+=2)n[r/2]=Number.parseInt(t.slice(r,r+2),16);return n}function Nf(e){return Array.from(e).map(t=>t.toString(16).padStart(2,"0")).join("")}class Zf{constructor(...t){}}const Rv=Object.freeze(Object.defineProperty({__proto__:null,BIGINT_FORMAT_RANGES:ui,Class:Zf,NUMBER_FORMAT_RANGES:ai,aborted:Le,allowsEval:oi,assert:yf,assertEqual:vf,assertIs:wf,assertNever:bf,assertNotEqual:gf,assignProp:Ze,base64ToUint8Array:gi,base64urlToUint8Array:Tf,cached:_t,captureStackTrace:lr,cleanEnum:Pf,cleanRegex:cn,clone:xe,cloneDef:Sf,createTransparentProxy:$f,defineLazy:N,esc:Ln,escapeRegex:Ne,extend:di,finalizeIssue:he,floatSafeRemainder:ri,getElementAtPath:Ef,getEnumValues:ni,getLengthableOrigin:ln,getParsedType:Af,getSizableOrigin:un,hexToUint8Array:Rf,isObject:et,isPlainObject:Be,issue:tt,joinValues:_f,jsonStringifyReplacer:Wt,merge:hi,mergeDefs:ze,normalizeParams:S,nullish:We,numKeys:kf,objectClone:xf,omit:fi,optionalKeys:ci,partial:mi,pick:li,prefixIssues:fe,primitiveTypes:ii,promiseAllObject:Cf,propertyKeyTypes:Ht,randomString:zf,required:vi,safeExtend:pi,shallowClone:an,stringifyPrimitive:si,uint8ArrayToBase64:wi,uint8ArrayToBase64url:If,uint8ArrayToHex:Nf,unwrapMessage:ft},Symbol.toStringTag,{value:"Module"})),bi=(e,t)=>{e.name="$ZodError",Object.defineProperty(e,"_zod",{value:e._zod,enumerable:!1}),Object.defineProperty(e,"issues",{value:t,enumerable:!1}),e.message=JSON.stringify(t,Wt,2),Object.defineProperty(e,"toString",{value:()=>e.message,enumerable:!1})},yi=v("$ZodError",bi),ae=v("$ZodError",bi,{Parent:Error});function Of(e,t=n=>n.message){const n={},r=[];for(const o of e.issues)o.path.length>0?(n[o.path[0]]=n[o.path[0]]||[],n[o.path[0]].push(t(o))):r.push(t(o));return{formErrors:r,fieldErrors:n}}function Df(e,t=n=>n.message){const n={_errors:[]},r=o=>{for(const i of o.issues)if(i.code==="invalid_union"&&i.errors.length)i.errors.map(s=>r({issues:s}));else if(i.code==="invalid_key")r({issues:i.issues});else if(i.code==="invalid_element")r({issues:i.issues});else if(i.path.length===0)n._errors.push(t(i));else{let s=n,c=0;for(;c<i.path.length;){const a=i.path[c];c===i.path.length-1?(s[a]=s[a]||{_errors:[]},s[a]._errors.push(t(i))):s[a]=s[a]||{_errors:[]},s=s[a],c++}}};return r(e),n}function Nv(e,t=n=>n.message){const n={errors:[]},r=(o,i=[])=>{var s,c;for(const a of o.issues)if(a.code==="invalid_union"&&a.errors.length)a.errors.map(u=>r({issues:u},a.path));else if(a.code==="invalid_key")r({issues:a.issues},a.path);else if(a.code==="invalid_element")r({issues:a.issues},a.path);else{const u=[...i,...a.path];if(u.length===0){n.errors.push(t(a));continue}let l=n,d=0;for(;d<u.length;){const m=u[d],h=d===u.length-1;typeof m=="string"?(l.properties??(l.properties={}),(s=l.properties)[m]??(s[m]={errors:[]}),l=l.properties[m]):(l.items??(l.items=[]),(c=l.items)[m]??(c[m]={errors:[]}),l=l.items[m]),h&&l.errors.push(t(a)),d++}}};return r(e),n}function Mf(e){const t=[],n=e.map(r=>typeof r=="object"?r.key:r);for(const r of n)typeof r=="number"?t.push(`[${r}]`):typeof r=="symbol"?t.push(`[${JSON.stringify(String(r))}]`):/[^\w$]/.test(r)?t.push(`[${JSON.stringify(r)}]`):(t.length&&t.push("."),t.push(r));return t.join("")}function Zv(e){var r;const t=[],n=[...e.issues].sort((o,i)=>(o.path??[]).length-(i.path??[]).length);for(const o of n)t.push(`✖ ${o.message}`),(r=o.path)!=null&&r.length&&t.push(`  → at ${Mf(o.path)}`);return t.join(`
`)}const fn=e=>(t,n,r,o)=>{const i=r?Object.assign(r,{async:!1}):{async:!1},s=t._zod.run({value:n,issues:[]},i);if(s instanceof Promise)throw new Je;if(s.issues.length){const c=new((o==null?void 0:o.Err)??e)(s.issues.map(a=>he(a,i,ce())));throw lr(c,o==null?void 0:o.callee),c}return s.value},Vr=fn(ae),dn=e=>async(t,n,r,o)=>{const i=r?Object.assign(r,{async:!0}):{async:!0};let s=t._zod.run({value:n,issues:[]},i);if(s instanceof Promise&&(s=await s),s.issues.length){const c=new((o==null?void 0:o.Err)??e)(s.issues.map(a=>he(a,i,ce())));throw lr(c,o==null?void 0:o.callee),c}return s.value},Wr=dn(ae),pn=e=>(t,n,r)=>{const o=r?{...r,async:!1}:{async:!1},i=t._zod.run({value:n,issues:[]},o);if(i instanceof Promise)throw new Je;return i.issues.length?{success:!1,error:new(e??yi)(i.issues.map(s=>he(s,o,ce())))}:{success:!0,data:i.value}},jf=pn(ae),hn=e=>async(t,n,r)=>{const o=r?Object.assign(r,{async:!0}):{async:!0};let i=t._zod.run({value:n,issues:[]},o);return i instanceof Promise&&(i=await i),i.issues.length?{success:!1,error:new e(i.issues.map(s=>he(s,o,ce())))}:{success:!0,data:i.value}},Lf=hn(ae),_i=e=>(t,n,r)=>{const o=r?Object.assign(r,{direction:"backward"}):{direction:"backward"};return fn(e)(t,n,o)},Ov=_i(ae),xi=e=>(t,n,r)=>fn(e)(t,n,r),Dv=xi(ae),Si=e=>async(t,n,r)=>{const o=r?Object.assign(r,{direction:"backward"}):{direction:"backward"};return dn(e)(t,n,o)},Mv=Si(ae),Ei=e=>async(t,n,r)=>dn(e)(t,n,r),jv=Ei(ae),Ci=e=>(t,n,r)=>{const o=r?Object.assign(r,{direction:"backward"}):{direction:"backward"};return pn(e)(t,n,o)},Lv=Ci(ae),zi=e=>(t,n,r)=>pn(e)(t,n,r),Fv=zi(ae),ki=e=>async(t,n,r)=>{const o=r?Object.assign(r,{direction:"backward"}):{direction:"backward"};return hn(e)(t,n,o)},Bv=ki(ae),Ai=e=>async(t,n,r)=>hn(e)(t,n,r),Uv=Ai(ae),$i=/^[cC][^\s-]{8,}$/,Pi=/^[0-9a-z]+$/,Ti=/^[0-9A-HJKMNP-TV-Za-hjkmnp-tv-z]{26}$/,Ii=/^[0-9a-vA-V]{20}$/,Ri=/^[A-Za-z0-9]{27}$/,Ni=/^[a-zA-Z0-9_-]{21}$/,Zi=/^P(?:(\d+W)|(?!.*W)(?=\d|T\d)(\d+Y)?(\d+M)?(\d+D)?(T(?=\d)(\d+H)?(\d+M)?(\d+([.,]\d+)?S)?)?)$/,Ff=/^[-+]?P(?!$)(?:(?:[-+]?\d+Y)|(?:[-+]?\d+[.,]\d+Y$))?(?:(?:[-+]?\d+M)|(?:[-+]?\d+[.,]\d+M$))?(?:(?:[-+]?\d+W)|(?:[-+]?\d+[.,]\d+W$))?(?:(?:[-+]?\d+D)|(?:[-+]?\d+[.,]\d+D$))?(?:T(?=[\d+-])(?:(?:[-+]?\d+H)|(?:[-+]?\d+[.,]\d+H$))?(?:(?:[-+]?\d+M)|(?:[-+]?\d+[.,]\d+M$))?(?:[-+]?\d+(?:[.,]\d+)?S)?)??$/,Oi=/^([0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12})$/,nt=e=>e?new RegExp(`^([0-9a-fA-F]{8}-[0-9a-fA-F]{4}-${e}[0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12})$`):/^([0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[1-8][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}|00000000-0000-0000-0000-000000000000|ffffffff-ffff-ffff-ffff-ffffffffffff)$/,Bf=nt(4),Uf=nt(6),Vf=nt(7),Di=/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/,Wf=/^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/,Hf=/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/,Mi=/^[^\s@"]{1,64}@[^\s@]{1,255}$/u,Kf=Mi,Gf=/^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/,Yf="^(\\p{Extended_Pictographic}|\\p{Emoji_Component})+$";function ji(){return new RegExp(Yf,"u")}const Li=/^(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])$/,Fi=/^(([0-9a-fA-F]{1,4}:){7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:))$/,Bi=/^((25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\/([0-9]|[1-2][0-9]|3[0-2])$/,Ui=/^(([0-9a-fA-F]{1,4}:){7}[0-9a-fA-F]{1,4}|::|([0-9a-fA-F]{1,4})?::([0-9a-fA-F]{1,4}:?){0,6})\/(12[0-8]|1[01][0-9]|[1-9]?[0-9])$/,Vi=/^$|^(?:[0-9a-zA-Z+/]{4})*(?:(?:[0-9a-zA-Z+/]{2}==)|(?:[0-9a-zA-Z+/]{3}=))?$/,fr=/^[A-Za-z0-9_-]*$/,dr=/^(?=.{1,253}\.?$)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[-0-9a-zA-Z]{0,61}[0-9a-zA-Z])?)*\.?$/,Wi=/^([a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?\.)+[a-zA-Z]{2,}$/,Hi=/^\+(?:[0-9]){6,14}[0-9]$/,Ki="(?:(?:\\d\\d[2468][048]|\\d\\d[13579][26]|\\d\\d0[48]|[02468][048]00|[13579][26]00)-02-29|\\d{4}-(?:(?:0[13578]|1[02])-(?:0[1-9]|[12]\\d|3[01])|(?:0[469]|11)-(?:0[1-9]|[12]\\d|30)|(?:02)-(?:0[1-9]|1\\d|2[0-8])))",Gi=new RegExp(`^${Ki}$`);function Yi(e){const t="(?:[01]\\d|2[0-3]):[0-5]\\d";return typeof e.precision=="number"?e.precision===-1?`${t}`:e.precision===0?`${t}:[0-5]\\d`:`${t}:[0-5]\\d\\.\\d{${e.precision}}`:`${t}(?::[0-5]\\d(?:\\.\\d+)?)?`}function Xi(e){return new RegExp(`^${Yi(e)}$`)}function qi(e){const t=Yi({precision:e.precision}),n=["Z"];e.local&&n.push(""),e.offset&&n.push("([+-](?:[01]\\d|2[0-3]):[0-5]\\d)");const r=`${t}(?:${n.join("|")})`;return new RegExp(`^${Ki}T(?:${r})$`)}const Ji=e=>{const t=e?`[\\s\\S]{${(e==null?void 0:e.minimum)??0},${(e==null?void 0:e.maximum)??""}}`:"[\\s\\S]*";return new RegExp(`^${t}$`)},Qi=/^-?\d+n?$/,es=/^-?\d+$/,ts=/^-?\d+(?:\.\d+)?/,ns=/^(?:true|false)$/i,rs=/^null$/i,os=/^undefined$/i,is=/^[^A-Z]*$/,ss=/^[^a-z]*$/,cs=/^[0-9a-fA-F]*$/;function xt(e,t){return new RegExp(`^[A-Za-z0-9+/]{${e}}${t}$`)}function St(e){return new RegExp(`^[A-Za-z0-9_-]{${e}}$`)}const Xf=/^[0-9a-fA-F]{32}$/,qf=xt(22,"=="),Jf=St(22),Qf=/^[0-9a-fA-F]{40}$/,ed=xt(27,"="),td=St(27),nd=/^[0-9a-fA-F]{64}$/,rd=xt(43,"="),od=St(43),id=/^[0-9a-fA-F]{96}$/,sd=xt(64,""),cd=St(64),ad=/^[0-9a-fA-F]{128}$/,ud=xt(86,"=="),ld=St(86),fd=Object.freeze(Object.defineProperty({__proto__:null,base64:Vi,base64url:fr,bigint:Qi,boolean:ns,browserEmail:Gf,cidrv4:Bi,cidrv6:Ui,cuid:$i,cuid2:Pi,date:Gi,datetime:qi,domain:Wi,duration:Zi,e164:Hi,email:Di,emoji:ji,extendedDuration:Ff,guid:Oi,hex:cs,hostname:dr,html5Email:Wf,idnEmail:Kf,integer:es,ipv4:Li,ipv6:Fi,ksuid:Ri,lowercase:is,md5_base64:qf,md5_base64url:Jf,md5_hex:Xf,nanoid:Ni,null:rs,number:ts,rfc5322Email:Hf,sha1_base64:ed,sha1_base64url:td,sha1_hex:Qf,sha256_base64:rd,sha256_base64url:od,sha256_hex:nd,sha384_base64:sd,sha384_base64url:cd,sha384_hex:id,sha512_base64:ud,sha512_base64url:ld,sha512_hex:ad,string:Ji,time:Xi,ulid:Ti,undefined:os,unicodeEmail:Mi,uppercase:ss,uuid:nt,uuid4:Bf,uuid6:Uf,uuid7:Vf,xid:Ii},Symbol.toStringTag,{value:"Module"})),J=v("$ZodCheck",(e,t)=>{var n;e._zod??(e._zod={}),e._zod.def=t,(n=e._zod).onattach??(n.onattach=[])}),as={number:"number",bigint:"bigint",object:"date"},us=v("$ZodCheckLessThan",(e,t)=>{J.init(e,t);const n=as[typeof t.value];e._zod.onattach.push(r=>{const o=r._zod.bag,i=(t.inclusive?o.maximum:o.exclusiveMaximum)??Number.POSITIVE_INFINITY;t.value<i&&(t.inclusive?o.maximum=t.value:o.exclusiveMaximum=t.value)}),e._zod.check=r=>{(t.inclusive?r.value<=t.value:r.value<t.value)||r.issues.push({origin:n,code:"too_big",maximum:t.value,input:r.value,inclusive:t.inclusive,inst:e,continue:!t.abort})}}),ls=v("$ZodCheckGreaterThan",(e,t)=>{J.init(e,t);const n=as[typeof t.value];e._zod.onattach.push(r=>{const o=r._zod.bag,i=(t.inclusive?o.minimum:o.exclusiveMinimum)??Number.NEGATIVE_INFINITY;t.value>i&&(t.inclusive?o.minimum=t.value:o.exclusiveMinimum=t.value)}),e._zod.check=r=>{(t.inclusive?r.value>=t.value:r.value>t.value)||r.issues.push({origin:n,code:"too_small",minimum:t.value,input:r.value,inclusive:t.inclusive,inst:e,continue:!t.abort})}}),dd=v("$ZodCheckMultipleOf",(e,t)=>{J.init(e,t),e._zod.onattach.push(n=>{var r;(r=n._zod.bag).multipleOf??(r.multipleOf=t.value)}),e._zod.check=n=>{if(typeof n.value!=typeof t.value)throw new Error("Cannot mix number and bigint in multiple_of check.");(typeof n.value=="bigint"?n.value%t.value===BigInt(0):ri(n.value,t.value)===0)||n.issues.push({origin:typeof n.value,code:"not_multiple_of",divisor:t.value,input:n.value,inst:e,continue:!t.abort})}}),pd=v("$ZodCheckNumberFormat",(e,t)=>{var s;J.init(e,t),t.format=t.format||"float64";const n=(s=t.format)==null?void 0:s.includes("int"),r=n?"int":"number",[o,i]=ai[t.format];e._zod.onattach.push(c=>{const a=c._zod.bag;a.format=t.format,a.minimum=o,a.maximum=i,n&&(a.pattern=es)}),e._zod.check=c=>{const a=c.value;if(n){if(!Number.isInteger(a)){c.issues.push({expected:r,format:t.format,code:"invalid_type",continue:!1,input:a,inst:e});return}if(!Number.isSafeInteger(a)){a>0?c.issues.push({input:a,code:"too_big",maximum:Number.MAX_SAFE_INTEGER,note:"Integers must be within the safe integer range.",inst:e,origin:r,continue:!t.abort}):c.issues.push({input:a,code:"too_small",minimum:Number.MIN_SAFE_INTEGER,note:"Integers must be within the safe integer range.",inst:e,origin:r,continue:!t.abort});return}}a<o&&c.issues.push({origin:"number",input:a,code:"too_small",minimum:o,inclusive:!0,inst:e,continue:!t.abort}),a>i&&c.issues.push({origin:"number",input:a,code:"too_big",maximum:i,inst:e})}}),hd=v("$ZodCheckBigIntFormat",(e,t)=>{J.init(e,t);const[n,r]=ui[t.format];e._zod.onattach.push(o=>{const i=o._zod.bag;i.format=t.format,i.minimum=n,i.maximum=r}),e._zod.check=o=>{const i=o.value;i<n&&o.issues.push({origin:"bigint",input:i,code:"too_small",minimum:n,inclusive:!0,inst:e,continue:!t.abort}),i>r&&o.issues.push({origin:"bigint",input:i,code:"too_big",maximum:r,inst:e})}}),md=v("$ZodCheckMaxSize",(e,t)=>{var n;J.init(e,t),(n=e._zod.def).when??(n.when=r=>{const o=r.value;return!We(o)&&o.size!==void 0}),e._zod.onattach.push(r=>{const o=r._zod.bag.maximum??Number.POSITIVE_INFINITY;t.maximum<o&&(r._zod.bag.maximum=t.maximum)}),e._zod.check=r=>{const o=r.value;o.size<=t.maximum||r.issues.push({origin:un(o),code:"too_big",maximum:t.maximum,inclusive:!0,input:o,inst:e,continue:!t.abort})}}),vd=v("$ZodCheckMinSize",(e,t)=>{var n;J.init(e,t),(n=e._zod.def).when??(n.when=r=>{const o=r.value;return!We(o)&&o.size!==void 0}),e._zod.onattach.push(r=>{const o=r._zod.bag.minimum??Number.NEGATIVE_INFINITY;t.minimum>o&&(r._zod.bag.minimum=t.minimum)}),e._zod.check=r=>{const o=r.value;o.size>=t.minimum||r.issues.push({origin:un(o),code:"too_small",minimum:t.minimum,inclusive:!0,input:o,inst:e,continue:!t.abort})}}),gd=v("$ZodCheckSizeEquals",(e,t)=>{var n;J.init(e,t),(n=e._zod.def).when??(n.when=r=>{const o=r.value;return!We(o)&&o.size!==void 0}),e._zod.onattach.push(r=>{const o=r._zod.bag;o.minimum=t.size,o.maximum=t.size,o.size=t.size}),e._zod.check=r=>{const o=r.value,i=o.size;if(i===t.size)return;const s=i>t.size;r.issues.push({origin:un(o),...s?{code:"too_big",maximum:t.size}:{code:"too_small",minimum:t.size},inclusive:!0,exact:!0,input:r.value,inst:e,continue:!t.abort})}}),wd=v("$ZodCheckMaxLength",(e,t)=>{var n;J.init(e,t),(n=e._zod.def).when??(n.when=r=>{const o=r.value;return!We(o)&&o.length!==void 0}),e._zod.onattach.push(r=>{const o=r._zod.bag.maximum??Number.POSITIVE_INFINITY;t.maximum<o&&(r._zod.bag.maximum=t.maximum)}),e._zod.check=r=>{const o=r.value;if(o.length<=t.maximum)return;const s=ln(o);r.issues.push({origin:s,code:"too_big",maximum:t.maximum,inclusive:!0,input:o,inst:e,continue:!t.abort})}}),bd=v("$ZodCheckMinLength",(e,t)=>{var n;J.init(e,t),(n=e._zod.def).when??(n.when=r=>{const o=r.value;return!We(o)&&o.length!==void 0}),e._zod.onattach.push(r=>{const o=r._zod.bag.minimum??Number.NEGATIVE_INFINITY;t.minimum>o&&(r._zod.bag.minimum=t.minimum)}),e._zod.check=r=>{const o=r.value;if(o.length>=t.minimum)return;const s=ln(o);r.issues.push({origin:s,code:"too_small",minimum:t.minimum,inclusive:!0,input:o,inst:e,continue:!t.abort})}}),yd=v("$ZodCheckLengthEquals",(e,t)=>{var n;J.init(e,t),(n=e._zod.def).when??(n.when=r=>{const o=r.value;return!We(o)&&o.length!==void 0}),e._zod.onattach.push(r=>{const o=r._zod.bag;o.minimum=t.length,o.maximum=t.length,o.length=t.length}),e._zod.check=r=>{const o=r.value,i=o.length;if(i===t.length)return;const s=ln(o),c=i>t.length;r.issues.push({origin:s,...c?{code:"too_big",maximum:t.length}:{code:"too_small",minimum:t.length},inclusive:!0,exact:!0,input:r.value,inst:e,continue:!t.abort})}}),mn=v("$ZodCheckStringFormat",(e,t)=>{var n,r;J.init(e,t),e._zod.onattach.push(o=>{const i=o._zod.bag;i.format=t.format,t.pattern&&(i.patterns??(i.patterns=new Set),i.patterns.add(t.pattern))}),t.pattern?(n=e._zod).check??(n.check=o=>{t.pattern.lastIndex=0,!t.pattern.test(o.value)&&o.issues.push({origin:"string",code:"invalid_format",format:t.format,input:o.value,...t.pattern?{pattern:t.pattern.toString()}:{},inst:e,continue:!t.abort})}):(r=e._zod).check??(r.check=()=>{})}),_d=v("$ZodCheckRegex",(e,t)=>{mn.init(e,t),e._zod.check=n=>{t.pattern.lastIndex=0,!t.pattern.test(n.value)&&n.issues.push({origin:"string",code:"invalid_format",format:"regex",input:n.value,pattern:t.pattern.toString(),inst:e,continue:!t.abort})}}),xd=v("$ZodCheckLowerCase",(e,t)=>{t.pattern??(t.pattern=is),mn.init(e,t)}),Sd=v("$ZodCheckUpperCase",(e,t)=>{t.pattern??(t.pattern=ss),mn.init(e,t)}),Ed=v("$ZodCheckIncludes",(e,t)=>{J.init(e,t);const n=Ne(t.includes),r=new RegExp(typeof t.position=="number"?`^.{${t.position}}${n}`:n);t.pattern=r,e._zod.onattach.push(o=>{const i=o._zod.bag;i.patterns??(i.patterns=new Set),i.patterns.add(r)}),e._zod.check=o=>{o.value.includes(t.includes,t.position)||o.issues.push({origin:"string",code:"invalid_format",format:"includes",includes:t.includes,input:o.value,inst:e,continue:!t.abort})}}),Cd=v("$ZodCheckStartsWith",(e,t)=>{J.init(e,t);const n=new RegExp(`^${Ne(t.prefix)}.*`);t.pattern??(t.pattern=n),e._zod.onattach.push(r=>{const o=r._zod.bag;o.patterns??(o.patterns=new Set),o.patterns.add(n)}),e._zod.check=r=>{r.value.startsWith(t.prefix)||r.issues.push({origin:"string",code:"invalid_format",format:"starts_with",prefix:t.prefix,input:r.value,inst:e,continue:!t.abort})}}),zd=v("$ZodCheckEndsWith",(e,t)=>{J.init(e,t);const n=new RegExp(`.*${Ne(t.suffix)}$`);t.pattern??(t.pattern=n),e._zod.onattach.push(r=>{const o=r._zod.bag;o.patterns??(o.patterns=new Set),o.patterns.add(n)}),e._zod.check=r=>{r.value.endsWith(t.suffix)||r.issues.push({origin:"string",code:"invalid_format",format:"ends_with",suffix:t.suffix,input:r.value,inst:e,continue:!t.abort})}});function Hr(e,t,n){e.issues.length&&t.issues.push(...fe(n,e.issues))}const kd=v("$ZodCheckProperty",(e,t)=>{J.init(e,t),e._zod.check=n=>{const r=t.schema._zod.run({value:n.value[t.property],issues:[]},{});if(r instanceof Promise)return r.then(o=>Hr(o,n,t.property));Hr(r,n,t.property)}}),Ad=v("$ZodCheckMimeType",(e,t)=>{J.init(e,t);const n=new Set(t.mime);e._zod.onattach.push(r=>{r._zod.bag.mime=t.mime}),e._zod.check=r=>{n.has(r.value.type)||r.issues.push({code:"invalid_value",values:t.mime,input:r.value.type,inst:e,continue:!t.abort})}}),$d=v("$ZodCheckOverwrite",(e,t)=>{J.init(e,t),e._zod.check=n=>{n.value=t.tx(n.value)}});class Pd{constructor(t=[]){this.content=[],this.indent=0,this&&(this.args=t)}indented(t){this.indent+=1,t(this),this.indent-=1}write(t){if(typeof t=="function"){t(this,{execution:"sync"}),t(this,{execution:"async"});return}const r=t.split(`
`).filter(s=>s),o=Math.min(...r.map(s=>s.length-s.trimStart().length)),i=r.map(s=>s.slice(o)).map(s=>" ".repeat(this.indent*2)+s);for(const s of i)this.content.push(s)}compile(){const t=Function,n=this==null?void 0:this.args,o=[...((this==null?void 0:this.content)??[""]).map(i=>`  ${i}`)];return new t(...n,o.join(`
`))}}const Td={major:4,minor:1,patch:12},T=v("$ZodType",(e,t)=>{var o;var n;e??(e={}),e._zod.def=t,e._zod.bag=e._zod.bag||{},e._zod.version=Td;const r=[...e._zod.def.checks??[]];e._zod.traits.has("$ZodCheck")&&r.unshift(e);for(const i of r)for(const s of i._zod.onattach)s(e);if(r.length===0)(n=e._zod).deferred??(n.deferred=[]),(o=e._zod.deferred)==null||o.push(()=>{e._zod.run=e._zod.parse});else{const i=(c,a,u)=>{let l=Le(c),d;for(const m of a){if(m._zod.def.when){if(!m._zod.def.when(c))continue}else if(l)continue;const h=c.issues.length,w=m._zod.check(c);if(w instanceof Promise&&(u==null?void 0:u.async)===!1)throw new Je;if(d||w instanceof Promise)d=(d??Promise.resolve()).then(async()=>{await w,c.issues.length!==h&&(l||(l=Le(c,h)))});else{if(c.issues.length===h)continue;l||(l=Le(c,h))}}return d?d.then(()=>c):c},s=(c,a,u)=>{if(Le(c))return c.aborted=!0,c;const l=i(a,r,u);if(l instanceof Promise){if(u.async===!1)throw new Je;return l.then(d=>e._zod.parse(d,u))}return e._zod.parse(l,u)};e._zod.run=(c,a)=>{if(a.skipChecks)return e._zod.parse(c,a);if(a.direction==="backward"){const l=e._zod.parse({value:c.value,issues:[]},{...a,skipChecks:!0});return l instanceof Promise?l.then(d=>s(d,c,a)):s(l,c,a)}const u=e._zod.parse(c,a);if(u instanceof Promise){if(a.async===!1)throw new Je;return u.then(l=>i(l,r,a))}return i(u,r,a)}}e["~standard"]={validate:i=>{var s;try{const c=jf(e,i);return c.success?{value:c.data}:{issues:(s=c.error)==null?void 0:s.issues}}catch{return Lf(e,i).then(a=>{var u;return a.success?{value:a.data}:{issues:(u=a.error)==null?void 0:u.issues}})}},vendor:"zod",version:1}}),vn=v("$ZodString",(e,t)=>{var n;T.init(e,t),e._zod.pattern=[...((n=e==null?void 0:e._zod.bag)==null?void 0:n.patterns)??[]].pop()??Ji(e._zod.bag),e._zod.parse=(r,o)=>{if(t.coerce)try{r.value=String(r.value)}catch{}return typeof r.value=="string"||r.issues.push({expected:"string",code:"invalid_type",input:r.value,inst:e}),r}}),Y=v("$ZodStringFormat",(e,t)=>{mn.init(e,t),vn.init(e,t)}),Id=v("$ZodGUID",(e,t)=>{t.pattern??(t.pattern=Oi),Y.init(e,t)}),Rd=v("$ZodUUID",(e,t)=>{if(t.version){const r={v1:1,v2:2,v3:3,v4:4,v5:5,v6:6,v7:7,v8:8}[t.version];if(r===void 0)throw new Error(`Invalid UUID version: "${t.version}"`);t.pattern??(t.pattern=nt(r))}else t.pattern??(t.pattern=nt());Y.init(e,t)}),Nd=v("$ZodEmail",(e,t)=>{t.pattern??(t.pattern=Di),Y.init(e,t)}),Zd=v("$ZodURL",(e,t)=>{Y.init(e,t),e._zod.check=n=>{try{const r=n.value.trim(),o=new URL(r);t.hostname&&(t.hostname.lastIndex=0,t.hostname.test(o.hostname)||n.issues.push({code:"invalid_format",format:"url",note:"Invalid hostname",pattern:dr.source,input:n.value,inst:e,continue:!t.abort})),t.protocol&&(t.protocol.lastIndex=0,t.protocol.test(o.protocol.endsWith(":")?o.protocol.slice(0,-1):o.protocol)||n.issues.push({code:"invalid_format",format:"url",note:"Invalid protocol",pattern:t.protocol.source,input:n.value,inst:e,continue:!t.abort})),t.normalize?n.value=o.href:n.value=r;return}catch{n.issues.push({code:"invalid_format",format:"url",input:n.value,inst:e,continue:!t.abort})}}}),Od=v("$ZodEmoji",(e,t)=>{t.pattern??(t.pattern=ji()),Y.init(e,t)}),Dd=v("$ZodNanoID",(e,t)=>{t.pattern??(t.pattern=Ni),Y.init(e,t)}),Md=v("$ZodCUID",(e,t)=>{t.pattern??(t.pattern=$i),Y.init(e,t)}),jd=v("$ZodCUID2",(e,t)=>{t.pattern??(t.pattern=Pi),Y.init(e,t)}),Ld=v("$ZodULID",(e,t)=>{t.pattern??(t.pattern=Ti),Y.init(e,t)}),Fd=v("$ZodXID",(e,t)=>{t.pattern??(t.pattern=Ii),Y.init(e,t)}),Bd=v("$ZodKSUID",(e,t)=>{t.pattern??(t.pattern=Ri),Y.init(e,t)}),Ud=v("$ZodISODateTime",(e,t)=>{t.pattern??(t.pattern=qi(t)),Y.init(e,t)}),Vd=v("$ZodISODate",(e,t)=>{t.pattern??(t.pattern=Gi),Y.init(e,t)}),Wd=v("$ZodISOTime",(e,t)=>{t.pattern??(t.pattern=Xi(t)),Y.init(e,t)}),Hd=v("$ZodISODuration",(e,t)=>{t.pattern??(t.pattern=Zi),Y.init(e,t)}),Kd=v("$ZodIPv4",(e,t)=>{t.pattern??(t.pattern=Li),Y.init(e,t),e._zod.onattach.push(n=>{const r=n._zod.bag;r.format="ipv4"})}),Gd=v("$ZodIPv6",(e,t)=>{t.pattern??(t.pattern=Fi),Y.init(e,t),e._zod.onattach.push(n=>{const r=n._zod.bag;r.format="ipv6"}),e._zod.check=n=>{try{new URL(`http://[${n.value}]`)}catch{n.issues.push({code:"invalid_format",format:"ipv6",input:n.value,inst:e,continue:!t.abort})}}}),Yd=v("$ZodCIDRv4",(e,t)=>{t.pattern??(t.pattern=Bi),Y.init(e,t)}),Xd=v("$ZodCIDRv6",(e,t)=>{t.pattern??(t.pattern=Ui),Y.init(e,t),e._zod.check=n=>{const r=n.value.split("/");try{if(r.length!==2)throw new Error;const[o,i]=r;if(!i)throw new Error;const s=Number(i);if(`${s}`!==i)throw new Error;if(s<0||s>128)throw new Error;new URL(`http://[${o}]`)}catch{n.issues.push({code:"invalid_format",format:"cidrv6",input:n.value,inst:e,continue:!t.abort})}}});function fs(e){if(e==="")return!0;if(e.length%4!==0)return!1;try{return atob(e),!0}catch{return!1}}const qd=v("$ZodBase64",(e,t)=>{t.pattern??(t.pattern=Vi),Y.init(e,t),e._zod.onattach.push(n=>{n._zod.bag.contentEncoding="base64"}),e._zod.check=n=>{fs(n.value)||n.issues.push({code:"invalid_format",format:"base64",input:n.value,inst:e,continue:!t.abort})}});function Jd(e){if(!fr.test(e))return!1;const t=e.replace(/[-_]/g,r=>r==="-"?"+":"/"),n=t.padEnd(Math.ceil(t.length/4)*4,"=");return fs(n)}const Qd=v("$ZodBase64URL",(e,t)=>{t.pattern??(t.pattern=fr),Y.init(e,t),e._zod.onattach.push(n=>{n._zod.bag.contentEncoding="base64url"}),e._zod.check=n=>{Jd(n.value)||n.issues.push({code:"invalid_format",format:"base64url",input:n.value,inst:e,continue:!t.abort})}}),ep=v("$ZodE164",(e,t)=>{t.pattern??(t.pattern=Hi),Y.init(e,t)});function tp(e,t=null){try{const n=e.split(".");if(n.length!==3)return!1;const[r]=n;if(!r)return!1;const o=JSON.parse(atob(r));return!("typ"in o&&(o==null?void 0:o.typ)!=="JWT"||!o.alg||t&&(!("alg"in o)||o.alg!==t))}catch{return!1}}const np=v("$ZodJWT",(e,t)=>{Y.init(e,t),e._zod.check=n=>{tp(n.value,t.alg)||n.issues.push({code:"invalid_format",format:"jwt",input:n.value,inst:e,continue:!t.abort})}}),rp=v("$ZodCustomStringFormat",(e,t)=>{Y.init(e,t),e._zod.check=n=>{t.fn(n.value)||n.issues.push({code:"invalid_format",format:t.format,input:n.value,inst:e,continue:!t.abort})}}),ds=v("$ZodNumber",(e,t)=>{T.init(e,t),e._zod.pattern=e._zod.bag.pattern??ts,e._zod.parse=(n,r)=>{if(t.coerce)try{n.value=Number(n.value)}catch{}const o=n.value;if(typeof o=="number"&&!Number.isNaN(o)&&Number.isFinite(o))return n;const i=typeof o=="number"?Number.isNaN(o)?"NaN":Number.isFinite(o)?void 0:"Infinity":void 0;return n.issues.push({expected:"number",code:"invalid_type",input:o,inst:e,...i?{received:i}:{}}),n}}),op=v("$ZodNumber",(e,t)=>{pd.init(e,t),ds.init(e,t)}),ps=v("$ZodBoolean",(e,t)=>{T.init(e,t),e._zod.pattern=ns,e._zod.parse=(n,r)=>{if(t.coerce)try{n.value=!!n.value}catch{}const o=n.value;return typeof o=="boolean"||n.issues.push({expected:"boolean",code:"invalid_type",input:o,inst:e}),n}}),hs=v("$ZodBigInt",(e,t)=>{T.init(e,t),e._zod.pattern=Qi,e._zod.parse=(n,r)=>{if(t.coerce)try{n.value=BigInt(n.value)}catch{}return typeof n.value=="bigint"||n.issues.push({expected:"bigint",code:"invalid_type",input:n.value,inst:e}),n}}),ip=v("$ZodBigInt",(e,t)=>{hd.init(e,t),hs.init(e,t)}),sp=v("$ZodSymbol",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{const o=n.value;return typeof o=="symbol"||n.issues.push({expected:"symbol",code:"invalid_type",input:o,inst:e}),n}}),cp=v("$ZodUndefined",(e,t)=>{T.init(e,t),e._zod.pattern=os,e._zod.values=new Set([void 0]),e._zod.optin="optional",e._zod.optout="optional",e._zod.parse=(n,r)=>{const o=n.value;return typeof o>"u"||n.issues.push({expected:"undefined",code:"invalid_type",input:o,inst:e}),n}}),ap=v("$ZodNull",(e,t)=>{T.init(e,t),e._zod.pattern=rs,e._zod.values=new Set([null]),e._zod.parse=(n,r)=>{const o=n.value;return o===null||n.issues.push({expected:"null",code:"invalid_type",input:o,inst:e}),n}}),up=v("$ZodAny",(e,t)=>{T.init(e,t),e._zod.parse=n=>n}),lp=v("$ZodUnknown",(e,t)=>{T.init(e,t),e._zod.parse=n=>n}),fp=v("$ZodNever",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>(n.issues.push({expected:"never",code:"invalid_type",input:n.value,inst:e}),n)}),dp=v("$ZodVoid",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{const o=n.value;return typeof o>"u"||n.issues.push({expected:"void",code:"invalid_type",input:o,inst:e}),n}}),pp=v("$ZodDate",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{if(t.coerce)try{n.value=new Date(n.value)}catch{}const o=n.value,i=o instanceof Date;return i&&!Number.isNaN(o.getTime())||n.issues.push({expected:"date",code:"invalid_type",input:o,...i?{received:"Invalid Date"}:{},inst:e}),n}});function Kr(e,t,n){e.issues.length&&t.issues.push(...fe(n,e.issues)),t.value[n]=e.value}const hp=v("$ZodArray",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{const o=n.value;if(!Array.isArray(o))return n.issues.push({expected:"array",code:"invalid_type",input:o,inst:e}),n;n.value=Array(o.length);const i=[];for(let s=0;s<o.length;s++){const c=o[s],a=t.element._zod.run({value:c,issues:[]},r);a instanceof Promise?i.push(a.then(u=>Kr(u,n,s))):Kr(a,n,s)}return i.length?Promise.all(i).then(()=>n):n}});function Kt(e,t,n,r){e.issues.length&&t.issues.push(...fe(n,e.issues)),e.value===void 0?n in r&&(t.value[n]=void 0):t.value[n]=e.value}function ms(e){var r,o,i,s;const t=Object.keys(e.shape);for(const c of t)if(!((s=(i=(o=(r=e.shape)==null?void 0:r[c])==null?void 0:o._zod)==null?void 0:i.traits)!=null&&s.has("$ZodType")))throw new Error(`Invalid element at key "${c}": expected a Zod schema`);const n=ci(e.shape);return{...e,keys:t,keySet:new Set(t),numKeys:t.length,optionalKeys:new Set(n)}}function vs(e,t,n,r,o,i){const s=[],c=o.keySet,a=o.catchall._zod,u=a.def.type;for(const l of Object.keys(t)){if(c.has(l))continue;if(u==="never"){s.push(l);continue}const d=a.run({value:t[l],issues:[]},r);d instanceof Promise?e.push(d.then(m=>Kt(m,n,l,t))):Kt(d,n,l,t)}return s.length&&n.issues.push({code:"unrecognized_keys",keys:s,input:t,inst:i}),e.length?Promise.all(e).then(()=>n):n}const mp=v("$ZodObject",(e,t)=>{T.init(e,t);const n=Object.getOwnPropertyDescriptor(t,"shape");if(!(n!=null&&n.get)){const c=t.shape;Object.defineProperty(t,"shape",{get:()=>{const a={...c};return Object.defineProperty(t,"shape",{value:a}),a}})}const r=_t(()=>ms(t));N(e._zod,"propValues",()=>{const c=t.shape,a={};for(const u in c){const l=c[u]._zod;if(l.values){a[u]??(a[u]=new Set);for(const d of l.values)a[u].add(d)}}return a});const o=et,i=t.catchall;let s;e._zod.parse=(c,a)=>{s??(s=r.value);const u=c.value;if(!o(u))return c.issues.push({expected:"object",code:"invalid_type",input:u,inst:e}),c;c.value={};const l=[],d=s.shape;for(const m of s.keys){const w=d[m]._zod.run({value:u[m],issues:[]},a);w instanceof Promise?l.push(w.then(p=>Kt(p,c,m,u))):Kt(w,c,m,u)}return i?vs(l,u,c,a,r.value,e):l.length?Promise.all(l).then(()=>c):c}}),vp=v("$ZodObjectJIT",(e,t)=>{mp.init(e,t);const n=e._zod.parse,r=_t(()=>ms(t)),o=m=>{const h=new Pd(["shape","payload","ctx"]),w=r.value,p=b=>{const E=Ln(b);return`shape[${E}]._zod.run({ value: input[${E}], issues: [] }, ctx)`};h.write("const input = payload.value;");const g=Object.create(null);let x=0;for(const b of w.keys)g[b]=`key_${x++}`;h.write("const newResult = {};");for(const b of w.keys){const E=g[b],C=Ln(b);h.write(`const ${E} = ${p(b)};`),h.write(`
        if (${E}.issues.length) {
          payload.issues = payload.issues.concat(${E}.issues.map(iss => ({
            ...iss,
            path: iss.path ? [${C}, ...iss.path] : [${C}]
          })));
        }
        
        
        if (${E}.value === undefined) {
          if (${C} in input) {
            newResult[${C}] = undefined;
          }
        } else {
          newResult[${C}] = ${E}.value;
        }
        
      `)}h.write("payload.value = newResult;"),h.write("return payload;");const y=h.compile();return(b,E)=>y(m,b,E)};let i;const s=et,c=!jn.jitless,u=c&&oi.value,l=t.catchall;let d;e._zod.parse=(m,h)=>{d??(d=r.value);const w=m.value;return s(w)?c&&u&&(h==null?void 0:h.async)===!1&&h.jitless!==!0?(i||(i=o(t.shape)),m=i(m,h),l?vs([],w,m,h,d,e):m):n(m,h):(m.issues.push({expected:"object",code:"invalid_type",input:w,inst:e}),m)}});function Gr(e,t,n,r){for(const i of e)if(i.issues.length===0)return t.value=i.value,t;const o=e.filter(i=>!Le(i));return o.length===1?(t.value=o[0].value,o[0]):(t.issues.push({code:"invalid_union",input:t.value,inst:n,errors:e.map(i=>i.issues.map(s=>he(s,r,ce())))}),t)}const gs=v("$ZodUnion",(e,t)=>{T.init(e,t),N(e._zod,"optin",()=>t.options.some(o=>o._zod.optin==="optional")?"optional":void 0),N(e._zod,"optout",()=>t.options.some(o=>o._zod.optout==="optional")?"optional":void 0),N(e._zod,"values",()=>{if(t.options.every(o=>o._zod.values))return new Set(t.options.flatMap(o=>Array.from(o._zod.values)))}),N(e._zod,"pattern",()=>{if(t.options.every(o=>o._zod.pattern)){const o=t.options.map(i=>i._zod.pattern);return new RegExp(`^(${o.map(i=>cn(i.source)).join("|")})$`)}});const n=t.options.length===1,r=t.options[0]._zod.run;e._zod.parse=(o,i)=>{if(n)return r(o,i);let s=!1;const c=[];for(const a of t.options){const u=a._zod.run({value:o.value,issues:[]},i);if(u instanceof Promise)c.push(u),s=!0;else{if(u.issues.length===0)return u;c.push(u)}}return s?Promise.all(c).then(a=>Gr(a,o,e,i)):Gr(c,o,e,i)}}),gp=v("$ZodDiscriminatedUnion",(e,t)=>{gs.init(e,t);const n=e._zod.parse;N(e._zod,"propValues",()=>{const o={};for(const i of t.options){const s=i._zod.propValues;if(!s||Object.keys(s).length===0)throw new Error(`Invalid discriminated union option at index "${t.options.indexOf(i)}"`);for(const[c,a]of Object.entries(s)){o[c]||(o[c]=new Set);for(const u of a)o[c].add(u)}}return o});const r=_t(()=>{var s;const o=t.options,i=new Map;for(const c of o){const a=(s=c._zod.propValues)==null?void 0:s[t.discriminator];if(!a||a.size===0)throw new Error(`Invalid discriminated union option at index "${t.options.indexOf(c)}"`);for(const u of a){if(i.has(u))throw new Error(`Duplicate discriminator value "${String(u)}"`);i.set(u,c)}}return i});e._zod.parse=(o,i)=>{const s=o.value;if(!et(s))return o.issues.push({code:"invalid_type",expected:"object",input:s,inst:e}),o;const c=r.value.get(s==null?void 0:s[t.discriminator]);return c?c._zod.run(o,i):t.unionFallback?n(o,i):(o.issues.push({code:"invalid_union",errors:[],note:"No matching discriminator",discriminator:t.discriminator,input:s,path:[t.discriminator],inst:e}),o)}}),wp=v("$ZodIntersection",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{const o=n.value,i=t.left._zod.run({value:o,issues:[]},r),s=t.right._zod.run({value:o,issues:[]},r);return i instanceof Promise||s instanceof Promise?Promise.all([i,s]).then(([a,u])=>Yr(n,a,u)):Yr(n,i,s)}});function Fn(e,t){if(e===t)return{valid:!0,data:e};if(e instanceof Date&&t instanceof Date&&+e==+t)return{valid:!0,data:e};if(Be(e)&&Be(t)){const n=Object.keys(t),r=Object.keys(e).filter(i=>n.indexOf(i)!==-1),o={...e,...t};for(const i of r){const s=Fn(e[i],t[i]);if(!s.valid)return{valid:!1,mergeErrorPath:[i,...s.mergeErrorPath]};o[i]=s.data}return{valid:!0,data:o}}if(Array.isArray(e)&&Array.isArray(t)){if(e.length!==t.length)return{valid:!1,mergeErrorPath:[]};const n=[];for(let r=0;r<e.length;r++){const o=e[r],i=t[r],s=Fn(o,i);if(!s.valid)return{valid:!1,mergeErrorPath:[r,...s.mergeErrorPath]};n.push(s.data)}return{valid:!0,data:n}}return{valid:!1,mergeErrorPath:[]}}function Yr(e,t,n){if(t.issues.length&&e.issues.push(...t.issues),n.issues.length&&e.issues.push(...n.issues),Le(e))return e;const r=Fn(t.value,n.value);if(!r.valid)throw new Error(`Unmergable intersection. Error path: ${JSON.stringify(r.mergeErrorPath)}`);return e.value=r.data,e}const ws=v("$ZodTuple",(e,t)=>{T.init(e,t);const n=t.items,r=n.length-[...n].reverse().findIndex(o=>o._zod.optin!=="optional");e._zod.parse=(o,i)=>{const s=o.value;if(!Array.isArray(s))return o.issues.push({input:s,inst:e,expected:"tuple",code:"invalid_type"}),o;o.value=[];const c=[];if(!t.rest){const u=s.length>n.length,l=s.length<r-1;if(u||l)return o.issues.push({...u?{code:"too_big",maximum:n.length}:{code:"too_small",minimum:n.length},input:s,inst:e,origin:"array"}),o}let a=-1;for(const u of n){if(a++,a>=s.length&&a>=r)continue;const l=u._zod.run({value:s[a],issues:[]},i);l instanceof Promise?c.push(l.then(d=>Rt(d,o,a))):Rt(l,o,a)}if(t.rest){const u=s.slice(n.length);for(const l of u){a++;const d=t.rest._zod.run({value:l,issues:[]},i);d instanceof Promise?c.push(d.then(m=>Rt(m,o,a))):Rt(d,o,a)}}return c.length?Promise.all(c).then(()=>o):o}});function Rt(e,t,n){e.issues.length&&t.issues.push(...fe(n,e.issues)),t.value[n]=e.value}const bp=v("$ZodRecord",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{const o=n.value;if(!Be(o))return n.issues.push({expected:"record",code:"invalid_type",input:o,inst:e}),n;const i=[];if(t.keyType._zod.values){const s=t.keyType._zod.values;n.value={};for(const a of s)if(typeof a=="string"||typeof a=="number"||typeof a=="symbol"){const u=t.valueType._zod.run({value:o[a],issues:[]},r);u instanceof Promise?i.push(u.then(l=>{l.issues.length&&n.issues.push(...fe(a,l.issues)),n.value[a]=l.value})):(u.issues.length&&n.issues.push(...fe(a,u.issues)),n.value[a]=u.value)}let c;for(const a in o)s.has(a)||(c=c??[],c.push(a));c&&c.length>0&&n.issues.push({code:"unrecognized_keys",input:o,inst:e,keys:c})}else{n.value={};for(const s of Reflect.ownKeys(o)){if(s==="__proto__")continue;const c=t.keyType._zod.run({value:s,issues:[]},r);if(c instanceof Promise)throw new Error("Async schemas not supported in object keys currently");if(c.issues.length){n.issues.push({code:"invalid_key",origin:"record",issues:c.issues.map(u=>he(u,r,ce())),input:s,path:[s],inst:e}),n.value[c.value]=c.value;continue}const a=t.valueType._zod.run({value:o[s],issues:[]},r);a instanceof Promise?i.push(a.then(u=>{u.issues.length&&n.issues.push(...fe(s,u.issues)),n.value[c.value]=u.value})):(a.issues.length&&n.issues.push(...fe(s,a.issues)),n.value[c.value]=a.value)}}return i.length?Promise.all(i).then(()=>n):n}}),yp=v("$ZodMap",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{const o=n.value;if(!(o instanceof Map))return n.issues.push({expected:"map",code:"invalid_type",input:o,inst:e}),n;const i=[];n.value=new Map;for(const[s,c]of o){const a=t.keyType._zod.run({value:s,issues:[]},r),u=t.valueType._zod.run({value:c,issues:[]},r);a instanceof Promise||u instanceof Promise?i.push(Promise.all([a,u]).then(([l,d])=>{Xr(l,d,n,s,o,e,r)})):Xr(a,u,n,s,o,e,r)}return i.length?Promise.all(i).then(()=>n):n}});function Xr(e,t,n,r,o,i,s){e.issues.length&&(Ht.has(typeof r)?n.issues.push(...fe(r,e.issues)):n.issues.push({code:"invalid_key",origin:"map",input:o,inst:i,issues:e.issues.map(c=>he(c,s,ce()))})),t.issues.length&&(Ht.has(typeof r)?n.issues.push(...fe(r,t.issues)):n.issues.push({origin:"map",code:"invalid_element",input:o,inst:i,key:r,issues:t.issues.map(c=>he(c,s,ce()))})),n.value.set(e.value,t.value)}const _p=v("$ZodSet",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{const o=n.value;if(!(o instanceof Set))return n.issues.push({input:o,inst:e,expected:"set",code:"invalid_type"}),n;const i=[];n.value=new Set;for(const s of o){const c=t.valueType._zod.run({value:s,issues:[]},r);c instanceof Promise?i.push(c.then(a=>qr(a,n))):qr(c,n)}return i.length?Promise.all(i).then(()=>n):n}});function qr(e,t){e.issues.length&&t.issues.push(...e.issues),t.value.add(e.value)}const xp=v("$ZodEnum",(e,t)=>{T.init(e,t);const n=ni(t.entries),r=new Set(n);e._zod.values=r,e._zod.pattern=new RegExp(`^(${n.filter(o=>Ht.has(typeof o)).map(o=>typeof o=="string"?Ne(o):o.toString()).join("|")})$`),e._zod.parse=(o,i)=>{const s=o.value;return r.has(s)||o.issues.push({code:"invalid_value",values:n,input:s,inst:e}),o}}),Sp=v("$ZodLiteral",(e,t)=>{if(T.init(e,t),t.values.length===0)throw new Error("Cannot create literal schema with no valid values");e._zod.values=new Set(t.values),e._zod.pattern=new RegExp(`^(${t.values.map(n=>typeof n=="string"?Ne(n):n?Ne(n.toString()):String(n)).join("|")})$`),e._zod.parse=(n,r)=>{const o=n.value;return e._zod.values.has(o)||n.issues.push({code:"invalid_value",values:t.values,input:o,inst:e}),n}}),Ep=v("$ZodFile",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{const o=n.value;return o instanceof File||n.issues.push({expected:"file",code:"invalid_type",input:o,inst:e}),n}}),Cp=v("$ZodTransform",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{if(r.direction==="backward")throw new ur(e.constructor.name);const o=t.transform(n.value,n);if(r.async)return(o instanceof Promise?o:Promise.resolve(o)).then(s=>(n.value=s,n));if(o instanceof Promise)throw new Je;return n.value=o,n}});function Jr(e,t){return e.issues.length&&t===void 0?{issues:[],value:void 0}:e}const zp=v("$ZodOptional",(e,t)=>{T.init(e,t),e._zod.optin="optional",e._zod.optout="optional",N(e._zod,"values",()=>t.innerType._zod.values?new Set([...t.innerType._zod.values,void 0]):void 0),N(e._zod,"pattern",()=>{const n=t.innerType._zod.pattern;return n?new RegExp(`^(${cn(n.source)})?$`):void 0}),e._zod.parse=(n,r)=>{if(t.innerType._zod.optin==="optional"){const o=t.innerType._zod.run(n,r);return o instanceof Promise?o.then(i=>Jr(i,n.value)):Jr(o,n.value)}return n.value===void 0?n:t.innerType._zod.run(n,r)}}),kp=v("$ZodNullable",(e,t)=>{T.init(e,t),N(e._zod,"optin",()=>t.innerType._zod.optin),N(e._zod,"optout",()=>t.innerType._zod.optout),N(e._zod,"pattern",()=>{const n=t.innerType._zod.pattern;return n?new RegExp(`^(${cn(n.source)}|null)$`):void 0}),N(e._zod,"values",()=>t.innerType._zod.values?new Set([...t.innerType._zod.values,null]):void 0),e._zod.parse=(n,r)=>n.value===null?n:t.innerType._zod.run(n,r)}),Ap=v("$ZodDefault",(e,t)=>{T.init(e,t),e._zod.optin="optional",N(e._zod,"values",()=>t.innerType._zod.values),e._zod.parse=(n,r)=>{if(r.direction==="backward")return t.innerType._zod.run(n,r);if(n.value===void 0)return n.value=t.defaultValue,n;const o=t.innerType._zod.run(n,r);return o instanceof Promise?o.then(i=>Qr(i,t)):Qr(o,t)}});function Qr(e,t){return e.value===void 0&&(e.value=t.defaultValue),e}const $p=v("$ZodPrefault",(e,t)=>{T.init(e,t),e._zod.optin="optional",N(e._zod,"values",()=>t.innerType._zod.values),e._zod.parse=(n,r)=>(r.direction==="backward"||n.value===void 0&&(n.value=t.defaultValue),t.innerType._zod.run(n,r))}),Pp=v("$ZodNonOptional",(e,t)=>{T.init(e,t),N(e._zod,"values",()=>{const n=t.innerType._zod.values;return n?new Set([...n].filter(r=>r!==void 0)):void 0}),e._zod.parse=(n,r)=>{const o=t.innerType._zod.run(n,r);return o instanceof Promise?o.then(i=>eo(i,e)):eo(o,e)}});function eo(e,t){return!e.issues.length&&e.value===void 0&&e.issues.push({code:"invalid_type",expected:"nonoptional",input:e.value,inst:t}),e}const Tp=v("$ZodSuccess",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>{if(r.direction==="backward")throw new ur("ZodSuccess");const o=t.innerType._zod.run(n,r);return o instanceof Promise?o.then(i=>(n.value=i.issues.length===0,n)):(n.value=o.issues.length===0,n)}}),Ip=v("$ZodCatch",(e,t)=>{T.init(e,t),N(e._zod,"optin",()=>t.innerType._zod.optin),N(e._zod,"optout",()=>t.innerType._zod.optout),N(e._zod,"values",()=>t.innerType._zod.values),e._zod.parse=(n,r)=>{if(r.direction==="backward")return t.innerType._zod.run(n,r);const o=t.innerType._zod.run(n,r);return o instanceof Promise?o.then(i=>(n.value=i.value,i.issues.length&&(n.value=t.catchValue({...n,error:{issues:i.issues.map(s=>he(s,r,ce()))},input:n.value}),n.issues=[]),n)):(n.value=o.value,o.issues.length&&(n.value=t.catchValue({...n,error:{issues:o.issues.map(i=>he(i,r,ce()))},input:n.value}),n.issues=[]),n)}}),Rp=v("$ZodNaN",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>((typeof n.value!="number"||!Number.isNaN(n.value))&&n.issues.push({input:n.value,inst:e,expected:"nan",code:"invalid_type"}),n)}),Np=v("$ZodPipe",(e,t)=>{T.init(e,t),N(e._zod,"values",()=>t.in._zod.values),N(e._zod,"optin",()=>t.in._zod.optin),N(e._zod,"optout",()=>t.out._zod.optout),N(e._zod,"propValues",()=>t.in._zod.propValues),e._zod.parse=(n,r)=>{if(r.direction==="backward"){const i=t.out._zod.run(n,r);return i instanceof Promise?i.then(s=>Nt(s,t.in,r)):Nt(i,t.in,r)}const o=t.in._zod.run(n,r);return o instanceof Promise?o.then(i=>Nt(i,t.out,r)):Nt(o,t.out,r)}});function Nt(e,t,n){return e.issues.length?(e.aborted=!0,e):t._zod.run({value:e.value,issues:e.issues},n)}const bs=v("$ZodCodec",(e,t)=>{T.init(e,t),N(e._zod,"values",()=>t.in._zod.values),N(e._zod,"optin",()=>t.in._zod.optin),N(e._zod,"optout",()=>t.out._zod.optout),N(e._zod,"propValues",()=>t.in._zod.propValues),e._zod.parse=(n,r)=>{if((r.direction||"forward")==="forward"){const i=t.in._zod.run(n,r);return i instanceof Promise?i.then(s=>Zt(s,t,r)):Zt(i,t,r)}else{const i=t.out._zod.run(n,r);return i instanceof Promise?i.then(s=>Zt(s,t,r)):Zt(i,t,r)}}});function Zt(e,t,n){if(e.issues.length)return e.aborted=!0,e;if((n.direction||"forward")==="forward"){const o=t.transform(e.value,e);return o instanceof Promise?o.then(i=>Ot(e,i,t.out,n)):Ot(e,o,t.out,n)}else{const o=t.reverseTransform(e.value,e);return o instanceof Promise?o.then(i=>Ot(e,i,t.in,n)):Ot(e,o,t.in,n)}}function Ot(e,t,n,r){return e.issues.length?(e.aborted=!0,e):n._zod.run({value:t,issues:e.issues},r)}const Zp=v("$ZodReadonly",(e,t)=>{T.init(e,t),N(e._zod,"propValues",()=>t.innerType._zod.propValues),N(e._zod,"values",()=>t.innerType._zod.values),N(e._zod,"optin",()=>t.innerType._zod.optin),N(e._zod,"optout",()=>t.innerType._zod.optout),e._zod.parse=(n,r)=>{if(r.direction==="backward")return t.innerType._zod.run(n,r);const o=t.innerType._zod.run(n,r);return o instanceof Promise?o.then(to):to(o)}});function to(e){return e.value=Object.freeze(e.value),e}const Op=v("$ZodTemplateLiteral",(e,t)=>{T.init(e,t);const n=[];for(const r of t.parts)if(typeof r=="object"&&r!==null){if(!r._zod.pattern)throw new Error(`Invalid template literal part, no pattern found: ${[...r._zod.traits].shift()}`);const o=r._zod.pattern instanceof RegExp?r._zod.pattern.source:r._zod.pattern;if(!o)throw new Error(`Invalid template literal part: ${r._zod.traits}`);const i=o.startsWith("^")?1:0,s=o.endsWith("$")?o.length-1:o.length;n.push(o.slice(i,s))}else if(r===null||ii.has(typeof r))n.push(Ne(`${r}`));else throw new Error(`Invalid template literal part: ${r}`);e._zod.pattern=new RegExp(`^${n.join("")}$`),e._zod.parse=(r,o)=>typeof r.value!="string"?(r.issues.push({input:r.value,inst:e,expected:"template_literal",code:"invalid_type"}),r):(e._zod.pattern.lastIndex=0,e._zod.pattern.test(r.value)||r.issues.push({input:r.value,inst:e,code:"invalid_format",format:t.format??"template_literal",pattern:e._zod.pattern.source}),r)}),Dp=v("$ZodFunction",(e,t)=>(T.init(e,t),e._def=t,e._zod.def=t,e.implement=n=>{if(typeof n!="function")throw new Error("implement() must be called with a function");return function(...r){const o=e._def.input?Vr(e._def.input,r):r,i=Reflect.apply(n,this,o);return e._def.output?Vr(e._def.output,i):i}},e.implementAsync=n=>{if(typeof n!="function")throw new Error("implementAsync() must be called with a function");return async function(...r){const o=e._def.input?await Wr(e._def.input,r):r,i=await Reflect.apply(n,this,o);return e._def.output?await Wr(e._def.output,i):i}},e._zod.parse=(n,r)=>typeof n.value!="function"?(n.issues.push({code:"invalid_type",expected:"function",input:n.value,inst:e}),n):(e._def.output&&e._def.output._zod.def.type==="promise"?n.value=e.implementAsync(n.value):n.value=e.implement(n.value),n),e.input=(...n)=>{const r=e.constructor;return Array.isArray(n[0])?new r({type:"function",input:new ws({type:"tuple",items:n[0],rest:n[1]}),output:e._def.output}):new r({type:"function",input:n[0],output:e._def.output})},e.output=n=>{const r=e.constructor;return new r({type:"function",input:e._def.input,output:n})},e)),Mp=v("$ZodPromise",(e,t)=>{T.init(e,t),e._zod.parse=(n,r)=>Promise.resolve(n.value).then(o=>t.innerType._zod.run({value:o,issues:[]},r))}),jp=v("$ZodLazy",(e,t)=>{T.init(e,t),N(e._zod,"innerType",()=>t.getter()),N(e._zod,"pattern",()=>e._zod.innerType._zod.pattern),N(e._zod,"propValues",()=>e._zod.innerType._zod.propValues),N(e._zod,"optin",()=>e._zod.innerType._zod.optin??void 0),N(e._zod,"optout",()=>e._zod.innerType._zod.optout??void 0),e._zod.parse=(n,r)=>e._zod.innerType._zod.run(n,r)}),Lp=v("$ZodCustom",(e,t)=>{J.init(e,t),T.init(e,t),e._zod.parse=(n,r)=>n,e._zod.check=n=>{const r=n.value,o=t.fn(r);if(o instanceof Promise)return o.then(i=>no(i,n,r,e));no(o,n,r,e)}});function no(e,t,n,r){if(!e){const o={code:"custom",input:n,inst:r,path:[...r._zod.def.path??[]],continue:!r._zod.def.abort};r._zod.def.params&&(o.params=r._zod.def.params),t.issues.push(tt(o))}}const Vv=Symbol("ZodOutput"),Wv=Symbol("ZodInput");class Fp{constructor(){this._map=new WeakMap,this._idmap=new Map}add(t,...n){const r=n[0];if(this._map.set(t,r),r&&typeof r=="object"&&"id"in r){if(this._idmap.has(r.id))throw new Error(`ID ${r.id} already exists in the registry`);this._idmap.set(r.id,t)}return this}clear(){return this._map=new WeakMap,this._idmap=new Map,this}remove(t){const n=this._map.get(t);return n&&typeof n=="object"&&"id"in n&&this._idmap.delete(n.id),this._map.delete(t),this}get(t){const n=t._zod.parent;if(n){const r={...this.get(n)??{}};delete r.id;const o={...r,...this._map.get(t)};return Object.keys(o).length?o:void 0}return this._map.get(t)}has(t){return this._map.has(t)}}function Bp(){return new Fp}const Dt=Bp();function Up(e,t){return new e({type:"string",...S(t)})}function Hv(e,t){return new e({type:"string",coerce:!0,...S(t)})}function ys(e,t){return new e({type:"string",format:"email",check:"string_format",abort:!1,...S(t)})}function Bn(e,t){return new e({type:"string",format:"guid",check:"string_format",abort:!1,...S(t)})}function _s(e,t){return new e({type:"string",format:"uuid",check:"string_format",abort:!1,...S(t)})}function xs(e,t){return new e({type:"string",format:"uuid",check:"string_format",abort:!1,version:"v4",...S(t)})}function Ss(e,t){return new e({type:"string",format:"uuid",check:"string_format",abort:!1,version:"v6",...S(t)})}function Es(e,t){return new e({type:"string",format:"uuid",check:"string_format",abort:!1,version:"v7",...S(t)})}function pr(e,t){return new e({type:"string",format:"url",check:"string_format",abort:!1,...S(t)})}function Cs(e,t){return new e({type:"string",format:"emoji",check:"string_format",abort:!1,...S(t)})}function zs(e,t){return new e({type:"string",format:"nanoid",check:"string_format",abort:!1,...S(t)})}function ks(e,t){return new e({type:"string",format:"cuid",check:"string_format",abort:!1,...S(t)})}function As(e,t){return new e({type:"string",format:"cuid2",check:"string_format",abort:!1,...S(t)})}function $s(e,t){return new e({type:"string",format:"ulid",check:"string_format",abort:!1,...S(t)})}function Ps(e,t){return new e({type:"string",format:"xid",check:"string_format",abort:!1,...S(t)})}function Ts(e,t){return new e({type:"string",format:"ksuid",check:"string_format",abort:!1,...S(t)})}function Is(e,t){return new e({type:"string",format:"ipv4",check:"string_format",abort:!1,...S(t)})}function Rs(e,t){return new e({type:"string",format:"ipv6",check:"string_format",abort:!1,...S(t)})}function Ns(e,t){return new e({type:"string",format:"cidrv4",check:"string_format",abort:!1,...S(t)})}function Zs(e,t){return new e({type:"string",format:"cidrv6",check:"string_format",abort:!1,...S(t)})}function Os(e,t){return new e({type:"string",format:"base64",check:"string_format",abort:!1,...S(t)})}function Ds(e,t){return new e({type:"string",format:"base64url",check:"string_format",abort:!1,...S(t)})}function Ms(e,t){return new e({type:"string",format:"e164",check:"string_format",abort:!1,...S(t)})}function js(e,t){return new e({type:"string",format:"jwt",check:"string_format",abort:!1,...S(t)})}const Kv={Any:null,Minute:-1,Second:0,Millisecond:3,Microsecond:6};function Vp(e,t){return new e({type:"string",format:"datetime",check:"string_format",offset:!1,local:!1,precision:null,...S(t)})}function Wp(e,t){return new e({type:"string",format:"date",check:"string_format",...S(t)})}function Hp(e,t){return new e({type:"string",format:"time",check:"string_format",precision:null,...S(t)})}function Kp(e,t){return new e({type:"string",format:"duration",check:"string_format",...S(t)})}function Gp(e,t){return new e({type:"number",checks:[],...S(t)})}function Gv(e,t){return new e({type:"number",coerce:!0,checks:[],...S(t)})}function Yp(e,t){return new e({type:"number",check:"number_format",abort:!1,format:"safeint",...S(t)})}function Xp(e,t){return new e({type:"number",check:"number_format",abort:!1,format:"float32",...S(t)})}function qp(e,t){return new e({type:"number",check:"number_format",abort:!1,format:"float64",...S(t)})}function Jp(e,t){return new e({type:"number",check:"number_format",abort:!1,format:"int32",...S(t)})}function Qp(e,t){return new e({type:"number",check:"number_format",abort:!1,format:"uint32",...S(t)})}function eh(e,t){return new e({type:"boolean",...S(t)})}function Yv(e,t){return new e({type:"boolean",coerce:!0,...S(t)})}function th(e,t){return new e({type:"bigint",...S(t)})}function Xv(e,t){return new e({type:"bigint",coerce:!0,...S(t)})}function nh(e,t){return new e({type:"bigint",check:"bigint_format",abort:!1,format:"int64",...S(t)})}function rh(e,t){return new e({type:"bigint",check:"bigint_format",abort:!1,format:"uint64",...S(t)})}function oh(e,t){return new e({type:"symbol",...S(t)})}function ih(e,t){return new e({type:"undefined",...S(t)})}function sh(e,t){return new e({type:"null",...S(t)})}function ch(e){return new e({type:"any"})}function ah(e){return new e({type:"unknown"})}function uh(e,t){return new e({type:"never",...S(t)})}function lh(e,t){return new e({type:"void",...S(t)})}function fh(e,t){return new e({type:"date",...S(t)})}function qv(e,t){return new e({type:"date",coerce:!0,...S(t)})}function dh(e,t){return new e({type:"nan",...S(t)})}function vt(e,t){return new us({check:"less_than",...S(t),value:e,inclusive:!1})}function Pe(e,t){return new us({check:"less_than",...S(t),value:e,inclusive:!0})}function gt(e,t){return new ls({check:"greater_than",...S(t),value:e,inclusive:!1})}function ge(e,t){return new ls({check:"greater_than",...S(t),value:e,inclusive:!0})}function Jv(e){return gt(0,e)}function Qv(e){return vt(0,e)}function eg(e){return Pe(0,e)}function tg(e){return ge(0,e)}function Un(e,t){return new dd({check:"multiple_of",...S(t),value:e})}function Ls(e,t){return new md({check:"max_size",...S(t),maximum:e})}function Vn(e,t){return new vd({check:"min_size",...S(t),minimum:e})}function ph(e,t){return new gd({check:"size_equals",...S(t),size:e})}function Fs(e,t){return new wd({check:"max_length",...S(t),maximum:e})}function Gt(e,t){return new bd({check:"min_length",...S(t),minimum:e})}function Bs(e,t){return new yd({check:"length_equals",...S(t),length:e})}function hh(e,t){return new _d({check:"string_format",format:"regex",...S(t),pattern:e})}function mh(e){return new xd({check:"string_format",format:"lowercase",...S(e)})}function vh(e){return new Sd({check:"string_format",format:"uppercase",...S(e)})}function gh(e,t){return new Ed({check:"string_format",format:"includes",...S(t),includes:e})}function wh(e,t){return new Cd({check:"string_format",format:"starts_with",...S(t),prefix:e})}function bh(e,t){return new zd({check:"string_format",format:"ends_with",...S(t),suffix:e})}function ng(e,t,n){return new kd({check:"property",property:e,schema:t,...S(n)})}function yh(e,t){return new Ad({check:"mime_type",mime:e,...S(t)})}function Et(e){return new $d({check:"overwrite",tx:e})}function _h(e){return Et(t=>t.normalize(e))}function xh(){return Et(e=>e.trim())}function Sh(){return Et(e=>e.toLowerCase())}function Eh(){return Et(e=>e.toUpperCase())}function Ch(e,t,n){return new e({type:"array",element:t,...S(n)})}function rg(e,t,n){return new e({type:"union",options:t,...S(n)})}function og(e,t,n,r){return new e({type:"union",options:n,discriminator:t,...S(r)})}function ig(e,t,n){return new e({type:"intersection",left:t,right:n})}function sg(e,t,n,r){const o=n instanceof T,i=o?r:n,s=o?n:null;return new e({type:"tuple",items:t,rest:s,...S(i)})}function cg(e,t,n,r){return new e({type:"record",keyType:t,valueType:n,...S(r)})}function ag(e,t,n,r){return new e({type:"map",keyType:t,valueType:n,...S(r)})}function ug(e,t,n){return new e({type:"set",valueType:t,...S(n)})}function lg(e,t,n){const r=Array.isArray(t)?Object.fromEntries(t.map(o=>[o,o])):t;return new e({type:"enum",entries:r,...S(n)})}function fg(e,t,n){return new e({type:"enum",entries:t,...S(n)})}function dg(e,t,n){return new e({type:"literal",values:Array.isArray(t)?t:[t],...S(n)})}function zh(e,t){return new e({type:"file",...S(t)})}function pg(e,t){return new e({type:"transform",transform:t})}function hg(e,t){return new e({type:"optional",innerType:t})}function mg(e,t){return new e({type:"nullable",innerType:t})}function vg(e,t,n){return new e({type:"default",innerType:t,get defaultValue(){return typeof n=="function"?n():an(n)}})}function gg(e,t,n){return new e({type:"nonoptional",innerType:t,...S(n)})}function wg(e,t){return new e({type:"success",innerType:t})}function bg(e,t,n){return new e({type:"catch",innerType:t,catchValue:typeof n=="function"?n:()=>n})}function yg(e,t,n){return new e({type:"pipe",in:t,out:n})}function _g(e,t){return new e({type:"readonly",innerType:t})}function xg(e,t,n){return new e({type:"template_literal",parts:t,...S(n)})}function Sg(e,t){return new e({type:"lazy",getter:t})}function Eg(e,t){return new e({type:"promise",innerType:t})}function kh(e,t,n){const r=S(n);return r.abort??(r.abort=!0),new e({type:"custom",check:"custom",fn:t,...r})}function Ah(e,t,n){return new e({type:"custom",check:"custom",fn:t,...S(n)})}function $h(e){const t=Ph(n=>(n.addIssue=r=>{if(typeof r=="string")n.issues.push(tt(r,n.value,t._zod.def));else{const o=r;o.fatal&&(o.continue=!1),o.code??(o.code="custom"),o.input??(o.input=n.value),o.inst??(o.inst=t),o.continue??(o.continue=!t._zod.def.abort),n.issues.push(tt(o))}},e(n.value,n)));return t}function Ph(e,t){const n=new J({check:"custom",...S(t)});return n._zod.check=e,n}function Th(e,t){const n=S(t);let r=n.truthy??["true","1","yes","on","y","enabled"],o=n.falsy??["false","0","no","off","n","disabled"];n.case!=="sensitive"&&(r=r.map(h=>typeof h=="string"?h.toLowerCase():h),o=o.map(h=>typeof h=="string"?h.toLowerCase():h));const i=new Set(r),s=new Set(o),c=e.Codec??bs,a=e.Boolean??ps,u=e.String??vn,l=new u({type:"string",error:n.error}),d=new a({type:"boolean",error:n.error}),m=new c({type:"pipe",in:l,out:d,transform:((h,w)=>{let p=h;return n.case!=="sensitive"&&(p=p.toLowerCase()),i.has(p)?!0:s.has(p)?!1:(w.issues.push({code:"invalid_value",expected:"stringbool",values:[...i,...s],input:w.value,inst:m,continue:!1}),{})}),reverseTransform:((h,w)=>h===!0?r[0]||"true":o[0]||"false"),error:n.error});return m}function gn(e,t,n,r={}){const o=S(r),i={...S(r),check:"string_format",type:"string",format:t,fn:typeof n=="function"?n:c=>n.test(c),...o};return n instanceof RegExp&&(i.pattern=n),new e(i)}const Us=v("ZodISODateTime",(e,t)=>{Ud.init(e,t),X.init(e,t)});function Vs(e){return Vp(Us,e)}const Ws=v("ZodISODate",(e,t)=>{Vd.init(e,t),X.init(e,t)});function Hs(e){return Wp(Ws,e)}const Ks=v("ZodISOTime",(e,t)=>{Wd.init(e,t),X.init(e,t)});function Gs(e){return Hp(Ks,e)}const Ys=v("ZodISODuration",(e,t)=>{Hd.init(e,t),X.init(e,t)});function Xs(e){return Kp(Ys,e)}const Cg=Object.freeze(Object.defineProperty({__proto__:null,ZodISODate:Ws,ZodISODateTime:Us,ZodISODuration:Ys,ZodISOTime:Ks,date:Hs,datetime:Vs,duration:Xs,time:Gs},Symbol.toStringTag,{value:"Module"})),qs=(e,t)=>{yi.init(e,t),e.name="ZodError",Object.defineProperties(e,{format:{value:n=>Df(e,n)},flatten:{value:n=>Of(e,n)},addIssue:{value:n=>{e.issues.push(n),e.message=JSON.stringify(e.issues,Wt,2)}},addIssues:{value:n=>{e.issues.push(...n),e.message=JSON.stringify(e.issues,Wt,2)}},isEmpty:{get(){return e.issues.length===0}}})},zg=v("ZodError",qs),ue=v("ZodError",qs,{Parent:Error}),Ih=fn(ue),Rh=dn(ue),Nh=pn(ue),Zh=hn(ue),Oh=_i(ue),Dh=xi(ue),Mh=Si(ue),jh=Ei(ue),Lh=Ci(ue),Fh=zi(ue),Bh=ki(ue),Uh=Ai(ue),R=v("ZodType",(e,t)=>(T.init(e,t),e.def=t,e.type=t.type,Object.defineProperty(e,"_def",{value:t}),e.check=(...n)=>e.clone(ze(t,{checks:[...t.checks??[],...n.map(r=>typeof r=="function"?{_zod:{check:r,def:{check:"custom"},onattach:[]}}:r)]})),e.clone=(n,r)=>xe(e,n,r),e.brand=()=>e,e.register=((n,r)=>(n.add(e,r),e)),e.parse=(n,r)=>Ih(e,n,r,{callee:e.parse}),e.safeParse=(n,r)=>Nh(e,n,r),e.parseAsync=async(n,r)=>Rh(e,n,r,{callee:e.parseAsync}),e.safeParseAsync=async(n,r)=>Zh(e,n,r),e.spa=e.safeParseAsync,e.encode=(n,r)=>Oh(e,n,r),e.decode=(n,r)=>Dh(e,n,r),e.encodeAsync=async(n,r)=>Mh(e,n,r),e.decodeAsync=async(n,r)=>jh(e,n,r),e.safeEncode=(n,r)=>Lh(e,n,r),e.safeDecode=(n,r)=>Fh(e,n,r),e.safeEncodeAsync=async(n,r)=>Bh(e,n,r),e.safeDecodeAsync=async(n,r)=>Uh(e,n,r),e.refine=(n,r)=>e.check(Pm(n,r)),e.superRefine=n=>e.check(Tm(n)),e.overwrite=n=>e.check(Et(n)),e.optional=()=>Hn(e),e.nullable=()=>Kn(e),e.nullish=()=>Hn(Kn(e)),e.nonoptional=n=>wm(e,n),e.array=()=>mr(e),e.or=n=>xc([e,n]),e.and=n=>om(e,n),e.transform=n=>Gn(e,Cc(n)),e.default=n=>mm(e,n),e.prefault=n=>gm(e,n),e.catch=n=>_m(e,n),e.pipe=n=>Gn(e,n),e.readonly=()=>Em(e),e.describe=n=>{const r=e.clone();return Dt.add(r,{description:n}),r},Object.defineProperty(e,"description",{get(){var n;return(n=Dt.get(e))==null?void 0:n.description},configurable:!0}),e.meta=(...n)=>{if(n.length===0)return Dt.get(e);const r=e.clone();return Dt.add(r,n[0]),r},e.isOptional=()=>e.safeParse(void 0).success,e.isNullable=()=>e.safeParse(null).success,e)),Js=v("_ZodString",(e,t)=>{vn.init(e,t),R.init(e,t);const n=e._zod.bag;e.format=n.format??null,e.minLength=n.minimum??null,e.maxLength=n.maximum??null,e.regex=(...r)=>e.check(hh(...r)),e.includes=(...r)=>e.check(gh(...r)),e.startsWith=(...r)=>e.check(wh(...r)),e.endsWith=(...r)=>e.check(bh(...r)),e.min=(...r)=>e.check(Gt(...r)),e.max=(...r)=>e.check(Fs(...r)),e.length=(...r)=>e.check(Bs(...r)),e.nonempty=(...r)=>e.check(Gt(1,...r)),e.lowercase=r=>e.check(mh(r)),e.uppercase=r=>e.check(vh(r)),e.trim=()=>e.check(xh()),e.normalize=(...r)=>e.check(_h(...r)),e.toLowerCase=()=>e.check(Sh()),e.toUpperCase=()=>e.check(Eh())}),Qs=v("ZodString",(e,t)=>{vn.init(e,t),Js.init(e,t),e.email=n=>e.check(ys(ec,n)),e.url=n=>e.check(pr(hr,n)),e.jwt=n=>e.check(js(mc,n)),e.emoji=n=>e.check(Cs(tc,n)),e.guid=n=>e.check(Bn(Wn,n)),e.uuid=n=>e.check(_s($e,n)),e.uuidv4=n=>e.check(xs($e,n)),e.uuidv6=n=>e.check(Ss($e,n)),e.uuidv7=n=>e.check(Es($e,n)),e.nanoid=n=>e.check(zs(nc,n)),e.guid=n=>e.check(Bn(Wn,n)),e.cuid=n=>e.check(ks(rc,n)),e.cuid2=n=>e.check(As(oc,n)),e.ulid=n=>e.check($s(ic,n)),e.base64=n=>e.check(Os(dc,n)),e.base64url=n=>e.check(Ds(pc,n)),e.xid=n=>e.check(Ps(sc,n)),e.ksuid=n=>e.check(Ts(cc,n)),e.ipv4=n=>e.check(Is(ac,n)),e.ipv6=n=>e.check(Rs(uc,n)),e.cidrv4=n=>e.check(Ns(lc,n)),e.cidrv6=n=>e.check(Zs(fc,n)),e.e164=n=>e.check(Ms(hc,n)),e.datetime=n=>e.check(Vs(n)),e.date=n=>e.check(Hs(n)),e.time=n=>e.check(Gs(n)),e.duration=n=>e.check(Xs(n))});function ro(e){return Up(Qs,e)}const X=v("ZodStringFormat",(e,t)=>{Y.init(e,t),Js.init(e,t)}),ec=v("ZodEmail",(e,t)=>{Nd.init(e,t),X.init(e,t)});function kg(e){return ys(ec,e)}const Wn=v("ZodGUID",(e,t)=>{Id.init(e,t),X.init(e,t)});function Ag(e){return Bn(Wn,e)}const $e=v("ZodUUID",(e,t)=>{Rd.init(e,t),X.init(e,t)});function $g(e){return _s($e,e)}function Pg(e){return xs($e,e)}function Tg(e){return Ss($e,e)}function Ig(e){return Es($e,e)}const hr=v("ZodURL",(e,t)=>{Zd.init(e,t),X.init(e,t)});function Rg(e){return pr(hr,e)}function Ng(e){return pr(hr,{protocol:/^https?$/,hostname:Wi,...S(e)})}const tc=v("ZodEmoji",(e,t)=>{Od.init(e,t),X.init(e,t)});function Zg(e){return Cs(tc,e)}const nc=v("ZodNanoID",(e,t)=>{Dd.init(e,t),X.init(e,t)});function Og(e){return zs(nc,e)}const rc=v("ZodCUID",(e,t)=>{Md.init(e,t),X.init(e,t)});function Dg(e){return ks(rc,e)}const oc=v("ZodCUID2",(e,t)=>{jd.init(e,t),X.init(e,t)});function Mg(e){return As(oc,e)}const ic=v("ZodULID",(e,t)=>{Ld.init(e,t),X.init(e,t)});function jg(e){return $s(ic,e)}const sc=v("ZodXID",(e,t)=>{Fd.init(e,t),X.init(e,t)});function Lg(e){return Ps(sc,e)}const cc=v("ZodKSUID",(e,t)=>{Bd.init(e,t),X.init(e,t)});function Fg(e){return Ts(cc,e)}const ac=v("ZodIPv4",(e,t)=>{Kd.init(e,t),X.init(e,t)});function Bg(e){return Is(ac,e)}const uc=v("ZodIPv6",(e,t)=>{Gd.init(e,t),X.init(e,t)});function Ug(e){return Rs(uc,e)}const lc=v("ZodCIDRv4",(e,t)=>{Yd.init(e,t),X.init(e,t)});function Vg(e){return Ns(lc,e)}const fc=v("ZodCIDRv6",(e,t)=>{Xd.init(e,t),X.init(e,t)});function Wg(e){return Zs(fc,e)}const dc=v("ZodBase64",(e,t)=>{qd.init(e,t),X.init(e,t)});function Hg(e){return Os(dc,e)}const pc=v("ZodBase64URL",(e,t)=>{Qd.init(e,t),X.init(e,t)});function Kg(e){return Ds(pc,e)}const hc=v("ZodE164",(e,t)=>{ep.init(e,t),X.init(e,t)});function Gg(e){return Ms(hc,e)}const mc=v("ZodJWT",(e,t)=>{np.init(e,t),X.init(e,t)});function Yg(e){return js(mc,e)}const wn=v("ZodCustomStringFormat",(e,t)=>{rp.init(e,t),X.init(e,t)});function Xg(e,t,n={}){return gn(wn,e,t,n)}function qg(e){return gn(wn,"hostname",dr,e)}function Jg(e){return gn(wn,"hex",cs,e)}function Qg(e,t){const n=(t==null?void 0:t.enc)??"hex",r=`${e}_${n}`,o=fd[r];if(!o)throw new Error(`Unrecognized hash format: ${r}`);return gn(wn,r,o,t)}const vc=v("ZodNumber",(e,t)=>{ds.init(e,t),R.init(e,t),e.gt=(r,o)=>e.check(gt(r,o)),e.gte=(r,o)=>e.check(ge(r,o)),e.min=(r,o)=>e.check(ge(r,o)),e.lt=(r,o)=>e.check(vt(r,o)),e.lte=(r,o)=>e.check(Pe(r,o)),e.max=(r,o)=>e.check(Pe(r,o)),e.int=r=>e.check(oo(r)),e.safe=r=>e.check(oo(r)),e.positive=r=>e.check(gt(0,r)),e.nonnegative=r=>e.check(ge(0,r)),e.negative=r=>e.check(vt(0,r)),e.nonpositive=r=>e.check(Pe(0,r)),e.multipleOf=(r,o)=>e.check(Un(r,o)),e.step=(r,o)=>e.check(Un(r,o)),e.finite=()=>e;const n=e._zod.bag;e.minValue=Math.max(n.minimum??Number.NEGATIVE_INFINITY,n.exclusiveMinimum??Number.NEGATIVE_INFINITY)??null,e.maxValue=Math.min(n.maximum??Number.POSITIVE_INFINITY,n.exclusiveMaximum??Number.POSITIVE_INFINITY)??null,e.isInt=(n.format??"").includes("int")||Number.isSafeInteger(n.multipleOf??.5),e.isFinite=!0,e.format=n.format??null});function Vh(e){return Gp(vc,e)}const Ct=v("ZodNumberFormat",(e,t)=>{op.init(e,t),vc.init(e,t)});function oo(e){return Yp(Ct,e)}function ew(e){return Xp(Ct,e)}function tw(e){return qp(Ct,e)}function nw(e){return Jp(Ct,e)}function rw(e){return Qp(Ct,e)}const gc=v("ZodBoolean",(e,t)=>{ps.init(e,t),R.init(e,t)});function Wh(e){return eh(gc,e)}const wc=v("ZodBigInt",(e,t)=>{hs.init(e,t),R.init(e,t),e.gte=(r,o)=>e.check(ge(r,o)),e.min=(r,o)=>e.check(ge(r,o)),e.gt=(r,o)=>e.check(gt(r,o)),e.gte=(r,o)=>e.check(ge(r,o)),e.min=(r,o)=>e.check(ge(r,o)),e.lt=(r,o)=>e.check(vt(r,o)),e.lte=(r,o)=>e.check(Pe(r,o)),e.max=(r,o)=>e.check(Pe(r,o)),e.positive=r=>e.check(gt(BigInt(0),r)),e.negative=r=>e.check(vt(BigInt(0),r)),e.nonpositive=r=>e.check(Pe(BigInt(0),r)),e.nonnegative=r=>e.check(ge(BigInt(0),r)),e.multipleOf=(r,o)=>e.check(Un(r,o));const n=e._zod.bag;e.minValue=n.minimum??null,e.maxValue=n.maximum??null,e.format=n.format??null});function ow(e){return th(wc,e)}const bc=v("ZodBigIntFormat",(e,t)=>{ip.init(e,t),wc.init(e,t)});function iw(e){return nh(bc,e)}function sw(e){return rh(bc,e)}const Hh=v("ZodSymbol",(e,t)=>{sp.init(e,t),R.init(e,t)});function cw(e){return oh(Hh,e)}const Kh=v("ZodUndefined",(e,t)=>{cp.init(e,t),R.init(e,t)});function aw(e){return ih(Kh,e)}const Gh=v("ZodNull",(e,t)=>{ap.init(e,t),R.init(e,t)});function Yh(e){return sh(Gh,e)}const Xh=v("ZodAny",(e,t)=>{up.init(e,t),R.init(e,t)});function uw(){return ch(Xh)}const qh=v("ZodUnknown",(e,t)=>{lp.init(e,t),R.init(e,t)});function wt(){return ah(qh)}const Jh=v("ZodNever",(e,t)=>{fp.init(e,t),R.init(e,t)});function yc(e){return uh(Jh,e)}const Qh=v("ZodVoid",(e,t)=>{dp.init(e,t),R.init(e,t)});function lw(e){return lh(Qh,e)}const em=v("ZodDate",(e,t)=>{pp.init(e,t),R.init(e,t),e.min=(r,o)=>e.check(ge(r,o)),e.max=(r,o)=>e.check(Pe(r,o));const n=e._zod.bag;e.minDate=n.minimum?new Date(n.minimum):null,e.maxDate=n.maximum?new Date(n.maximum):null});function fw(e){return fh(em,e)}const tm=v("ZodArray",(e,t)=>{hp.init(e,t),R.init(e,t),e.element=t.element,e.min=(n,r)=>e.check(Gt(n,r)),e.nonempty=n=>e.check(Gt(1,n)),e.max=(n,r)=>e.check(Fs(n,r)),e.length=(n,r)=>e.check(Bs(n,r)),e.unwrap=()=>e.element});function mr(e,t){return Ch(tm,e,t)}function dw(e){const t=e._zod.def.shape;return Ec(Object.keys(t))}const vr=v("ZodObject",(e,t)=>{vp.init(e,t),R.init(e,t),N(e,"shape",()=>t.shape),e.keyof=()=>Ec(Object.keys(e._zod.def.shape)),e.catchall=n=>e.clone({...e._zod.def,catchall:n}),e.passthrough=()=>e.clone({...e._zod.def,catchall:wt()}),e.loose=()=>e.clone({...e._zod.def,catchall:wt()}),e.strict=()=>e.clone({...e._zod.def,catchall:yc()}),e.strip=()=>e.clone({...e._zod.def,catchall:void 0}),e.extend=n=>di(e,n),e.safeExtend=n=>pi(e,n),e.merge=n=>hi(e,n),e.pick=n=>li(e,n),e.omit=n=>fi(e,n),e.partial=(...n)=>mi(zc,e,n[0]),e.required=(...n)=>vi(kc,e,n[0])});function pw(e,t){const n={type:"object",shape:e??{},...S(t)};return new vr(n)}function hw(e,t){return new vr({type:"object",shape:e,catchall:yc(),...S(t)})}function mw(e,t){return new vr({type:"object",shape:e,catchall:wt(),...S(t)})}const _c=v("ZodUnion",(e,t)=>{gs.init(e,t),R.init(e,t),e.options=t.options});function xc(e,t){return new _c({type:"union",options:e,...S(t)})}const nm=v("ZodDiscriminatedUnion",(e,t)=>{_c.init(e,t),gp.init(e,t)});function vw(e,t,n){return new nm({type:"union",options:t,discriminator:e,...S(n)})}const rm=v("ZodIntersection",(e,t)=>{wp.init(e,t),R.init(e,t)});function om(e,t){return new rm({type:"intersection",left:e,right:t})}const im=v("ZodTuple",(e,t)=>{ws.init(e,t),R.init(e,t),e.rest=n=>e.clone({...e._zod.def,rest:n})});function sm(e,t,n){const r=t instanceof T,o=r?n:t,i=r?t:null;return new im({type:"tuple",items:e,rest:i,...S(o)})}const Sc=v("ZodRecord",(e,t)=>{bp.init(e,t),R.init(e,t),e.keyType=t.keyType,e.valueType=t.valueType});function cm(e,t,n){return new Sc({type:"record",keyType:e,valueType:t,...S(n)})}function gw(e,t,n){const r=xe(e);return r._zod.values=void 0,new Sc({type:"record",keyType:r,valueType:t,...S(n)})}const am=v("ZodMap",(e,t)=>{yp.init(e,t),R.init(e,t),e.keyType=t.keyType,e.valueType=t.valueType});function ww(e,t,n){return new am({type:"map",keyType:e,valueType:t,...S(n)})}const um=v("ZodSet",(e,t)=>{_p.init(e,t),R.init(e,t),e.min=(...n)=>e.check(Vn(...n)),e.nonempty=n=>e.check(Vn(1,n)),e.max=(...n)=>e.check(Ls(...n)),e.size=(...n)=>e.check(ph(...n))});function bw(e,t){return new um({type:"set",valueType:e,...S(t)})}const Yt=v("ZodEnum",(e,t)=>{xp.init(e,t),R.init(e,t),e.enum=t.entries,e.options=Object.values(t.entries);const n=new Set(Object.keys(t.entries));e.extract=(r,o)=>{const i={};for(const s of r)if(n.has(s))i[s]=t.entries[s];else throw new Error(`Key ${s} not found in enum`);return new Yt({...t,checks:[],...S(o),entries:i})},e.exclude=(r,o)=>{const i={...t.entries};for(const s of r)if(n.has(s))delete i[s];else throw new Error(`Key ${s} not found in enum`);return new Yt({...t,checks:[],...S(o),entries:i})}});function Ec(e,t){const n=Array.isArray(e)?Object.fromEntries(e.map(r=>[r,r])):e;return new Yt({type:"enum",entries:n,...S(t)})}function yw(e,t){return new Yt({type:"enum",entries:e,...S(t)})}const lm=v("ZodLiteral",(e,t)=>{Sp.init(e,t),R.init(e,t),e.values=new Set(t.values),Object.defineProperty(e,"value",{get(){if(t.values.length>1)throw new Error("This schema contains multiple valid literal values. Use `.values` instead.");return t.values[0]}})});function _w(e,t){return new lm({type:"literal",values:Array.isArray(e)?e:[e],...S(t)})}const fm=v("ZodFile",(e,t)=>{Ep.init(e,t),R.init(e,t),e.min=(n,r)=>e.check(Vn(n,r)),e.max=(n,r)=>e.check(Ls(n,r)),e.mime=(n,r)=>e.check(yh(Array.isArray(n)?n:[n],r))});function xw(e){return zh(fm,e)}const dm=v("ZodTransform",(e,t)=>{Cp.init(e,t),R.init(e,t),e._zod.parse=(n,r)=>{if(r.direction==="backward")throw new ur(e.constructor.name);n.addIssue=i=>{if(typeof i=="string")n.issues.push(tt(i,n.value,t));else{const s=i;s.fatal&&(s.continue=!1),s.code??(s.code="custom"),s.input??(s.input=n.value),s.inst??(s.inst=e),n.issues.push(tt(s))}};const o=t.transform(n.value,n);return o instanceof Promise?o.then(i=>(n.value=i,n)):(n.value=o,n)}});function Cc(e){return new dm({type:"transform",transform:e})}const zc=v("ZodOptional",(e,t)=>{zp.init(e,t),R.init(e,t),e.unwrap=()=>e._zod.def.innerType});function Hn(e){return new zc({type:"optional",innerType:e})}const pm=v("ZodNullable",(e,t)=>{kp.init(e,t),R.init(e,t),e.unwrap=()=>e._zod.def.innerType});function Kn(e){return new pm({type:"nullable",innerType:e})}function Sw(e){return Hn(Kn(e))}const hm=v("ZodDefault",(e,t)=>{Ap.init(e,t),R.init(e,t),e.unwrap=()=>e._zod.def.innerType,e.removeDefault=e.unwrap});function mm(e,t){return new hm({type:"default",innerType:e,get defaultValue(){return typeof t=="function"?t():an(t)}})}const vm=v("ZodPrefault",(e,t)=>{$p.init(e,t),R.init(e,t),e.unwrap=()=>e._zod.def.innerType});function gm(e,t){return new vm({type:"prefault",innerType:e,get defaultValue(){return typeof t=="function"?t():an(t)}})}const kc=v("ZodNonOptional",(e,t)=>{Pp.init(e,t),R.init(e,t),e.unwrap=()=>e._zod.def.innerType});function wm(e,t){return new kc({type:"nonoptional",innerType:e,...S(t)})}const bm=v("ZodSuccess",(e,t)=>{Tp.init(e,t),R.init(e,t),e.unwrap=()=>e._zod.def.innerType});function Ew(e){return new bm({type:"success",innerType:e})}const ym=v("ZodCatch",(e,t)=>{Ip.init(e,t),R.init(e,t),e.unwrap=()=>e._zod.def.innerType,e.removeCatch=e.unwrap});function _m(e,t){return new ym({type:"catch",innerType:e,catchValue:typeof t=="function"?t:()=>t})}const xm=v("ZodNaN",(e,t)=>{Rp.init(e,t),R.init(e,t)});function Cw(e){return dh(xm,e)}const Ac=v("ZodPipe",(e,t)=>{Np.init(e,t),R.init(e,t),e.in=t.in,e.out=t.out});function Gn(e,t){return new Ac({type:"pipe",in:e,out:t})}const $c=v("ZodCodec",(e,t)=>{Ac.init(e,t),bs.init(e,t)});function zw(e,t,n){return new $c({type:"pipe",in:e,out:t,transform:n.decode,reverseTransform:n.encode})}const Sm=v("ZodReadonly",(e,t)=>{Zp.init(e,t),R.init(e,t),e.unwrap=()=>e._zod.def.innerType});function Em(e){return new Sm({type:"readonly",innerType:e})}const Cm=v("ZodTemplateLiteral",(e,t)=>{Op.init(e,t),R.init(e,t)});function kw(e,t){return new Cm({type:"template_literal",parts:e,...S(t)})}const zm=v("ZodLazy",(e,t)=>{jp.init(e,t),R.init(e,t),e.unwrap=()=>e._zod.def.getter()});function km(e){return new zm({type:"lazy",getter:e})}const Am=v("ZodPromise",(e,t)=>{Mp.init(e,t),R.init(e,t),e.unwrap=()=>e._zod.def.innerType});function Aw(e){return new Am({type:"promise",innerType:e})}const $m=v("ZodFunction",(e,t)=>{Dp.init(e,t),R.init(e,t)});function $w(e){return new $m({type:"function",input:Array.isArray(e==null?void 0:e.input)?sm(e==null?void 0:e.input):(e==null?void 0:e.input)??mr(wt()),output:(e==null?void 0:e.output)??wt()})}const gr=v("ZodCustom",(e,t)=>{Lp.init(e,t),R.init(e,t)});function Pw(e){const t=new J({check:"custom"});return t._zod.check=e,t}function Tw(e,t){return kh(gr,e??(()=>!0),t)}function Pm(e,t={}){return Ah(gr,e,t)}function Tm(e){return $h(e)}function Iw(e,t={error:`Input not instance of ${e.name}`}){const n=new gr({type:"custom",check:"custom",fn:r=>r instanceof e,abort:!0,...S(t)});return n._zod.bag.Class=e,n}const Rw=(...e)=>Th({Codec:$c,Boolean:gc,String:Qs},...e);function Nw(e){const t=km(()=>xc([ro(e),Vh(),Wh(),Yh(),mr(t),cm(ro(),t)]));return t}function Zw(e,t){return Gn(Cc(e),t)}const Ow={invalid_type:"invalid_type",too_big:"too_big",too_small:"too_small",invalid_format:"invalid_format",not_multiple_of:"not_multiple_of",unrecognized_keys:"unrecognized_keys",invalid_union:"invalid_union",invalid_key:"invalid_key",invalid_element:"invalid_element",invalid_value:"invalid_value",custom:"custom"};function Dw(e){ce({customError:e})}function Mw(){return ce().customError}var io;io||(io={});function so(e,[t,n]){return Math.min(n,Math.max(t,e))}function Im(e){const t=f.useRef({value:e,previous:e});return f.useMemo(()=>(t.current.value!==e&&(t.current.previous=t.current.value,t.current.value=e),t.current.previous),[e])}var Pc=Object.freeze({position:"absolute",border:0,width:1,height:1,padding:0,margin:-1,overflow:"hidden",clip:"rect(0, 0, 0, 0)",whiteSpace:"nowrap",wordWrap:"normal"}),Rm="VisuallyHidden",Tc=f.forwardRef((e,t)=>_.jsx(q.span,{...e,ref:t,style:{...Pc,...e.style}}));Tc.displayName=Rm;var jw=Tc,Nm=[" ","Enter","ArrowUp","ArrowDown"],Zm=[" ","Enter"],Ue="Select",[bn,yn,Om]=fo(Ue),[it]=Qt(Ue,[Om,Io]),_n=Io(),[Dm,Oe]=it(Ue),[Mm,jm]=it(Ue),Ic=e=>{const{__scopeSelect:t,children:n,open:r,defaultOpen:o,onOpenChange:i,value:s,defaultValue:c,onValueChange:a,dir:u,name:l,autoComplete:d,disabled:m,required:h,form:w}=e,p=_n(t),[g,x]=f.useState(null),[y,b]=f.useState(null),[E,C]=f.useState(!1),A=po(u),[z,k]=In({prop:r,defaultProp:o??!1,onChange:i,caller:Ue}),[D,Z]=In({prop:s,defaultProp:c,onChange:a,caller:Ue}),L=f.useRef(null),U=g?w||!!g.closest("form"):!0,[M,O]=f.useState(new Set),H=Array.from(M).map(I=>I.props.value).join(";");return _.jsx(ll,{...p,children:_.jsxs(Dm,{required:h,scope:t,trigger:g,onTriggerChange:x,valueNode:y,onValueNodeChange:b,valueNodeHasChildren:E,onValueNodeHasChildrenChange:C,contentId:en(),value:D,onValueChange:Z,open:z,onOpenChange:k,dir:A,triggerPointerDownPosRef:L,disabled:m,children:[_.jsx(bn.Provider,{scope:t,children:_.jsx(Mm,{scope:e.__scopeSelect,onNativeOptionAdd:f.useCallback(I=>{O(j=>new Set(j).add(I))},[]),onNativeOptionRemove:f.useCallback(I=>{O(j=>{const $=new Set(j);return $.delete(I),$})},[]),children:n})}),U?_.jsxs(ea,{"aria-hidden":!0,required:h,tabIndex:-1,name:l,autoComplete:d,value:D,onChange:I=>Z(I.target.value),disabled:m,form:w,children:[D===void 0?_.jsx("option",{value:""}):null,Array.from(M)]},H):null]})})};Ic.displayName=Ue;var Rc="SelectTrigger",Nc=f.forwardRef((e,t)=>{const{__scopeSelect:n,disabled:r=!1,...o}=e,i=_n(n),s=Oe(Rc,n),c=s.disabled||r,a=Q(t,s.onTriggerChange),u=yn(n),l=f.useRef("touch"),[d,m,h]=na(p=>{const g=u().filter(b=>!b.disabled),x=g.find(b=>b.value===s.value),y=ra(g,p,x);y!==void 0&&s.onValueChange(y.value)}),w=p=>{c||(s.onOpenChange(!0),h()),p&&(s.triggerPointerDownPosRef.current={x:Math.round(p.pageX),y:Math.round(p.pageY)})};return _.jsx(fl,{asChild:!0,...i,children:_.jsx(q.button,{type:"button",role:"combobox","aria-controls":s.contentId,"aria-expanded":s.open,"aria-required":s.required,"aria-autocomplete":"none",dir:s.dir,"data-state":s.open?"open":"closed",disabled:c,"data-disabled":c?"":void 0,"data-placeholder":ta(s.value)?"":void 0,...o,ref:a,onClick:W(o.onClick,p=>{p.currentTarget.focus(),l.current!=="mouse"&&w(p)}),onPointerDown:W(o.onPointerDown,p=>{l.current=p.pointerType;const g=p.target;g.hasPointerCapture(p.pointerId)&&g.releasePointerCapture(p.pointerId),p.button===0&&p.ctrlKey===!1&&p.pointerType==="mouse"&&(w(p),p.preventDefault())}),onKeyDown:W(o.onKeyDown,p=>{const g=d.current!=="";!(p.ctrlKey||p.altKey||p.metaKey)&&p.key.length===1&&m(p.key),!(g&&p.key===" ")&&Nm.includes(p.key)&&(w(),p.preventDefault())})})})});Nc.displayName=Rc;var Zc="SelectValue",Oc=f.forwardRef((e,t)=>{const{__scopeSelect:n,className:r,style:o,children:i,placeholder:s="",...c}=e,a=Oe(Zc,n),{onValueNodeHasChildrenChange:u}=a,l=i!==void 0,d=Q(t,a.onValueNodeChange);return ne(()=>{u(l)},[u,l]),_.jsx(q.span,{...c,ref:d,style:{pointerEvents:"none"},children:ta(a.value)?_.jsx(_.Fragment,{children:s}):i})});Oc.displayName=Zc;var Lm="SelectIcon",Dc=f.forwardRef((e,t)=>{const{__scopeSelect:n,children:r,...o}=e;return _.jsx(q.span,{"aria-hidden":!0,...o,ref:t,children:r||"▼"})});Dc.displayName=Lm;var Fm="SelectPortal",Mc=e=>_.jsx(Fo,{asChild:!0,...e});Mc.displayName=Fm;var Ve="SelectContent",jc=f.forwardRef((e,t)=>{const n=Oe(Ve,e.__scopeSelect),[r,o]=f.useState();if(ne(()=>{o(new DocumentFragment)},[]),!n.open){const i=r;return i?Jt.createPortal(_.jsx(Lc,{scope:e.__scopeSelect,children:_.jsx(bn.Slot,{scope:e.__scopeSelect,children:_.jsx("div",{children:e.children})})}),i):null}return _.jsx(Fc,{...e,ref:t})});jc.displayName=Ve;var le=10,[Lc,De]=it(Ve),Bm="SelectContentImpl",Um=pt("SelectContent.RemoveScroll"),Fc=f.forwardRef((e,t)=>{const{__scopeSelect:n,position:r="item-aligned",onCloseAutoFocus:o,onEscapeKeyDown:i,onPointerDownOutside:s,side:c,sideOffset:a,align:u,alignOffset:l,arrowPadding:d,collisionBoundary:m,collisionPadding:h,sticky:w,hideWhenDetached:p,avoidCollisions:g,...x}=e,y=Oe(Ve,n),[b,E]=f.useState(null),[C,A]=f.useState(null),z=Q(t,P=>E(P)),[k,D]=f.useState(null),[Z,L]=f.useState(null),U=yn(n),[M,O]=f.useState(!1),H=f.useRef(!1);f.useEffect(()=>{if(b)return Il(b)},[b]),Za();const I=f.useCallback(P=>{const[G,...te]=U().map(B=>B.ref.current),[V]=te.slice(-1),F=document.activeElement;for(const B of P)if(B===F||(B==null||B.scrollIntoView({block:"nearest"}),B===G&&C&&(C.scrollTop=0),B===V&&C&&(C.scrollTop=C.scrollHeight),B==null||B.focus(),document.activeElement!==F))return},[U,C]),j=f.useCallback(()=>I([k,b]),[I,k,b]);f.useEffect(()=>{M&&j()},[M,j]);const{onOpenChange:$,triggerPointerDownPosRef:K}=y;f.useEffect(()=>{if(b){let P={x:0,y:0};const G=V=>{var F,B;P={x:Math.abs(Math.round(V.pageX)-(((F=K.current)==null?void 0:F.x)??0)),y:Math.abs(Math.round(V.pageY)-(((B=K.current)==null?void 0:B.y)??0))}},te=V=>{P.x<=10&&P.y<=10?V.preventDefault():b.contains(V.target)||$(!1),document.removeEventListener("pointermove",G),K.current=null};return K.current!==null&&(document.addEventListener("pointermove",G),document.addEventListener("pointerup",te,{capture:!0,once:!0})),()=>{document.removeEventListener("pointermove",G),document.removeEventListener("pointerup",te,{capture:!0})}}},[b,$,K]),f.useEffect(()=>{const P=()=>$(!1);return window.addEventListener("blur",P),window.addEventListener("resize",P),()=>{window.removeEventListener("blur",P),window.removeEventListener("resize",P)}},[$]);const[re,Se]=na(P=>{const G=U().filter(F=>!F.disabled),te=G.find(F=>F.ref.current===document.activeElement),V=ra(G,P,te);V&&setTimeout(()=>V.ref.current.focus())}),st=f.useCallback((P,G,te)=>{const V=!H.current&&!te;(y.value!==void 0&&y.value===G||V)&&(D(P),V&&(H.current=!0))},[y.value]),ct=f.useCallback(()=>b==null?void 0:b.focus(),[b]),ke=f.useCallback((P,G,te)=>{const V=!H.current&&!te;(y.value!==void 0&&y.value===G||V)&&L(P)},[y.value]),He=r==="popper"?Yn:Bc,Me=He===Yn?{side:c,sideOffset:a,align:u,alignOffset:l,arrowPadding:d,collisionBoundary:m,collisionPadding:h,sticky:w,hideWhenDetached:p,avoidCollisions:g}:{};return _.jsx(Lc,{scope:n,content:b,viewport:C,onViewportChange:A,itemRefCallback:st,selectedItem:k,onItemLeave:ct,itemTextRefCallback:ke,focusSelectedItem:j,selectedItemText:Z,position:r,isPositioned:M,searchRef:re,children:_.jsx(ti,{as:Um,allowPinchZoom:!0,children:_.jsx(go,{asChild:!0,trapped:y.open,onMountAutoFocus:P=>{P.preventDefault()},onUnmountAutoFocus:W(o,P=>{var G;(G=y.trigger)==null||G.focus({preventScroll:!0}),P.preventDefault()}),children:_.jsx(mo,{asChild:!0,disableOutsidePointerEvents:!0,onEscapeKeyDown:i,onPointerDownOutside:s,onFocusOutside:P=>P.preventDefault(),onDismiss:()=>y.onOpenChange(!1),children:_.jsx(He,{role:"listbox",id:y.contentId,"data-state":y.open?"open":"closed",dir:y.dir,onContextMenu:P=>P.preventDefault(),...x,...Me,onPlaced:()=>O(!0),ref:z,style:{display:"flex",flexDirection:"column",outline:"none",...x.style},onKeyDown:W(x.onKeyDown,P=>{const G=P.ctrlKey||P.altKey||P.metaKey;if(P.key==="Tab"&&P.preventDefault(),!G&&P.key.length===1&&Se(P.key),["ArrowUp","ArrowDown","Home","End"].includes(P.key)){let V=U().filter(F=>!F.disabled).map(F=>F.ref.current);if(["ArrowUp","End"].includes(P.key)&&(V=V.slice().reverse()),["ArrowUp","ArrowDown"].includes(P.key)){const F=P.target,B=V.indexOf(F);V=V.slice(B+1)}setTimeout(()=>I(V)),P.preventDefault()}})})})})})})});Fc.displayName=Bm;var Vm="SelectItemAlignedPosition",Bc=f.forwardRef((e,t)=>{const{__scopeSelect:n,onPlaced:r,...o}=e,i=Oe(Ve,n),s=De(Ve,n),[c,a]=f.useState(null),[u,l]=f.useState(null),d=Q(t,z=>l(z)),m=yn(n),h=f.useRef(!1),w=f.useRef(!0),{viewport:p,selectedItem:g,selectedItemText:x,focusSelectedItem:y}=s,b=f.useCallback(()=>{if(i.trigger&&i.valueNode&&c&&u&&p&&g&&x){const z=i.trigger.getBoundingClientRect(),k=u.getBoundingClientRect(),D=i.valueNode.getBoundingClientRect(),Z=x.getBoundingClientRect();if(i.dir!=="rtl"){const F=Z.left-k.left,B=D.left-F,oe=z.left-B,me=z.width+oe,at=Math.max(me,k.width),ut=window.innerWidth-le,lt=so(B,[le,Math.max(le,ut-at)]);c.style.minWidth=me+"px",c.style.left=lt+"px"}else{const F=k.right-Z.right,B=window.innerWidth-D.right-F,oe=window.innerWidth-z.right-B,me=z.width+oe,at=Math.max(me,k.width),ut=window.innerWidth-le,lt=so(B,[le,Math.max(le,ut-at)]);c.style.minWidth=me+"px",c.style.right=lt+"px"}const L=m(),U=window.innerHeight-le*2,M=p.scrollHeight,O=window.getComputedStyle(u),H=parseInt(O.borderTopWidth,10),I=parseInt(O.paddingTop,10),j=parseInt(O.borderBottomWidth,10),$=parseInt(O.paddingBottom,10),K=H+I+M+$+j,re=Math.min(g.offsetHeight*5,K),Se=window.getComputedStyle(p),st=parseInt(Se.paddingTop,10),ct=parseInt(Se.paddingBottom,10),ke=z.top+z.height/2-le,He=U-ke,Me=g.offsetHeight/2,P=g.offsetTop+Me,G=H+I+P,te=K-G;if(G<=ke){const F=L.length>0&&g===L[L.length-1].ref.current;c.style.bottom="0px";const B=u.clientHeight-p.offsetTop-p.offsetHeight,oe=Math.max(He,Me+(F?ct:0)+B+j),me=G+oe;c.style.height=me+"px"}else{const F=L.length>0&&g===L[0].ref.current;c.style.top="0px";const oe=Math.max(ke,H+p.offsetTop+(F?st:0)+Me)+te;c.style.height=oe+"px",p.scrollTop=G-ke+p.offsetTop}c.style.margin=`${le}px 0`,c.style.minHeight=re+"px",c.style.maxHeight=U+"px",r==null||r(),requestAnimationFrame(()=>h.current=!0)}},[m,i.trigger,i.valueNode,c,u,p,g,x,i.dir,r]);ne(()=>b(),[b]);const[E,C]=f.useState();ne(()=>{u&&C(window.getComputedStyle(u).zIndex)},[u]);const A=f.useCallback(z=>{z&&w.current===!0&&(b(),y==null||y(),w.current=!1)},[b,y]);return _.jsx(Hm,{scope:n,contentWrapper:c,shouldExpandOnScrollRef:h,onScrollButtonChange:A,children:_.jsx("div",{ref:a,style:{display:"flex",flexDirection:"column",position:"fixed",zIndex:E},children:_.jsx(q.div,{...o,ref:d,style:{boxSizing:"border-box",maxHeight:"100%",...o.style}})})})});Bc.displayName=Vm;var Wm="SelectPopperPosition",Yn=f.forwardRef((e,t)=>{const{__scopeSelect:n,align:r="start",collisionPadding:o=le,...i}=e,s=_n(n);return _.jsx(dl,{...s,...i,ref:t,align:r,collisionPadding:o,style:{boxSizing:"border-box",...i.style,"--radix-select-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-select-content-available-width":"var(--radix-popper-available-width)","--radix-select-content-available-height":"var(--radix-popper-available-height)","--radix-select-trigger-width":"var(--radix-popper-anchor-width)","--radix-select-trigger-height":"var(--radix-popper-anchor-height)"}})});Yn.displayName=Wm;var[Hm,wr]=it(Ve,{}),Xn="SelectViewport",Uc=f.forwardRef((e,t)=>{const{__scopeSelect:n,nonce:r,...o}=e,i=De(Xn,n),s=wr(Xn,n),c=Q(t,i.onViewportChange),a=f.useRef(0);return _.jsxs(_.Fragment,{children:[_.jsx("style",{dangerouslySetInnerHTML:{__html:"[data-radix-select-viewport]{scrollbar-width:none;-ms-overflow-style:none;-webkit-overflow-scrolling:touch;}[data-radix-select-viewport]::-webkit-scrollbar{display:none}"},nonce:r}),_.jsx(bn.Slot,{scope:n,children:_.jsx(q.div,{"data-radix-select-viewport":"",role:"presentation",...o,ref:c,style:{position:"relative",flex:1,overflow:"hidden auto",...o.style},onScroll:W(o.onScroll,u=>{const l=u.currentTarget,{contentWrapper:d,shouldExpandOnScrollRef:m}=s;if(m!=null&&m.current&&d){const h=Math.abs(a.current-l.scrollTop);if(h>0){const w=window.innerHeight-le*2,p=parseFloat(d.style.minHeight),g=parseFloat(d.style.height),x=Math.max(p,g);if(x<w){const y=x+h,b=Math.min(w,y),E=y-b;d.style.height=b+"px",d.style.bottom==="0px"&&(l.scrollTop=E>0?E:0,d.style.justifyContent="flex-end")}}}a.current=l.scrollTop})})})]})});Uc.displayName=Xn;var Vc="SelectGroup",[Km,Gm]=it(Vc),Ym=f.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e,o=en();return _.jsx(Km,{scope:n,id:o,children:_.jsx(q.div,{role:"group","aria-labelledby":o,...r,ref:t})})});Ym.displayName=Vc;var Wc="SelectLabel",Xm=f.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e,o=Gm(Wc,n);return _.jsx(q.div,{id:o.id,...r,ref:t})});Xm.displayName=Wc;var Xt="SelectItem",[qm,Hc]=it(Xt),Kc=f.forwardRef((e,t)=>{const{__scopeSelect:n,value:r,disabled:o=!1,textValue:i,...s}=e,c=Oe(Xt,n),a=De(Xt,n),u=c.value===r,[l,d]=f.useState(i??""),[m,h]=f.useState(!1),w=Q(t,y=>{var b;return(b=a.itemRefCallback)==null?void 0:b.call(a,y,r,o)}),p=en(),g=f.useRef("touch"),x=()=>{o||(c.onValueChange(r),c.onOpenChange(!1))};if(r==="")throw new Error("A <Select.Item /> must have a value prop that is not an empty string. This is because the Select value can be set to an empty string to clear the selection and show the placeholder.");return _.jsx(qm,{scope:n,value:r,disabled:o,textId:p,isSelected:u,onItemTextChange:f.useCallback(y=>{d(b=>b||((y==null?void 0:y.textContent)??"").trim())},[]),children:_.jsx(bn.ItemSlot,{scope:n,value:r,disabled:o,textValue:l,children:_.jsx(q.div,{role:"option","aria-labelledby":p,"data-highlighted":m?"":void 0,"aria-selected":u&&m,"data-state":u?"checked":"unchecked","aria-disabled":o||void 0,"data-disabled":o?"":void 0,tabIndex:o?void 0:-1,...s,ref:w,onFocus:W(s.onFocus,()=>h(!0)),onBlur:W(s.onBlur,()=>h(!1)),onClick:W(s.onClick,()=>{g.current!=="mouse"&&x()}),onPointerUp:W(s.onPointerUp,()=>{g.current==="mouse"&&x()}),onPointerDown:W(s.onPointerDown,y=>{g.current=y.pointerType}),onPointerMove:W(s.onPointerMove,y=>{var b;g.current=y.pointerType,o?(b=a.onItemLeave)==null||b.call(a):g.current==="mouse"&&y.currentTarget.focus({preventScroll:!0})}),onPointerLeave:W(s.onPointerLeave,y=>{var b;y.currentTarget===document.activeElement&&((b=a.onItemLeave)==null||b.call(a))}),onKeyDown:W(s.onKeyDown,y=>{var E;((E=a.searchRef)==null?void 0:E.current)!==""&&y.key===" "||(Zm.includes(y.key)&&x(),y.key===" "&&y.preventDefault())})})})})});Kc.displayName=Xt;var dt="SelectItemText",Gc=f.forwardRef((e,t)=>{const{__scopeSelect:n,className:r,style:o,...i}=e,s=Oe(dt,n),c=De(dt,n),a=Hc(dt,n),u=jm(dt,n),[l,d]=f.useState(null),m=Q(t,x=>d(x),a.onItemTextChange,x=>{var y;return(y=c.itemTextRefCallback)==null?void 0:y.call(c,x,a.value,a.disabled)}),h=l==null?void 0:l.textContent,w=f.useMemo(()=>_.jsx("option",{value:a.value,disabled:a.disabled,children:h},a.value),[a.disabled,a.value,h]),{onNativeOptionAdd:p,onNativeOptionRemove:g}=u;return ne(()=>(p(w),()=>g(w)),[p,g,w]),_.jsxs(_.Fragment,{children:[_.jsx(q.span,{id:a.textId,...i,ref:m}),a.isSelected&&s.valueNode&&!s.valueNodeHasChildren?Jt.createPortal(i.children,s.valueNode):null]})});Gc.displayName=dt;var Yc="SelectItemIndicator",Xc=f.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e;return Hc(Yc,n).isSelected?_.jsx(q.span,{"aria-hidden":!0,...r,ref:t}):null});Xc.displayName=Yc;var qn="SelectScrollUpButton",qc=f.forwardRef((e,t)=>{const n=De(qn,e.__scopeSelect),r=wr(qn,e.__scopeSelect),[o,i]=f.useState(!1),s=Q(t,r.onScrollButtonChange);return ne(()=>{if(n.viewport&&n.isPositioned){let c=function(){const u=a.scrollTop>0;i(u)};const a=n.viewport;return c(),a.addEventListener("scroll",c),()=>a.removeEventListener("scroll",c)}},[n.viewport,n.isPositioned]),o?_.jsx(Qc,{...e,ref:s,onAutoScroll:()=>{const{viewport:c,selectedItem:a}=n;c&&a&&(c.scrollTop=c.scrollTop-a.offsetHeight)}}):null});qc.displayName=qn;var Jn="SelectScrollDownButton",Jc=f.forwardRef((e,t)=>{const n=De(Jn,e.__scopeSelect),r=wr(Jn,e.__scopeSelect),[o,i]=f.useState(!1),s=Q(t,r.onScrollButtonChange);return ne(()=>{if(n.viewport&&n.isPositioned){let c=function(){const u=a.scrollHeight-a.clientHeight,l=Math.ceil(a.scrollTop)<u;i(l)};const a=n.viewport;return c(),a.addEventListener("scroll",c),()=>a.removeEventListener("scroll",c)}},[n.viewport,n.isPositioned]),o?_.jsx(Qc,{...e,ref:s,onAutoScroll:()=>{const{viewport:c,selectedItem:a}=n;c&&a&&(c.scrollTop=c.scrollTop+a.offsetHeight)}}):null});Jc.displayName=Jn;var Qc=f.forwardRef((e,t)=>{const{__scopeSelect:n,onAutoScroll:r,...o}=e,i=De("SelectScrollButton",n),s=f.useRef(null),c=yn(n),a=f.useCallback(()=>{s.current!==null&&(window.clearInterval(s.current),s.current=null)},[]);return f.useEffect(()=>()=>a(),[a]),ne(()=>{var l;const u=c().find(d=>d.ref.current===document.activeElement);(l=u==null?void 0:u.ref.current)==null||l.scrollIntoView({block:"nearest"})},[c]),_.jsx(q.div,{"aria-hidden":!0,...o,ref:t,style:{flexShrink:0,...o.style},onPointerDown:W(o.onPointerDown,()=>{s.current===null&&(s.current=window.setInterval(r,50))}),onPointerMove:W(o.onPointerMove,()=>{var u;(u=i.onItemLeave)==null||u.call(i),s.current===null&&(s.current=window.setInterval(r,50))}),onPointerLeave:W(o.onPointerLeave,()=>{a()})})}),Jm="SelectSeparator",Qm=f.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e;return _.jsx(q.div,{"aria-hidden":!0,...r,ref:t})});Qm.displayName=Jm;var Qn="SelectArrow",ev=f.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e,o=_n(n),i=Oe(Qn,n),s=De(Qn,n);return i.open&&s.position==="popper"?_.jsx(pl,{...o,...r,ref:t}):null});ev.displayName=Qn;var tv="SelectBubbleInput",ea=f.forwardRef(({__scopeSelect:e,value:t,...n},r)=>{const o=f.useRef(null),i=Q(r,o),s=Im(t);return f.useEffect(()=>{const c=o.current;if(!c)return;const a=window.HTMLSelectElement.prototype,l=Object.getOwnPropertyDescriptor(a,"value").set;if(s!==t&&l){const d=new Event("change",{bubbles:!0});l.call(c,t),c.dispatchEvent(d)}},[s,t]),_.jsx(q.select,{...n,style:{...Pc,...n.style},ref:i,defaultValue:t})});ea.displayName=tv;function ta(e){return e===""||e===void 0}function na(e){const t=Te(e),n=f.useRef(""),r=f.useRef(0),o=f.useCallback(s=>{const c=n.current+s;t(c),(function a(u){n.current=u,window.clearTimeout(r.current),u!==""&&(r.current=window.setTimeout(()=>a(""),1e3))})(c)},[t]),i=f.useCallback(()=>{n.current="",window.clearTimeout(r.current)},[]);return f.useEffect(()=>()=>window.clearTimeout(r.current),[]),[n,o,i]}function ra(e,t,n){const o=t.length>1&&Array.from(t).every(u=>u===t[0])?t[0]:t,i=n?e.indexOf(n):-1;let s=nv(e,Math.max(i,0));o.length===1&&(s=s.filter(u=>u!==n));const a=s.find(u=>u.textValue.toLowerCase().startsWith(o.toLowerCase()));return a!==n?a:void 0}function nv(e,t){return e.map((n,r)=>e[(t+r)%e.length])}var rv=Ic,ov=Nc,iv=Oc,sv=Dc,cv=Mc,av=jc,uv=Uc,lv=Kc,fv=Gc,dv=Xc,pv=qc,hv=Jc;function Lw({...e}){return _.jsx(rv,{"data-slot":"select",...e})}function Fw({...e}){return _.jsx(iv,{"data-slot":"select-value",...e})}function Bw({className:e,size:t="default",children:n,...r}){return _.jsxs(ov,{"data-slot":"select-trigger","data-size":t,className:ee("border-input data-[placeholder]:text-muted-foreground [&_svg:not([class*='text-'])]:text-muted-foreground focus-visible:border-ring focus-visible:ring-ring/50 aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive dark:bg-input/30 dark:hover:bg-input/50 flex w-fit items-center justify-between gap-2 rounded-md border bg-transparent px-3 py-2 text-sm whitespace-nowrap shadow-xs transition-[color,box-shadow] outline-none focus-visible:ring-[3px] disabled:cursor-not-allowed disabled:opacity-50 data-[size=default]:h-9 data-[size=sm]:h-8 *:data-[slot=select-value]:line-clamp-1 *:data-[slot=select-value]:flex *:data-[slot=select-value]:items-center *:data-[slot=select-value]:gap-2 [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4",e),...r,children:[n,_.jsx(sv,{asChild:!0,children:_.jsx(ao,{className:"size-4 opacity-50"})})]})}function Uw({className:e,children:t,position:n="popper",align:r="center",...o}){return _.jsx(cv,{children:_.jsxs(av,{"data-slot":"select-content",className:ee("bg-popover text-popover-foreground data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 relative z-50 max-h-(--radix-select-content-available-height) min-w-[8rem] origin-(--radix-select-content-transform-origin) overflow-x-hidden overflow-y-auto rounded-md border shadow-md",n==="popper"&&"data-[side=bottom]:translate-y-1 data-[side=left]:-translate-x-1 data-[side=right]:translate-x-1 data-[side=top]:-translate-y-1",e),position:n,align:r,...o,children:[_.jsx(mv,{}),_.jsx(uv,{className:ee("p-1",n==="popper"&&"h-[var(--radix-select-trigger-height)] w-full min-w-[var(--radix-select-trigger-width)] scroll-my-1"),children:t}),_.jsx(vv,{})]})})}function Vw({className:e,children:t,...n}){return _.jsxs(lv,{"data-slot":"select-item",className:ee("focus:bg-accent focus:text-accent-foreground [&_svg:not([class*='text-'])]:text-muted-foreground relative flex w-full cursor-default items-center gap-2 rounded-sm py-1.5 pr-8 pl-2 text-sm outline-hidden select-none data-[disabled]:pointer-events-none data-[disabled]:opacity-50 [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4 *:[span]:last:flex *:[span]:last:items-center *:[span]:last:gap-2",e),...n,children:[_.jsx("span",{className:"absolute right-2 flex size-3.5 items-center justify-center",children:_.jsx(dv,{children:_.jsx(ua,{className:"size-4"})})}),_.jsx(fv,{children:t})]})}function mv({className:e,...t}){return _.jsx(pv,{"data-slot":"select-scroll-up-button",className:ee("flex cursor-default items-center justify-center py-1",e),...t,children:_.jsx(da,{className:"size-4"})})}function vv({className:e,...t}){return _.jsx(hv,{"data-slot":"select-scroll-down-button",className:ee("flex cursor-default items-center justify-center py-1",e),...t,children:_.jsx(ao,{className:"size-4"})})}const gv={sm:"w-8 h-8",md:"w-12 h-12",lg:"w-16 h-16",xl:"w-24 h-24"},wv={sm:"text-xs",md:"text-sm",lg:"text-base",xl:"text-lg"};function oa({size:e="md",className:t,text:n,visible:r=!0}){const{t:o}=er(),i=n===void 0?o("loading.default"):n;return _.jsxs("div",{className:ee("flex flex-col items-center justify-center space-y-2 transition-opacity duration-200",r?"opacity-100":"opacity-0 pointer-events-none",t),children:[_.jsx("div",{className:ee("relative mineru-loading",gv[e]),children:_.jsxs("svg",{width:"64",height:"64",viewBox:"0 0 64 64",fill:"none",xmlns:"http://www.w3.org/2000/svg",className:"w-full h-full",children:[_.jsx("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M21.1513 29.924C21.1513 35.9728 24.1217 41.3284 28.6845 44.6137C31.4126 42.1705 33.1291 38.6224 33.1291 34.6736V24.9187C33.1291 23.4495 34.121 22.1652 35.5434 21.7928L53.36 17.1279C55.4098 16.5912 57.4136 18.1364 57.4136 20.2538L57.4136 32.1232C57.4136 46.1937 45.9984 57.6001 31.9171 57.6001L31.8755 57.6001C17.7941 57.6001 6.37891 46.1937 6.37891 32.1232V23.9317C6.37891 22.457 7.37805 21.1694 8.80736 20.8021L17.1119 18.668C19.1582 18.1421 21.1513 19.6863 21.1513 21.7976V29.924ZM10.0748 32.1232C10.0748 37.0258 11.6957 41.5501 14.4311 45.1904C15.706 46.8871 17.6525 48.0176 19.7748 48.0176C21.7952 48.0176 23.7108 47.5693 25.4274 46.7668C20.56 42.771 17.4554 36.7098 17.4554 29.924V22.393L10.0748 24.2896V32.1232Z",fill:"currentColor",className:"opacity-80 mineru-body"}),_.jsxs("g",{className:"mineru-left-eye",children:[_.jsx("circle",{cx:"37.5682",cy:"13.3644",r:"3.4821",fill:"currentColor",className:"text-gray-800"}),_.jsx("circle",{cx:"37.5682",cy:"13.3644",r:"1.5",fill:"white",className:"mineru-eyeball-left"})]}),_.jsxs("g",{className:"mineru-right-eye",children:[_.jsx("circle",{cx:"49.4166",cy:"9.88223",r:"3.4821",fill:"currentColor",className:"text-gray-800"}),_.jsx("circle",{cx:"49.4166",cy:"9.88223",r:"1.5",fill:"white",className:"mineru-eyeball-right"})]}),_.jsxs("g",{className:"mineru-trail opacity-40",children:[_.jsx("circle",{cx:"15",cy:"50",r:"1",fill:"currentColor",className:"text-blue-400 mineru-trail-1"}),_.jsx("circle",{cx:"12",cy:"52",r:"0.8",fill:"currentColor",className:"text-blue-400 mineru-trail-2"}),_.jsx("circle",{cx:"9",cy:"54",r:"0.6",fill:"currentColor",className:"text-blue-400 mineru-trail-3"})]})]})}),i&&_.jsx("p",{className:ee("text-gray-600 animate-pulse font-medium",wv[e]),children:i})]})}function bv({loading:e=!1,loadingText:t,loadingSize:n="lg",className:r,innerClassName:o,children:i}){const{t:s}=er(),c=t===void 0?s("loading.default"):t;return _.jsxs("div",{className:ee("relative",r),children:[_.jsx("div",{className:ee("absolute inset-0 bg-white/80 backdrop-blur-sm flex items-center justify-center z-10 transition-opacity duration-200",e?"opacity-100":"opacity-0 pointer-events-none"),children:_.jsx(oa,{size:n,text:c,visible:e})}),_.jsx("div",{className:ee("transition-opacity duration-200",e?"opacity-50 pointer-events-none":"opacity-100",o),children:i})]})}function Ww({loading:e=!1,loadingText:t,className:n,children:r}){const{t:o}=er(),i=t===void 0?o("loading.default"):t;return _.jsx("div",{className:ee("min-h-[400px]",n),children:_.jsx(bv,{loading:e,loadingText:i,loadingSize:"lg",children:r})})}function Hw({loading:e=!1,className:t,children:n,...r}){return _.jsxs("button",{className:ee("relative inline-flex items-center justify-center transition-opacity duration-200",e&&"pointer-events-none",t),disabled:e,...r,children:[e&&_.jsx("div",{className:"absolute inset-0 flex items-center justify-center",children:_.jsx(oa,{size:"sm",visible:e})}),_.jsx("span",{className:ee("transition-opacity duration-200",e?"opacity-0":"opacity-100"),children:n})]})}export{Dt as $,fl as A,Cv as B,dl as C,mo as D,In as E,go as F,en as G,ua as H,Pv as I,Hw as J,pw as K,bv as L,cm as M,Vh as N,Wh as O,Ww as P,mr as Q,ll as R,Lw as S,ro as T,vw as U,Ev as V,jw as W,zv as X,_f as Y,si as Z,Ec as _,Bw as a,yp as a$,ni as a0,Fp as a1,up as a2,hp as a3,Je as a4,qd as a5,Qd as a6,hs as a7,ip as a8,ps as a9,Sd as aA,bs as aB,Lp as aC,rp as aD,pp as aE,Ap as aF,gp as aG,ep as aH,Nd as aI,Od as aJ,ur as aK,xp as aL,yi as aM,Ep as aN,Dp as aO,Id as aP,Kd as aQ,Gd as aR,Vd as aS,Ud as aT,Hd as aU,Wd as aV,wp as aW,np as aX,Bd as aY,jp as aZ,Sp as a_,Yd as aa,Xd as ab,Md as ac,jd as ad,Ip as ae,J as af,hd as ag,zd as ah,ls as ai,Ed as aj,yd as ak,us as al,xd as am,wd as an,md as ao,Ad as ap,bd as aq,vd as ar,dd as as,pd as at,$d as au,kd as av,_d as aw,gd as ax,Cd as ay,mn as az,Fw as b,og as b$,Rp as b0,Dd as b1,fp as b2,Pp as b3,ap as b4,kp as b5,ds as b6,op as b7,mp as b8,vp as b9,Wv as bA,Vv as bB,Pd as bC,Tv as bD,Kv as bE,ch as bF,Ch as bG,Os as bH,Ds as bI,th as bJ,eh as bK,bg as bL,Ph as bM,Ns as bN,Zs as bO,Xv as bP,Yv as bQ,qv as bR,Gv as bS,Hv as bT,ks as bU,As as bV,kh as bW,fh as bX,xi as bY,Ei as bZ,vg as b_,zp as ba,Np as bb,$p as bc,Mp as bd,Zp as be,ae as bf,bp as bg,_p as bh,vn as bi,Y as bj,Tp as bk,sp as bl,Op as bm,Cp as bn,ws as bo,T as bp,Ld as bq,Zd as br,Rd as bs,cp as bt,gs as bu,lp as bv,dp as bw,Fd as bx,Iv as by,v as bz,Uw as c,zi as c$,Ms as c0,ys as c1,Cs as c2,_i as c3,Si as c4,bh as c5,lg as c6,zh as c7,Xp as c8,qp as c9,Gt as cA,Vn as cB,Un as cC,dh as cD,zs as cE,fg as cF,Qv as cG,uh as cH,tg as cI,gg as cJ,eg as cK,_h as cL,sh as cM,mg as cN,Gp as cO,hg as cP,Et as cQ,fn as cR,dn as cS,yg as cT,Jv as cU,Eg as cV,ng as cW,_g as cX,cg as cY,Ah as cZ,hh as c_,gt as ca,ge as cb,Bn as cc,gh as cd,Yp as ce,Jp as cf,nh as cg,ig as ch,Is as ci,Rs as cj,Wp as ck,Vp as cl,Kp as cm,Hp as cn,js as co,Ts as cp,Sg as cq,Bs as cr,dg as cs,mh as ct,vt as cu,Pe as cv,ag as cw,Fs as cx,Ls as cy,yh as cz,Vw as d,vc as d$,Ai as d0,Ci as d1,ki as d2,pn as d3,hn as d4,ug as d5,ph as d6,wh as d7,Up as d8,gn as d9,ce as dA,Dv as dB,jv as dC,Ov as dD,Mv as dE,Of as dF,Df as dG,jn as dH,fs as dI,Jd as dJ,tp as dK,Vr as dL,Wr as dM,Zv as dN,fd as dO,Bp as dP,Fv as dQ,Uv as dR,Lv as dS,Bv as dT,jf as dU,Lf as dV,Mf as dW,Nv as dX,Rv as dY,Td as dZ,Qs as d_,Th as da,wg as db,$h as dc,oh as dd,xg as de,Sh as df,Eh as dg,pg as dh,xh as di,sg as dj,Qp as dk,rh as dl,$s as dm,ih as dn,rg as dp,ah as dq,vh as dr,pr as ds,_s as dt,xs as du,Ss as dv,Es as dw,lh as dx,Ps as dy,xe as dz,xv as e,ic as e$,gc as e0,wc as e1,em as e2,Xh as e3,tm as e4,dc as e5,pc as e6,bc as e7,lc as e8,fc as e9,cc as eA,zm as eB,lm as eC,am as eD,xm as eE,nc as eF,Jh as eG,kc as eH,Gh as eI,pm as eJ,Ct as eK,vr as eL,zc as eM,Ac as eN,vm as eO,Am as eP,Sm as eQ,ue as eR,Sc as eS,um as eT,X as eU,bm as eV,Hh as eW,Cm as eX,dm as eY,im as eZ,R as e_,rc as ea,oc as eb,ym as ec,$c as ed,gr as ee,wn as ef,hm as eg,nm as eh,hc as ei,ec as ej,tc as ek,Yt as el,zg as em,fm as en,io as eo,$m as ep,Wn as eq,ac as er,uc as es,Ws as et,Us as eu,Ys as ev,Ks as ew,rm as ex,Ow as ey,mc as ez,Sv as f,Hn as f$,hr as f0,$e as f1,Kh as f2,_c as f3,qh as f4,Qh as f5,sc as f6,Js as f7,mm as f8,$w as f9,Jg as fA,qg as fB,Ng as fC,Iw as fD,oo as fE,nw as fF,iw as fG,om as fH,Bg as fI,Ug as fJ,Cg as fK,Nw as fL,Yg as fM,dw as fN,Fg as fO,km as fP,_w as fQ,mw as fR,ww as fS,Cw as fT,Og as fU,yw as fV,yc as fW,wm as fX,Yh as fY,Kn as fZ,Sw as f_,uw as fa,Hg as fb,Kg as fc,ow as fd,_m as fe,Pw as ff,Vg as fg,Wg as fh,zw as fi,Dg as fj,Mg as fk,Tw as fl,fw as fm,Dh as fn,jh as fo,Gg as fp,kg as fq,Zg as fr,Oh as fs,Mh as ft,xw as fu,ew as fv,tw as fw,Mw as fx,Ag as fy,Qg as fz,Qt as g,Ih as g0,Rh as g1,gw as g2,Gn as g3,gm as g4,Zw as g5,Aw as g6,Em as g7,Pm as g8,Fh as g9,Ig as gA,lw as gB,Lg as gC,Im as gD,rl as gE,ha as gF,Uh as ga,Lh as gb,Bh as gc,Nh as gd,Zh as ge,bw as gf,Dw as gg,hw as gh,Xg as gi,Rw as gj,Ew as gk,Tm as gl,cw as gm,kw as gn,Cc as go,sm as gp,rw as gq,sw as gr,jg as gs,aw as gt,xc as gu,wt as gv,Rg as gw,$g as gx,Pg as gy,Tg as gz,fo as h,Io as i,kv as j,po as k,vl as l,Fo as m,Q as n,W as o,Il as p,$v as q,q as r,Ca as s,Za as t,Te as u,ti as v,pt as w,Av as x,pl as y,uo as z};
